﻿angular.module('fwapp.controllers')

// 登录 注册 个人中心
.controller('AccountController', function ($scope, $rootScope, $state, AccountService, HospitalService
, $ionicPopup, $ionicModal, $ionicPlatform, $ionicHistory, $ionicScrollDelegate, $ionicLoading, $fwCordovaToast) {
    // 若已登录，跳转
    if (localStorage.hasLogin == 1) {
        $state.go('app.home');
    }

    // 移除登录信息
    localStorage.hasLogin = 0;
    $rootScope.hasLogin = 0;
    localStorage.currentAccountId = "";
    // 初始化登录信息
    $scope.data = new Object();
    $scope.data.password = '';
    // 验证码发送时间间隔
    $scope.timespan = 0;
    // 验证用户ID
    $scope.loginAccountId = "";
    // 验证手机号
    $scope.loginPhoneNum = "";
    // 密码强度
    $scope.pwdLevel = 0;
    $scope.pwdLevelDescr = '非常弱';
    $scope.pwdLevelLimit = 1;
    $scope.pwdLevelNotice = '';
    // 错误信息
    $scope.errorMsgPhone = '';
    $scope.errorMsgPwd = '';
    $scope.errorMsgPwd2 = '';
    // 免责声明
    $scope.statement = new Object();
    $scope.statement.agree = false;
    $scope.statement.content = '';
    // 防止多次获取验证码
    $scope.disableGetVericode = false;
    // 防止多次注册
    $scope.disableRegister = false;
    // 防止多次登录
    $scope.disableLogin = false;
    // 图片验证码
    $scope.imageVericode = {};
    $scope.imageVericode.status = 0;
    $scope.imageVericode.src = {};

    // 注册模态窗口 验证码
    $ionicModal.fromTemplateUrl('vericode.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.vericodeModal = modal;
    });
    // 注册模态窗口 免责声明
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('statement.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.statementModal = modal;
    });
    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        if ($scope.vericodeModal) {
            $scope.vericodeModal.remove();
        }
        $scope.statementModal.remove();
    })

    $scope.reg = function () {
        // 改为弹出免责声明
        //$state.go('register');
        $scope.statement.usage = 'reg';
        $scope.statementModal.show();
    }

    $scope.statementHide = function () {
        $scope.statementModal.hide();
        $ionicScrollDelegate.scrollTop();
        $scope.statement.agree = false;
        $scope.statement.usage = '';
    }

    $scope.agree = function () {
        // 2018-12-29 16:57:54 通过免责声明内容 检测网络连接状态
        if ($scope.statement.content == null || $scope.statement.content == "") {
            var alertPopup = $ionicPopup.alert({
                title: '网络连接异常',
                template: '网络连接不可用，请检查网络设置',
                okText: "确定"
            });
            return;
        }
        $scope.statementHide();
        $state.go('register');
    }

    $scope.goBack = function () {
        if ($ionicHistory.currentView().stateName == 'login') {
            $state.go('app.home');
        }
        else {
            $state.go('login')
        }
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        if (localStorage.privacyPolicyAuthStatus == null || localStorage.privacyPolicyAuthStatus == "0") {
            // 跳转首页之后提示隐私授权
            $rootScope.checkPrivacyPolicyAuthStatus();
        }
        // 干掉缓存的用户名密码
        $scope.data.accountCode = '';
        $scope.data.password = '';
        if ($ionicHistory.currentView().stateName == 'login') {
            $ionicPlatform.registerBackButtonAction(function (e) {
                $scope.goBack();
                e.preventDefault();
                return false;
            }, 135, 'account');
        }
        // 登录页面
        if (window.location.href.indexOf("#/login") > -1) {
            // 获取免责声明
            HospitalService.statement().then(function (data) {
                $scope.statement.content = data;
            }, function (err) {
                $fwCordovaToast.showShortBottom("网络连接不可用，请检查网络设置");
            });
            // iOS发布版
            if (window.cordova && currentPlatform == "iOS") {
                // 2017-11-15 17:53:09 js调用蛤蟆吃啥
                window.location.href = serviceUrl + '/Account/RegisterDevice';
            }
        }
        // 注册页面
        else if (window.location.href.indexOf("#/register") > -1) {
            $scope.data.phonenum = '';
            // 获取密码强度限制
            $scope.getPasswordLevelLimit();
            // 获取图片验证码
            $scope.getImageVericode();
        }
        // 若安卓端token仍为空，重新获取
        if (window.cordova && currentPlatform == "Android" && deviceToken == "") {
            // 获取推送ID
            window.plugins.jPushPlugin.getRegistrationID(function (regId) {
                deviceToken = regId;
            })
        }
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        //console.log('beforeLeave' + $ionicHistory.currentView().stateName);
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'account') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
            //console.log($ionicPlatform.$backButtonActions[actionId].id);
            //console.log($ionicPlatform.$backButtonActions[actionId].priority);
        }
    });

    // 切换页面成功 清空数据
    $scope.$on("$locationChangeStart", function (event, newUrl) {
        // 初始化登录信息
        $scope.data = new Object();
        // 错误信息
        $scope.errorMsgPhone = '';
        $scope.errorMsgPwd = '';
        $scope.errorMsgPwd2 = '';
        // 登录页注册回车键登录
        if (newUrl.indexOf('#/login') > -1) {
            $(document).off("keyup");
            $(document).on("keyup", function (e) {
                if (13 == e.keyCode) {
                    $scope.login();
                }
            });
        }
        else {
            $(document).off("keyup");
        }
    });

    // 获取密码强度限制
    $scope.getPasswordLevelLimit = function () {
        //$ionicLoading.show();
        AccountService.getPasswordLevelLimit().then(function (data) {
            //$ionicLoading.hide();
            // 查询成功
            if (data.result == 1) {
                //console.log(data.data);
                $scope.pwdLevelLimit = data.data;
                $scope.pwdLevelNotice = data.notice;
                $scope.errorMsgPwd = $scope.pwdLevelNotice;
            }
        }, function () {
            //$ionicLoading.hide();
        })
    }

    // 登录
    $scope.login = function () {
        // 防止连击
        if (isFastClick()) {
            return;
        }
        $scope.disableLogin = true;
        //console.log($scope.data.accountCode);
        //console.log($scope.data.password);
        // TODO: 验证用户名密码
        AccountService.login($scope.data.accountCode, $scope.data.password).then(function (data) {
            // 登录成功
            if (data.result == 1) {
                // 绑定用户信息
                localStorage.hasLogin = 1;
                $rootScope.hasLogin = 1;
                localStorage.currentAccountId = data.data.id;
                $rootScope.currentAccountId = data.data.id;
                // 2017-01-09 14:52:51 上传通知权限
                SetNoticeAuth();
                // 跳转到首页
                $state.go('app.home');
            }
            // 需要短信验证
            else if (data.result == -1) {
                // 获取图片验证码
                $scope.getImageVericode();
                // 弹出验证码页面
                $scope.loginAccountId = data.data.id;
                $scope.loginPhoneNum = data.data.phone;
                console.log($scope.loginAccountId);
                console.log($scope.loginPhoneNum);
                $scope.vericodeModal.show();
                //$scope.timespan = 60;
                //TimeCount();
            }
            // 登录失败
            else {
                localStorage.haslogin = 0;
                $rootScope.hasLogin = 0;
                var alertPopup = $ionicPopup.alert({
                    title: '登录失败',
                    template: data.msg,
                    okText: "确定"
                });
            }
            $scope.disableLogin = false;
        }, function (data) {
            var alertPopup = $ionicPopup.alert({
                title: '网络连接异常',
                template: '网络连接不可用，请检查网络设置',
                okText: "确定"
            });
            $scope.disableLogin = false;
        });
    };

    // 注册
    $scope.register = function () {
        // 防止连击
        if (isFastClick()) {
            return;
        }
        $scope.disableRegister = true;
        AccountService.register($scope.data.phonenum, $scope.data.password, $scope.data.vericode).then(function (data) {
            // 注册成功
            if (data.result == 1) {
                // 跳转
                localStorage.hasLogin = 1;
                $rootScope.hasLogin = 1;
                localStorage.currentAccountId = data.data.id;
                $rootScope.currentAccountId = data.data.id;
                // 2017-01-09 14:52:51 上传通知权限
                SetNoticeAuth();
                $state.go('app.home');
            }
            // 注册失败
            else {
                var alertPopup = $ionicPopup.alert({
                    title: '注册失败',
                    template: data.msg,
                    okText: "确定"
                });
            }
            $scope.disableRegister = false;
        }, function (data) {
            $scope.disableRegister = false;
        })
    };

    // 隐藏验证码页面
    $scope.vericodeHide = function () {
        $scope.vericodeModal.hide();
        $scope.data.vericode = '';
        //$scope.timespan = 60;
        $scope.phoneNum = '';
    };

    // 格式化手机号
    $scope.formatPhone = function () {
        if ($scope.data.phonenum.indexOf(' ') > -1) {
            $scope.data.phonenum = $scope.data.phonenum.split(' ').join('');
        }
    }

    // 验证手机号
    $scope.checkPhone = function () {
        // 格式化手机号
        $scope.formatPhone();
        var result = true;
        // 验证格式
        result = regPhoneNum.test($scope.data.phonenum);
        // 格式错误
        if (!result) {
            $scope.errorMsgPhone = "手机号错误,请核实后重新输入";
            return false;
        }
        $scope.errorMsgPhone = '';
        return true;
    }

    // 密码强度
    $scope.checkPwdLevel = function () {
        // 检查密码强度
        $scope.pwdLevel = calcPwdLevel($scope.data.password);
        //console.log($scope.pwdLevel);
        if ($scope.pwdLevel > 2) {
            $scope.pwdLevelDescr = '强';
        }
        else if ($scope.pwdLevel > 1) {
            $scope.pwdLevelDescr = '中';
        }
        else if ($scope.pwdLevel > 0) {
            $scope.pwdLevelDescr = '弱';
        }
        else {
            $scope.pwdLevelDescr = '非常弱';
        }
    }

    // 密码验证
    $scope.checkPwd = function () {
        // 检查密码强度
        $scope.checkPwdLevel();
        //console.log($scope.pwdLevel + ":" + $scope.pwdLevelDescr);
        // 密码为空
        if (typeof ($scope.data.password) == 'undefined' || $scope.data.password.length == 0) {
            $scope.errorMsgPwd = '密码不得为空，' + $scope.pwdLevelNotice;
            return false;
        }
        // 密码强度过弱
        if ($scope.pwdLevel < $scope.pwdLevelLimit) {
            $scope.errorMsgPwd = '密码强度过弱，' + $scope.pwdLevelNotice;
            if ($scope.pwdLevelNotice == null || $scope.pwdLevelNotice == '') {
                switch ($scope.pwdLevelLimit) {
                    case 3:
                        $scope.errorMsgPwd += '密码应至少8位，包含数字、小写字母和大写字母。';
                        break;
                    case 2:
                        $scope.errorMsgPwd += '密码应至少8位，包含数字和字母。';
                        break;
                    case 1:
                    default:
                        $scope.errorMsgPwd += '密码应至少6位，建议包含数字和字母。';
                        break;
                }
            }
            return false;
        }
        $scope.errorMsgPwd = '';
        return $scope.checkPwd2();
    }

    // 确认密码验证
    $scope.checkPwd2 = function () {
        // 确认密码为空
        if (typeof ($scope.data.password2) == 'undefined' || $scope.data.password2.length == 0) {
            $scope.errorMsgPwd2 = '确认密码不得为空';
            return false;
        }
        // 两次输入不一致
        if ($scope.data.password != $scope.data.password2) {
            $scope.errorMsgPwd2 = '两次输入的密码不一致';
            return false;
        }
        $scope.errorMsgPwd2 = '';
        return true;
    }

    // 获取验证码
    $scope.getVericode = function (usage) {
        // 防止连击
        if (isFastClick()) {
            return;
        }
        // 验证图片验证码
        if ($scope.data.imageVericode == null || $scope.data.imageVericode.length == 0) {
            var alertPopup = $ionicPopup.alert({
                title: '验证失败',
                template: '图片验证码不得为空',
                okText: "确定"
            });
            return;
        }
        console.log(usage);
        // 注册用 usage=1
        if (usage == '1') {
            console.log($scope.data);
            // 验证手机号
            if ($scope.data.phonenum == null || $scope.data.phonenum.length == 0) {
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: '手机号不得为空',
                    okText: "确定"
                });
                return;
            }
            // 验证密码
            if (!$scope.checkPwd()) {
                var checkPwdMsg = $scope.errorMsgPwd == '' ? $scope.errorMsgPwd2 : $scope.errorMsgPwd;
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: checkPwdMsg,
                    okText: "确定"
                });
                return;
            }
            $scope.disableGetVericode = true;
            AccountService.sendVericodeByPhone($scope.data.phonenum, usage, $scope.data.imageVericode).then(function (data) {
                // 发送成功
                if (data.result == 1) {
                    // 倒计时
                    $scope.timespan = 60;
                    TimeCount();
                }
                // 服务调用失败
                else if (data.result == 0) {
                    // 刷新图片验证码
                    $scope.getImageVericode();
                    var alertPopup = $ionicPopup.alert({
                        title: '验证失败',
                        template: data.msg,
                        okText: "确定"
                    });
                }
                // 发送次数过多
                else {
                    // 刷新图片验证码
                    $scope.getImageVericode();
                    var alertPopup = $ionicPopup.alert({
                        title: '验证失败',
                        template: '获取验证码失败，请稍后重试',
                        okText: "确定"
                    });
                }
                $scope.disableGetVericode = false;
            })
        }
        // 新设备 usage=6
        if (usage == '6') {
            $scope.disableGetVericode = true;
            AccountService.sendVericodeById($scope.loginAccountId, usage, $scope.data.imageVericode).then(function (data) {
                // 发送成功
                if (data.result == 1) {
                    // 倒计时
                    $scope.timespan = 60;
                    TimeCount();
                }
                // 服务调用失败
                else if (data.result == 0) {
                    // 刷新图片验证码
                    $scope.getImageVericode();
                    var alertPopup = $ionicPopup.alert({
                        title: '验证失败',
                        template: data.msg,
                        okText: "确定"
                    });
                }
                // 发送次数过多
                else {
                    // 刷新图片验证码
                    $scope.getImageVericode();
                    var alertPopup = $ionicPopup.alert({
                        title: '验证失败',
                        template: '获取验证码失败，请稍后重试',
                        okText: "确定"
                    });
                }
                $scope.disableGetVericode = false;
            })
        }
    };

    // 比对验证码
    $scope.compareVericode = function () {
        // APP设备首次登录验证 usage=6
        AccountService.compareVericode($scope.loginAccountId, $scope.data.vericode, currentPlatform, deviceToken, "6").then(function (data) {
            if (data.result == 1) {
                // localStorage记录登录状态，登录信息。跳转
                localStorage.hasLogin = 1;
                $rootScope.hasLogin = 1;
                localStorage.currentAccountId = $scope.loginAccountId;
                $rootScope.currentAccountId = $scope.loginAccountId;
                // 2017-01-09 14:52:51 上传通知权限
                SetNoticeAuth();
                $scope.vericodeModal.hide();
                $state.go('app.home');
            }
            else {
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: data.msg,
                    okText: "确定"
                });
            }
        })
    };

    // 重新发送倒计时
    function TimeCount() {
        if (!$scope.$$phase) {
            $scope.$apply($scope.timespan = $scope.timespan - 1);
        } else {
            $scope.timespan = $scope.timespan - 1;
        }
        resendTimeer = setTimeout(TimeCount, 1000);
        if ($scope.timespan <= 0) {
            clearTimeout(resendTimeer);
        }
    };

    $scope.resetPassword = function () {
        $state.go("resetPassword");
    }

    // 获取图片验证码
    $scope.getImageVericode = function () {
        AccountService.getImageVericode().then(function (data) {
            // 需要验证码
            if (data.result == 1) {
                $scope.imageVericode.src = "data:image/jpeg;base64," + data.data;
            }
            // 不需要验证码
            else {
                $scope.imageVericode.src = "";
            }
            $scope.imageVericode.status = data.result;
            $scope.data.imageVericode = "";
        }, function (data) {
            // 获取失败 显示 点击重新获取
            $scope.imageVericode.status = 1;
        });
    }
})