﻿angular.module('fwapp.controllers')

// 医院动态
.controller('ArticleAppController', function ($scope, $rootScope, $state, $stateParams, ArticleAppService, $fwCordovaToast
    , $ionicSlideBoxDelegate, $ionicScrollDelegate, $ionicPlatform, $ionicLoading) {

    // 栏目ID
    $scope.columnId = $stateParams.columnId;
    // 初始滑块状态
    $scope.step = 0;
    // 文章列表
    $scope.articleList = [];
    // 栏目信息
    $scope.columnInfo = new Object();
    // 列表滚动条位置
    $scope.scrollPosition = { left: 0, top: 0, zoom: 1 };
    // 文章内容
    $scope.articleDetail = new Object();
    // 当前页
    $scope.pageNum = 1;
    // 每页数量
    $scope.pageSize = 10;
    // 是否可继续加载
    $scope.canLoadMore = false;
    // 是否加载完毕，防止无内容闪现
    $scope.isLoadFinish = false;
    // 页面标题列表
    $scope.titleList = ["", ""];

    // 滑到上一步
    $scope.lastSlide = function () {
        $ionicSlideBoxDelegate.$getByHandle('slideNews').previous();
    }
    // 滑到下一步
    $scope.nextSlide = function () {
        $ionicSlideBoxDelegate.$getByHandle('slideNews').next();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        $ionicSlideBoxDelegate.$getByHandle('slideNews').slide(index);
    }
    // 滑块切换触发
    $scope.slideChanged = function () {
        // 记录当前步骤
        $scope.step = $ionicSlideBoxDelegate.$getByHandle('slideNews').currentIndex();
        // 重新计算滚动条高度
        $ionicScrollDelegate.resize();
        // 列表页滚到记录高度
        if ($scope.step == 0) {
            $ionicScrollDelegate.$getByHandle('scrollNews').scrollTo($scope.scrollPosition.left, $scope.scrollPosition.top);
            $scope.articleDetail = new Object();
        }
        // 内容页滚到顶
        else {
            $ionicScrollDelegate.scrollTop();
        }
    }

    // 后退 重写goBack
    $scope.goBack = function () {
        if ($scope.step == 0) {
            $rootScope.goBack();
        }
        else {
            $scope.lastSlide();
        }
    }

    $scope.loadList = function (index) {
        ArticleAppService.columnInfo($scope.columnId).then(function (data) {
            $scope.titleList[0] = data.column.NAME;
            $scope.columnInfo = data.column;
        })
        ArticleAppService.list($scope.columnId, $scope.pageNum, $scope.pageSize).then(function (data) {
            if (data.result == 1) {
                for (var i = 0; i < data.articleList.length; i++) {
                    $scope.articleList.push(data.articleList[i]);
                }
                $scope.canLoadMore = (data.pageNum - 1) * data.pageSize + data.articleList.length < data.totalCount;
                $scope.pageNum = $scope.pageNum + 1;
                $scope.isLoadFinish = true;
                $scope.$broadcast('scroll.infiniteScrollComplete');
                $scope.$broadcast('scroll.refreshComplete');
            } else {
                $scope.isLoadFinish = true;
                $fwCordovaToast.showShortBottom("网络异常，请稍后重试!");
            }
        }, function (data) {
            $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
        })
    }

    $scope.loadDetail = function (index) {
        // 记录当前列表页滚动条位置
        $scope.scrollPosition = $ionicScrollDelegate.$getByHandle('scrollNews').getScrollPosition();
        $ionicLoading.show();
        // 跳转
        $scope.nextSlide();
        ArticleAppService.detail($scope.articleList[index].ARTICLE_ID).then(function (data) {
            if (data.result == 1) {
                $scope.articleDetail = data.article;
                console.log(data.article.CONTENT);
                $scope.articleDetail.CONTENT = data.article.CONTENT;
                $scope.titleList[1] = data.article.TITLE;
                $ionicScrollDelegate.resize();
                $ionicLoading.hide();
            } else {
                $ionicLoading.hide();
                $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
            }
        }, function (data) {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
        });
    }

    // 是否可继续延迟加载
    $scope.moreDataCanBeLoaded = function () {
        return $scope.isLoadFinish && $scope.canLoadMore && $scope.step == 0;
    }

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        $ionicSlideBoxDelegate.$getByHandle('slideNews').enableSlide(false);
    })

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            if ($scope.step == 0) {
                $rootScope.goBack();
            }
            else {
                $scope.goBack();
            }
            e.preventDefault();
            return false;
        }, 135, 'articleApp');
        $scope.loadList();
    })

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'articleApp') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    })

})