﻿angular.module('fwapp.controllers')

// 更改密码
.controller('ChangePasswordController', function ($scope, $rootScope, $state, $stateParams, ChangePasswordService, AccountService
, $ionicPopup, $ionicHistory, $ionicPlatform, $ionicLoading) {

    //新旧密码
    $scope.pwdModel = {
        pwd_old: '',
        pwd_new: '',
        pwd_confirm: ''
    }

    // 防止多次提交
    $scope.disableSubmit = false;

    // 密码强度
    $scope.pwdLevel = 0;
    $scope.pwdLevelDescr = '非常弱';
    $scope.pwdLevelLimit = 1;
    $scope.pwdLevelNotice = '';
    // 错误信息
    $scope.errorMsgPhone = '';
    $scope.errorMsgPwd = '';
    $scope.errorMsgPwd2 = '';

    //后退键
    $scope.goBack = function () {
        $state.go("app.securityCenter");
        //        $ionicHistory.goBack();
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'changePassword');
        // 获取密码强度限制
        $scope.getPasswordLevelLimit();
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'changePassword') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });

    // 获取密码强度限制
    $scope.getPasswordLevelLimit = function () {
        //$ionicLoading.show();
        AccountService.getPasswordLevelLimit().then(function (data) {
            //$ionicLoading.hide();
            // 查询成功
            if (data.result == 1) {
                //console.log(data.data);
                $scope.pwdLevelLimit = data.data;
                $scope.pwdLevelNotice = data.notice;
                $scope.errorMsgPwd = $scope.pwdLevelNotice;
            }
        }, function () {
            //$ionicLoading.hide();
        })
    }

    //更改密码
    $scope.submitChange = function () {
        // 防止连击
        if (isFastClick()) {
            return;
        }
        $scope.accountId = localStorage.currentAccountId;
        // 如果不能获取到accountId，转到登录页，如果能，修改密码
        if ($scope.accountid == '') {
            var alertPopup = $ionicPopup.alert({
                title: '请先登录',
                template: null
            });
            // 删除用户信息
            localStorage.hasLogin = 0;
            $rootScope.hasLogin = 0;
            localStorage.currentAccountId = "";
            // 初始化一下消息中心提示
            // 是否有未读消息
            $rootScope.hasUnread = false;
            $rootScope.unReadCount = 0;
            // 跳转到登录页
            $state.go('login');
        }
        else {
            if ($scope.pwdModel.pwd_new == $scope.pwdModel.pwd_confirm) {
                // 验证密码
                if (!$scope.checkPwd()) {
                    var checkPwdMsg = $scope.errorMsgPwd == '' ? $scope.errorMsgPwd2 : $scope.errorMsgPwd;
                    var alertPopup = $ionicPopup.alert({
                        title: '验证失败',
                        template: checkPwdMsg
                    });
                    return;
                }
                $scope.disableSubmit = true;
                ChangePasswordService.changePassword($scope.pwdModel.pwd_old, $scope.pwdModel.pwd_new, $scope.accountId).then(function (data) {
                    //$scope.changeResult = data;
                    if (data.result == 0) {
                        var alertPopup = $ionicPopup.alert({
                            title: '修改失败',
                            template: data.msg
                        });
                    } else if (data.result == 1) {
                        var alertPopup = $ionicPopup.alert({
                            title: '修改成功',
                            template: null
                        });
                        // 删除用户信息
                        localStorage.hasLogin = 0;
                        $rootScope.hasLogin = 0;
                        localStorage.currentAccountId = "";
                        // 初始化一下消息中心提示
                        // 是否有未读消息
                        $rootScope.hasUnread = false;
                        $rootScope.unReadCount = 0;
                        // 跳转到登录页
                        $state.go('login');
                    }
                    $scope.disableSubmit = false;
                }, function (data) {
                    $scope.disableSubmit = false;
                });
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: '修改失败',
                    template: '两次输入的新密码不一致'
                });
            }
        }
    }

    // 密码强度
    $scope.checkPwdLevel = function () {
        // 检查密码强度
        $scope.pwdLevel = calcPwdLevel($scope.pwdModel.pwd_new);
        //console.log($scope.pwdLevel);
        if ($scope.pwdLevel > 2) {
            $scope.pwdLevelDescr = '强';
        }
        else if ($scope.pwdLevel > 1) {
            $scope.pwdLevelDescr = '中';
        }
        else if ($scope.pwdLevel > 0) {
            $scope.pwdLevelDescr = '弱';
        }
        else {
            $scope.pwdLevelDescr = '非常弱';
        }
    }

    // 密码验证
    $scope.checkPwd = function () {
        // 检查密码强度
        $scope.checkPwdLevel();
        //console.log($scope.pwdLevel + ":" + $scope.pwdLevelDescr);
        // 密码为空
        if (typeof ($scope.pwdModel.pwd_new) == 'undefined' || $scope.pwdModel.pwd_new.length == 0) {
            $scope.errorMsgPwd = '密码不得为空，' + $scope.pwdLevelNotice;
            return false;
        }
        // 密码强度过弱
        if ($scope.pwdLevel < $scope.pwdLevelLimit) {
            $scope.errorMsgPwd = '密码强度过弱，' + $scope.pwdLevelNotice;
            if ($scope.pwdLevelNotice == null || $scope.pwdLevelNotice == '') {
                switch ($scope.pwdLevelLimit) {
                    case 3:
                        $scope.errorMsgPwd += '密码应至少8位，包含数字、小写字母和大写字母。';
                        break;
                    case 2:
                        $scope.errorMsgPwd += '密码应至少8位，包含数字和字母。';
                        break;
                    case 1:
                    default:
                        $scope.errorMsgPwd += '密码应至少6位，建议包含数字和字母。';
                        break;
                }
            }
            return false;
        }
        $scope.errorMsgPwd = '';
        return $scope.checkPwd2();
    }

    // 确认密码验证
    $scope.checkPwd2 = function () {
        // 确认密码为空
        if (typeof ($scope.pwdModel.pwd_confirm) == 'undefined' || $scope.pwdModel.pwd_confirm.length == 0) {
            $scope.errorMsgPwd2 = '确认密码不得为空';
            return false;
        }
        // 两次输入不一致
        if ($scope.pwdModel.pwd_new != $scope.pwdModel.pwd_confirm) {
            $scope.errorMsgPwd2 = '两次输入的密码不一致';
            return false;
        }
        $scope.errorMsgPwd2 = '';
        return true;
    }
})