angular.module('fwapp.controllers')

// 我的在线问诊
.controller('ConsultationListController', function ($scope, $rootScope, $state, $http, $window
, $ionicPopup, $ionicLoading, $ionicModal, $ionicScrollDelegate, $ionicPlatform, $ionicSlideBoxDelegate, $interval, $stateParams
, $cordovaAppVersion, $cordovaFileTransfer, $cordovaFileOpener2, $fwCordovaToast, $cordovaInAppBrowser
, ConsultationService, VisitPatientService, RequestService) {

    // 如果没登录 扔出去
    if (localStorage.currentAccountId.length == 0) {
        $state.go("login");
        return;
    }

    // 定义视频问诊滑块
    var slideConsultationList = $ionicSlideBoxDelegate.$getByHandle('slideConsultationList');
    // 初始滑块状态
    $scope.step = 0;

    // 会话列表
    $scope.chatInfoList = [];
    // 显示会话分类
    $scope.type = "1";
    // 刷新计时器
    $scope.refershTimer = undefined;
    // 刷新计时器间隔毫秒（1分钟）
    $scope.refershTimerInterval = 1000 * 60;
    // 配置项
    $scope.configData = {};
    // 会话详情
    $scope.chatSignle = {};
    // 2021-10-22 16:57:45 是否跳转转诊支付
    $scope.toPayReferral = $stateParams.toPayReferral;

    // #region 滑动方法

    // 滑到上一步
    $scope.lastSlide = function () {
        slideConsultationList.previous();
        $scope.step = slideConsultationList.currentIndex();
    }
    // 滑到下一步
    $scope.nextSlide = function () {
        slideConsultationList.next();
        $scope.step = slideConsultationList.currentIndex();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        slideConsultationList.slide(index);
        $scope.step = slideConsultationList.currentIndex();
        console.log("toSlide =>" + index);
    }

    // 页面切换
    $scope.slideChanged = function () {
        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();
        //$fwCordovaToast.showShortBottom("step: " + $scope.step);
    }

    // #endregion

    // #region 模态框相关

    // 注册模态窗口 查看病情描述
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('infomation.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.infomationModal = modal;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.infomationModal.remove();
    })

    // 病情描述模态框展示
    $scope.infomationModalShow = function () {
        $scope.infomationModal.show();
    }

    // 病情描述模态框隐藏
    $scope.infomationModalHide = function () {
        $scope.infomationModal.hide();
    }

    // #endregion

    // 1. 定时刷新会话列表
    $scope.refreshTimerInit = function () {
        $scope.refreshTimerDestroy();
        $scope.refershTimer = $interval(function () {
            // 如果会话列表
            $scope.getChatInfoList();
        }, $scope.refershTimerInterval);
        // 获取会话列表
        $scope.getChatInfoList();
    }

    // 销毁刷新定时器
    $scope.refreshTimerDestroy = function () {
        if (angular.isDefined($scope.refershTimer)) {
            $interval.cancel($scope.refershTimer);
            $scope.refershTimer = undefined;
        }
    }

    // 2. 获取会话列表
    $scope.getChatInfoList = function (type) {
        if (type == "refresh") {
            // 直接广播刷新完毕，使下拉刷新隐藏
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $scope.$broadcast('scroll.refreshComplete');
            $ionicLoading.show();
        }

        // 获取会话列表
        ConsultationService.getChatInfoList($scope.type).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 1) {
                $scope.chatInfoList = data.data;
                // 2021-10-22 18:26:40 切换图文/视频 刷新列表 回到顶端
                if (type == "changeType") {
                    $ionicScrollDelegate.scrollTop();
                    $ionicScrollDelegate.resize();
                }
                // 2021-10-22 17:29:19 转诊跳转支付
                if ($scope.toPayReferral == "1") {
                    for (var i in $scope.chatInfoList) {
                        if ($scope.chatInfoList[i].status == "0" && ($scope.chatInfoList[i].is_referral == '1' || $scope.chatInfoList[i].is_referral == '2')) {
                            $scope.pay(i);
                            break;
                        }
                    }
                }
            }
            else {
                $scope.chatInfoList = [];
                $fwCordovaToast.showShortBottom(data.msg);
            }
            // 首次跳转后重置
            $scope.toPayReferral = "0";
        }, function () {
            $ionicLoading.hide();
            $scope.chatInfoList = [];
            $fwCordovaToast.showShortBottom("获取会话列表，网络错误");
        })
    }

    // 3. 图文问诊进入会话
    $scope.openChat = function (index) {
        // 2021-8-24 13:37:22 HM 改成，调易复诊新SDK了
        var chatInfo = $scope.chatInfoList[index];

        // 历史会话
        if (chatInfo.status == "3" || chatInfo.status == "8" || chatInfo.status == "9" || chatInfo.status == "10") {
            // 调易复诊SDK
            if (chatInfo.IM_TYPE == "1") {
                var param = {
                    accountId: chatInfo.vpId.replace(/[-]/g, ""),
                    hospitalOrderId: chatInfo.treatApplyId
                };

                var funcSuccess = function (funcData) {
                    console.log('百洋：openChatMessageRecord 调用成功');
                    console.log(funcData);
                }

                var funcError = function (funcData) {
                    console.log('百洋：openChatMessageRecord 调用失败');
                    console.log(funcData);
                }
                // 2023-10-07 11:09:00 CGZ 移除道一巡和易复诊插件
                //window.plugins.EasyChatPlugin.openChatMessageRecord(param, funcSuccess, funcError);
            }
            // 调腾讯SDK
            else {
                var param = { type: "chat", param: chatInfo.IM_URL };

                var funcSuccess = function (data) {
                    console.log("MiniProgramPlugin：launchMiniProgram 调用成功");
                    console.log(data);
                }
                var funcError = function (data) {
                    console.log("MiniProgramPlugin：launchMiniProgram 调用失败");
                    console.log(data);
                }

                window.plugins.MiniProgramPlugin.launchMiniProgramV2(param, funcSuccess, funcError);
            }
        }
        else if (chatInfo.status == "2") {
            // 走AJAX，获取患者基本信息
            $ionicLoading.show();
            ConsultationService.visitPatientInfo(chatInfo.vpId).then(function (data) {
                $ionicLoading.hide();
                if (data.result == 0) {
                    $fwCordovaToast.showShortBottom(data.msg);
                }
                else {
                    // 调易复诊SDK
                    if (chatInfo.IM_TYPE == "1") {
                        var param = {
                            accountSourceId: data.data.ACCOUNT_ID,
                            accountId: data.data.VISIT_PATIENT_ID,
                            patientName: data.data.VISIT_PATIENT_NAME,
                            patientSex: data.data.SEX == '1' ? "男" : "女",
                            patientBirthday: data.data.BIRTHDAY.slice(0, 10),
                            patientHeadPic: data.data.HEAD_PIC,
                            patientPhoneNo: data.data.PHONE_NUM,
                            doctorId: chatInfo.doctorCode,
                            doctorEmployeeCardNo: chatInfo.staffNumber, // 胸卡号
                            hospitalOrderId: chatInfo.treatApplyId,
                            fuzhen: "0"
                        };

                        var funcSuccess = function (funcData) {
                            console.log('百洋：toChat 调用成功');
                            console.log(funcData);
                        }

                        var funcError = function (funcData) {
                            console.log('百洋：toChat 调用失败');
                            console.log(funcData);
                        }
                        // 2023-10-07 11:09:00 CGZ 移除道一巡和易复诊插件
                        //window.plugins.EasyChatPlugin.toChat(param, funcSuccess, funcError);
                    }
                    // 调腾讯SDK
                    else {
                        var param = { type: "chat", param: chatInfo.IM_URL };

                        var funcSuccess = function (data) {
                            console.log("MiniProgramPlugin：launchMiniProgram 调用成功");
                            console.log(data);
                        }
                        var funcError = function (data) {
                            console.log("MiniProgramPlugin：launchMiniProgram 调用失败");
                            console.log(data);
                        }

                        window.plugins.MiniProgramPlugin.launchMiniProgramV2(param, funcSuccess, funcError);
                    }
                }
            }, function () {
                $ionicLoading.hide();
                $fwCordovaToast.showShortBottom("获取患者基本信息，网络错误");
            })
        }
        // 2021-10-22 13:50:42 待支付转诊 跳转缴费
        else if (chatInfo.status == "0") {
            $scope.pay(index);
        }
        // 2024-4-17 18:00:10 HM 自行退款
        else if (chatInfo.status == "14") {
            $ionicLoading.show();
            ConsultationService.getRefundBJYBUrlBYTreat(chatInfo.treatApplyId, chatInfo.vpId).then(function (data) {
                $ionicLoading.hide();
                if (data.result == 0) {
                    $ionicPopup.alert({
                        title: '提示',
                        template: data.msg,
                        okText: "确定"
                    });
                }
                else {
                    if (data.ybUrl != "") {
                        // 先用cordovaInAppBrowser的方式，后期还得切换到插件的形式
                        var herfUrl = "https://ds.alipay.com/?scheme=" + encodeURIComponent("alipays://platformapi/startapp?appId=2021003175643256&page=" + encodeURIComponent(data.ybUrl));

                        //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
                        //$cordovaInAppBrowser.open(herfUrl, '_system', option).then(function (event) { });
                        //2023.7.31 新插件原有调用方式参数不生效
                        showInAppBrowser(herfUrl, '_system');

                        // 注册个返回事件
                        document.addEventListener("resume", OnResumeYBCancel, false);
                    }
                    else {
                        $ionicPopup.alert({
                            title: '提示',
                            template: "网络错误，请稍后重试",
                            okText: "确定"
                        });
                    }
                }
            }, function () {
                var alertPopup = $ionicPopup.alert({
                    title: '网络错误',
                    template: '加载失败,请检查网络'
                });
                $ionicLoading.hide();
            })
        }
    }

    // app后台回到
    function OnResumeYBCancel() {
        setTimeout(function () {
            // 刷新订单列表
            $scope.getChatInfoList();

            // 解绑后台唤醒事件监测
            document.removeEventListener("resume", OnResumeYBCancel, false);
        }, 1000);
    }

    // 3.1 查看历史会话
    $scope.getHistoryChatInfo = function (treatApplyId, vpId) {
        // 重置状态
        $scope.chatSignle = {};

        $ionicLoading.show();
        ConsultationService.getHistoryChatInfo(treatApplyId, vpId).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                var alertPopup = $ionicPopup.alert({
                    title: '错误',
                    template: data.msg
                });
            }
            else {
                // 赋值，然后跳转到下一页面
                $scope.chatSignle = data.data;
                console.log($scope.chatSignle);
                $scope.toSlide(1);
            }
        }, function () {
            var alertPopup = $ionicPopup.alert({
                title: '网络错误',
                template: '加载失败,请检查网络'
            });
            $ionicLoading.hide();
        })
    }

    // 3.1 查看病情描述
    $scope.goInfomation = function (index) {
        var infomation = $scope.chatSignle[index];
        var data = {
            "infomationId": infomation.TREAT_INFOMATION_ID,
            "vpId": infomation.VISIT_PATIENT_ID,
            "doctorCode": infomation.DOCTOR_CODE,
            "isSubmit": false,
            "treatType": 1
        };

        $scope.infomationModalShow();
        $scope.$broadcast("infomationShow", data);
    }

    // 3.2 接收病情描述返回
    $scope.$on('infomationHide', function (event, data) {
        $scope.infomationModalHide();
    })

    // 3.3 显示弹出大图
    $scope.popupImgShow = function (index) {
        var infomation = $scope.chatSignle[index];
        $scope.showImageUrl = "";

        $ionicModal.fromTemplateUrl("popup_image_info.html", {
            scope: $scope,
            animation: "fade-in"
        }).then(function (modal) {
            $scope.popupImageModal = modal;

            $scope.showImageUrl = infomation.MSG_CONTENT;
            $scope.popupImageModal.show();
        });
    }

    // 3.3.1 隐藏弹出大图
    $scope.popupImgHide = function () {
        // 隐藏弹出
        $scope.popupImageModal.hide();
        $scope.popupImageModal.remove();
    }

    // 3.4 查看媒体资料
    $scope.getMediaInfo = function (index) {
        var infomation = $scope.chatSignle[index];
        //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
        //$cordovaInAppBrowser.open(infomation.MSG_CONTENT, '_system', option).then(function (event) { });
        //2023.7.31 新插件原有调用方式参数不生效
        showInAppBrowser(infomation.MSG_CONTENT, '_system');
    }

    // 4. 进入会话详情
    $scope.goOlTreatVideo = function (vpId, treatApplyId) {
        $state.go("app.olTreatVideo", { vpId: vpId, treatApplyId: treatApplyId });
    }

    // 5. 收银台
    // 2021-10-22 13:53:32 与openChat统一传入index
    $scope.pay = function (index) {
        var obj = $scope.chatInfoList[index];
        // 2024-4-18 08:48:59 HM 需要验证一下是否医保患者
        // 先验证是否为医保患者
        $ionicLoading.show();
        RequestService.checkMI(obj.vPID).then(function (dataMI) {
            $ionicLoading.hide();
            if (dataMI.result == 1) {
                var isPatientMI = dataMI.isMI == "1";
                console.log("是否为医保患者:" + isPatientMI);

                // 吃后端一个配置
                if (obj.byTreatBJYBPayStatus == "0") {
                    isPatientMI = false;
                }

                //收银台
                $scope.cashier("consultation", obj.fee, obj.vPID, obj.treatApplyId, "", "", obj.doctorCode, isPatientMI, "", "", obj.fee).then(function (dataCashier) {
                    if (dataCashier.code == 1) {
                        $scope.respApply(obj);
                    }
                    else {
                        // $scope.applyId = "";
                    }
                })
            }
            // 报错了
            else {
                $ionicPopup.alert({
                    title: '提示',
                    template: dataMI.msg,
                    okText: "确定"
                });
            }
        }, function (data) {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "判断是否为医保患者失败，请稍后再试",
                okText: "确定"
            });
        })
    }

    // 6. 验证支付状态
    $scope.respApply = function (obj) {
        $ionicLoading.show();
        ConsultationService.respApply(obj.treatApplyId, obj.informationId).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 1) {
                // 调易复诊SDK
                if (data.data.IM_TYPE == "1") {
                    // 调易复诊sdk
                    // 2020-2-6 14:02:52 HM 在线咨询功能修改，这里全部默认为初诊患者，0为初诊、1为就诊
                    var param = {
                        accountSourceId: obj.accountId,
                        accountId: obj.vPID,
                        patientName: obj.vPName,
                        patientSex: obj.vPSex == '1' ? "男" : "女",
                        patientBirthday: obj.vPBirthday.slice(0, 10),
                        patientHeadPic: obj.headPic,
                        patientPhoneNo: obj.phoneNum,
                        doctorId: obj.doctorCode,
                        doctorEmployeeCardNo: obj.staffNumber, // 胸卡号
                        hospitalOrderId: obj.treatApplyId,
                        fuzhen: "0"
                    };

                    var funcSuccess = function (funcData) {
                        console.log('百洋：toChat 调用成功');
                        console.log(funcData);
                    }

                    var funcError = function (funcData) {
                        console.log('百洋：toChat 调用失败');
                        console.log(funcData);
                    }
                    // 2023-10-07 11:09:00 CGZ 移除道一巡和易复诊插件
                    //window.plugins.EasyChatPlugin.toChat(param, funcSuccess, funcError);
                }
                // 调腾讯SDK
                else {
                    var param = { type: "chat", param: data.data.IM_URL };

                    var funcSuccess = function (data) {
                        console.log("MiniProgramPlugin：launchMiniProgram 调用成功");
                        console.log(data);
                    }
                    var funcError = function (data) {
                        console.log("MiniProgramPlugin：launchMiniProgram 调用失败");
                        console.log(data);
                    }

                    window.plugins.MiniProgramPlugin.launchMiniProgramV2(param, funcSuccess, funcError);
                }
            }
            else if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            else {
                $fwCordovaToast.showShortBottom("网络错误");
            }
        }, function () {
            $fwCordovaToast.showShortBottom("网络错误");
            $ionicLoading.hide();
        })
    }

    // 7.取消预约
    $scope.cancelBYApply = function (index) {
        $ionicPopup.confirm({
            title: "提示",
            template: "当前操作不可逆，是否确认取消预约？",
            cancelText: '取消',
            okText: '确定'
        }).then(function (res) {
            if (res) {
                var obj = $scope.chatInfoList[index];

                $ionicLoading.show();
                ConsultationService.cancelBYTreatApply(obj.treatApplyId, obj.vPID).then(function (data) {
                    $ionicLoading.hide();
                    if (data.result == 0) {
                        var alertPopup = $ionicPopup.alert({
                            title: '错误',
                            template: data.msg
                        });
                    }
                    else {
                        // 刷新列表
                        $scope.getChatInfoList("refresh");
                    }
                }, function () {
                    var alertPopup = $ionicPopup.alert({
                        title: '网络错误',
                        template: '加载失败,请检查网络'
                    });
                    $ionicLoading.hide();
                })
            }
        })
    }

    // 切换tab标签页
    $scope.changeType = function (type) {
        $scope.type = type;
        $scope.chatInfoList = [];
        // 获取会话列表
        $scope.getChatInfoList("changeType");
    }

    // 医保患者自行退号
    $scope.signOutVideoApply = function (vpId, treatApplyId) {
        //console.log("1111");
        $ionicPopup.confirm({
            title: "提示",
            template: "当前操作不可逆，是否确认取消预约？",
            cancelText: '取消',
            okText: '确定'
        }).then(function (res) {
            if (res) {
                // 退号，退费
                $scope.cancelApply(vpId, treatApplyId);
            }
        })
    }

    $scope.cancelApply = function (vpId, treatApplyId) {
        $ionicLoading.show();
        ConsultationService.overTimeVideoApply(treatApplyId, vpId).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
            else if (data.result == 99) {
                $ionicPopup.alert({
                    title: '提示',
                    template: "网络超时，请重试",
                    okText: "确定"
                });
            }
            // 有可能有1，有可能有2
            else {
                // 这个页面调用，状态一定是15，前端卡了状态，ybUrl一定不为空
                // 医保移动支付跳转
                if (data.ybUrl != "") {
                    // 先用cordovaInAppBrowser的方式，后期还得切换到插件的形式
                    var herfUrl = "https://ds.alipay.com/?scheme=" + encodeURIComponent("alipays://platformapi/startapp?appId=2021003175643256&page=" + encodeURIComponent(data.ybUrl));

                    //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
                    //$cordovaInAppBrowser.open(herfUrl, '_system', option).then(function (event) { });
                    //2023.7.31 新插件原有调用方式参数不生效
                    showInAppBrowser(herfUrl, '_system');

                    // 注册个返回事件
                    document.addEventListener("resume", OnResumeYBCancel, false);
                }
                else {
                    $ionicLoading.hide();
                    $ionicPopup.alert({
                        title: '提示',
                        template: "网络失败，请稍后再试",
                        okText: "确定"
                    });
                }
            }
        }, function () {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "网络失败，请稍后再试",
                okText: "确定"
            });
        })
    }

    // app后台回到
    function OnResumeYBCancel() {
        setTimeout(function () {
            // 获取会话列表
            $scope.getChatInfoList();

            // 解绑后台唤醒事件监测
            document.removeEventListener("resume", OnResumeYBCancel, false);
        }, 1000);
    }

    // 返回
    $scope.goBack = function () {
        if ($scope.step == 0) {
            $state.go('app.personal');
        }
        else {
            $scope.toSlide(0);
        }
    }

    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'consultationList');

        $ionicLoading.show();
        ConsultationService.getConfig().then(function (conData) {
            $ionicLoading.hide();
            if (conData.result == 0) {
                $fwCordovaToast.showShortBottom(conData.msg);
            }
            else {
                $scope.configData = conData.data;

                // 如果进来的是视频问诊，这里直接替他选好视频问诊
                if ($stateParams.treatType == "2") {
                    $scope.type = "2";
                }

                // 初始化刷新计时器
                $scope.refreshTimerInit();
            }
        }, function () {
            $fwCordovaToast.showShortBottom("网络错误");
            $ionicLoading.hide();
        })
    });

    $scope.$on('$ionicView.beforeLeave', function () {
        // 解除返回键绑定
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'consultationList') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }

        $scope.refreshTimerDestroy();
    });

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        slideConsultationList.enableSlide(false);
    });
})
