﻿angular.module('fwapp.controllers')

.controller('DietController', function ($scope, $rootScope, $state, $stateParams, $timeout,
    VisitPatientService, HealthService, SrvyService,
    $ionicSlideBoxDelegate, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $ionicPopup, $ionicActionSheet, $ionicModal, $ionicPopover,
    $cordovaDatePicker, $fwCordovaToast) {

    // 就诊人ID
    $scope.vpId = $stateParams.vpid;
    // 就诊人信息
    $scope.vpInfo = new Object();
    // 就诊人列表
    $scope.vpList = [];

    // 每日饮食
    $scope.dailyDiet = new Object();
    // 查看日期
    $scope.dietDate = (new Date()).Format("yyyy-MM-dd");
    // 最后可查看日期
    $scope.lastDate = (new Date()).Format("yyyy-MM-dd");
    // 饮食TAB业
    $scope.dietTab = 0;

    // 卡路里目标
    $scope.dietGoal = { CALORIES_GOAL: 2500 };

    // 每餐饮食
    $scope.mealDiet = new Object();

    // 食物列表
    $scope.foodList = [];
    // 常用食物列表
    $scope.favoriteFoodList = [];
    // 食物查询条件
    $scope.foodFilter = new Object();
    // 临时列表
    $scope.tmpFoodList = [];

    // 问卷调查信息
    $scope.srvyInfo = [];
    // 个人填写问卷信息
    $scope.selfSrvyList = [];

    // 模板内容
    $scope.tmpl = new Object();
    // 模板信息
    $scope.tmplInfo = new Object();
    // 总题数
    $scope.qstnCount = 0;
    // 问卷结果
    $scope.srvyResult = new Object();
    // 当前问卷ID
    $scope.currentRec = new Object();
    // 反馈列表(评价)
    $scope.fbResultList = new Object();
    // 反馈列表(评分)
    $scope.fbCalcList = new Object();
    // 反馈TAB页
    $scope.feebbackTab = 0;
    // 评价反馈数量
    $scope.fbResultCount = 0;

    // 注册模态窗口：每餐信息
    $ionicModal.fromTemplateUrl('diet_meal.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.dietMealModal = modal;
    });

    // 注册模态窗口：食物查找
    $ionicModal.fromTemplateUrl('diet_food.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.dietFoodModal = modal;
    });

    // 注册模态窗口：量表评估
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('srvyTmpl.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.srvyModal = modal;
    });

    // 注册模态窗口：建议反馈
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('feedback.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.feedbackModal = modal;
    });

    // 注册模态窗口：饮食目标
    $ionicModal.fromTemplateUrl('diet_goal.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.dietGoalModal = modal;
    });

    // 注册弹出菜单：就诊人列表
    $ionicPopover.fromTemplateUrl('pop_vplist.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popVplist = popover;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.dietMealModal.remove();
        $scope.dietFoodModal.remove();
        $scope.srvyModal.remove();
        $scope.feedbackModal.remove();
        $scope.dietGoalModal.remove();
    })

    //#region 饮食信息

    // 加载饮食列表
    $scope.loadDailyDiet = function () {
        $ionicLoading.show();
        HealthService.getDailyDiet($scope.vpId, $scope.dietDate).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            else if (!data.isEmpty) {
                $scope.dailyDiet = data.data;
            } else {
                initDailyDiet();
            }
            $ionicLoading.hide();
        })
    }

    // 获取饮食目标
    $scope.getDietGoal = function () {
        HealthService.getDietGoal($scope.vpId).then(function (data) {
            $scope.dietGoal.CALORIES_GOAL = data.CALORIES_GOAL;
        });
    }

    // 前一天
    $scope.preDay = function () {
        $scope.dietDate = new Date((new Date($scope.dietDate)).setDate(new Date($scope.dietDate).getDate() - 1)).Format("yyyy-MM-dd");
        $scope.loadDailyDiet();
    }

    // 后一天
    $scope.nextDay = function () {
        if ($scope.dietDate == (new Date()).Format("yyyy-MM-dd")) {
            return false;
        }
        $scope.dietDate = new Date((new Date($scope.dietDate)).setDate(new Date($scope.dietDate).getDate() + 1)).Format("yyyy-MM-dd");
        $scope.loadDailyDiet();
    }

    // 切换就诊人
    $scope.changeVp = function (vpid) {
        $scope.vpId = vpid;
        $scope.vpInfo = new Object();
        $scope.loadVPInfo();
        $scope.loadDailyDiet();
        $scope.loadSrvyInfo();
        $scope.getDietGoal();
        $scope.popVplist.hide();
    }

    // 编辑每餐饮食
    $scope.editMeal = function (mealId, type, name) {
        HealthService.getMealDiet($scope.vpId, mealId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            else if (!data.isEmpty) {
                $scope.mealDiet = data.data;
            } else {
                initMealDiet();
            }

            $scope.mealDiet.MEAL_TYPE = type;
            $scope.mealDiet.MEAL_NAME = name;
            $scope.dietMealModal.show();

            if ($scope.mealDiet.DIET_MEAL_ID == '') {
                $scope.addFood();
            }
        });
    }

    // 每餐饮食关闭
    $scope.editMealHide = function () {
        $scope.dietMealModal.hide();
    }

    // 修改食物数量
    $scope.addAmount = function (food, value) {
        var amountTest = food.FOOD_AMOUNT + value;
        if (amountTest <= 0) {
            $ionicPopup.confirm({
                title: '删除确认',
                template: '是否删除该食物？',
                okText: '确认',
                cancelText: '取消'
            }).then(function (res) {
                if (res) {
                    for (var i = 0; i < $scope.mealDiet.DETAIL.length; i++) {
                        if ($scope.mealDiet.DETAIL[i].FOOD_ID == food.FOOD_ID) {
                            $scope.mealDiet.DETAIL.splice(i, 1);
                            break;
                        }
                    }

                    $scope.mealDiet = calcMeal($scope.mealDiet);
                }
                else {
                    return false;
                }
            });
        }
        else {
            food.FOOD_AMOUNT += value;
            calcFood(food, food.FOOD_INFO, food.FOOD_AMOUNT);
            calcMeal($scope.mealDiet);
        }
    }

    // 保存
    $scope.saveMeal = function () {
        var param = '';
        if ($scope.mealDiet.DETAIL.length > 0) {
            for (var i = 0; i < $scope.mealDiet.DETAIL.length; i++) {
                param += $scope.mealDiet.DETAIL[i].FOOD_ID + ";" + $scope.mealDiet.DETAIL[i].FOOD_AMOUNT + "|";
            }
            param = param.substr(0, param.length - 1);
        }
        HealthService.editMealDiet($scope.vpId, $scope.dietDate, $scope.mealDiet.MEAL_TIME, $scope.mealDiet.DIET_MEAL_ID, $scope.mealDiet.MEAL_TYPE, param).then(function (data) {
            if (data.result == 1) {
                $scope.loadDailyDiet();
                $scope.editMealHide();
            }
        });
    }

    // 切换饮食TAB页
    $scope.dietTabChange = function (index) {
        $scope.dietTab = index;
        $ionicSlideBoxDelegate.$getByHandle('slideDiet').slide(index);

        $ionicScrollDelegate.$getByHandle("scrollDiet").resize();
        $ionicScrollDelegate.$getByHandle("scrollDiet").scrollTop();
    }

    //#endregion

    // 显示目标设置模态窗口
    $scope.editGoalShow = function () {
        $scope.dietGoalModal.show();
    }

    // 隐藏目标设置模态窗口
    $scope.editGoalHide = function () {
        $scope.dietGoalModal.hide();
        $scope.getDietGoal();
    }

    // 目标设置保存
    $scope.saveGoal = function () {
        HealthService.setDietGoal($scope.vpId, $scope.dietGoal.CALORIES_GOAL).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.editGoalHide();
            }
        });
    }

    //#region 问卷信息
    // 读取问卷信息
    $scope.loadSrvyInfo = function () {
        $scope.srvyInfo = [];
        $scope.selfSrvyList = [];

        SrvyService.srvyInfo('DIET', $scope.vpId).then(function (data) {
            if (data.result == 1) {
                $scope.srvyInfo.push(data.data);
            }
            SrvyService.selfSrvyList('DIET', $scope.vpId).then(function (sData) {
                $scope.selfSrvyList = sData.data;
            });
        })
    }

    // 显示问卷填写信息
    $scope.showTmpl = function (tmplId, recId, available) {
        $scope.currentRec = recId;
        $scope.loadTmpl(tmplId);
    }

    // 加载模板信息
    $scope.loadTmpl = function (tmplId) {
        $scope.isLoadFinish_Tmpl = false;
        $ionicLoading.show();

        $scope.tmpl = new Object();

        if ($scope.tmplInfo.display == "SLIDE") {
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').update();
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').slide(0);
        }

        // 加载模板
        SrvyService.items(tmplId).then(function (data) {
            $scope.tmpl = data.QSTN_LIST;
            $scope.tmplInfo.name = data.TMPL_NAME;
            $scope.tmplInfo.id = data.TMPL_ID;
            $scope.tmplInfo.display = data.TMPL_DISPLAY;
            $scope.qstnCount = $scope.tmpl.length;

            $scope.isLoadFinish_Tmpl = true;

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();

            if ($scope.tmplInfo.display == "SLIDE") {
                $timeout(function () {
                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').enableSlide(false);

                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').update();
                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').slide(0);
                    $scope.cQstn = 0;

                    $ionicLoading.hide();
                }, 500);
            } else {
                $ionicLoading.hide();
            }
        })

        $scope.srvyList = [];
        $scope.srvyModal.show();
    }

    // 隐藏问卷填写信息
    $scope.hideTmpl = function () {
        $scope.srvyModal.hide();
    }

    // 保存问卷结果
    $scope.saveResult = function () {
        $ionicLoading.show();
        SrvyService.saveRecord($scope.tmplInfo.id, $scope.currentRec, $scope.vpId, $scope.srvyResult).then(function (data) {
            if (data.result == 1) {
                if (data.nTmplId != '') {
                    $scope.loadTmpl(data.nTmplId);
                } else {
                    $fwCordovaToast.showShortBottom("问卷填写完成！");

                    // 初始化题目信息（防止再次进入显示混乱）
                    $scope.tmpl = new Object();
                    $scope.tmplInfo = new Object();
                    $scope.qstnCount = 0;

                    $scope.hideTmpl();
                    $scope.showFeedback(data.recId);
                    $scope.loadSrvyInfo();
                }
            } else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            $ionicLoading.hide();
        });
    }

    // 显示反馈信息
    $scope.showFeedback = function (recId) {
        SrvyService.getFeedBack(recId).then(function (data) {
            $scope.tmpl = data.QSTN_LIST;
            $scope.srvyResult = data.REC_QSTN;
            $scope.fbResultList = data.FB_RESULT_LIST;
            $scope.fbCalcList = data.FB_CALC_LIST;

            $scope.fbResultCount = Object.getOwnPropertyNames($scope.fbResultList).length;

            $ionicScrollDelegate.$getByHandle("scrollFeedback").resize();
            $ionicScrollDelegate.$getByHandle("scrollFeedback").scrollTop();
            $scope.feebbackTab = 0;

            $ionicSlideBoxDelegate.$getByHandle('slideFeedback').enableSlide(false);

            $scope.feedbackModal.show();
        });
    }

    // 切换
    $scope.feedbackTabChange = function (index) {
        $scope.feebbackTab = index;
        $ionicSlideBoxDelegate.$getByHandle('slideFeedback').slide(index);

        $ionicScrollDelegate.$getByHandle("scrollFeedback").resize();
        $ionicScrollDelegate.$getByHandle("scrollFeedback").scrollTop();
    }

    // 隐藏反馈信息
    $scope.hideFeedback = function () {
        $scope.feedbackModal.hide();
        $scope.tmpl = new Object();
        $scope.srvyResult = new Object();
    }

    // 显示个人填写的问卷信息
    $scope.showTmplSelf = function (srvy) {
        if (srvy.SRVY_STATUS == 1) {
            $scope.showFeedback(srvy.REC_ID);
        } else {
            $scope.showTmpl(srvy.LAST_TMPL_ID, srvy.REC_ID, true);
        }
    }

    //#endregion

    //#region 食物选择

    // 添加食物
    $scope.addFood = function () {
        $scope.foodFilter.name = '';
        $scope.dietFoodModal.show();
        $scope.favoriteFood();
    }

    // 隐藏食物
    $scope.addFoodHide = function () {
        $scope.mealDiet = calcMeal($scope.mealDiet);
        $scope.dietFoodModal.hide();

        $scope.foodFilter.name = '';
        $scope.foodList = [];
    }

    // 查询食物
    $scope.searchFood = function () {
        HealthService.searchFood($scope.foodFilter.name).then(function (data) {
            $scope.foodList = data.data;
        });
    }

    // 清除选择
    $scope.clearFoodFilter = function () {
        $scope.foodFilter.name = '';
        $scope.foodList = [];
    }

    // 常用食物列表
    $scope.favoriteFood = function () {
        HealthService.favoriteFood($scope.vpId).then(function (data) {
            $scope.favoriteFoodList = data.data;
        });
    }

    // 选择食物
    $scope.checkFood = function (food) {
        var isInList = false;
        for (var i = 0; i < $scope.mealDiet.DETAIL.length; i++) {
            if ($scope.mealDiet.DETAIL[i].FOOD_ID == food.FOOD_ID) {
                isInList = true;
                break;
            }
        }
        if (isInList) {
            $fwCordovaToast.showShortBottom("食物已存在");
        } else {
            var mealDetail = new Object();
            mealDetail = calcFood(mealDetail, food, 100);
            $scope.mealDiet.DETAIL.push(mealDetail);
            $fwCordovaToast.showShortBottom("添加成功");
        }
    }

    //#endregion

    // 日期/时间选择器
    $scope.datePicker = function (target, type, value) {
        var defaultDate = new Date();

        if (value != undefined && value != null && value != '') {
            // 处理iOS日期格式
            if (currentPlatform == "iOS") {
                value = value.replace(/-/g, "/");
            }
            defaultDate = new Date(value);
        }
        var options = {
            mode: type,  	// 'date' or 'time' or 'datetime'
            date: defaultDate,
            okText: '确定',
            cancelText: '取消',
            doneButtonLabel: '确定',
            cancelButtonLabel: '取消',
            is24Hour: true,
            androidTheme: 3,
            locale: 'zh_cn',
            maxDate: $scope.lastDate
        };

        $cordovaDatePicker.show(options).then(function (date) {
            if (typeof (date) != 'undefined') {
                var resultDate = new Date(date)
                switch (target) {
                    case 'diet_date':
                        $scope.dietDate = resultDate.Format('yyyy-MM-dd');
                        $scope.loadDailyDiet();
                        break;
                    case 'meal_time':
                        $scope.mealDiet.MEAL_TIME = resultDate.Format('hh:mm');
                        break;
                }
            }
        });
    }

    // 计算食物
    function calcFood(mealDetail, food, amount) {
        if (mealDetail.FOOD_ID == undefined) {
            mealDetail = {
                FOOD_ID: food.FOOD_ID,
                FOOD_NAME: food.FOOD_NAME,
                FOOD_TYPE: food.FOOD_TYPE,
                FOOD_UNIT: food.FOOD_UNIT,
                FOOD_AMOUNT: amount,
                FOOD_INFO: food
            };
        }
        mealDetail.FOOD_CALORIES = Math.round((amount / food.UNIT_AMOUNT) * food.FOOD_CALORIES);

        if (food.FOOD_PROTEIN != null) {
            mealDetail.FOOD_PROTEIN = Math.round((amount / food.UNIT_AMOUNT) * food.FOOD_PROTEIN);
        } else {
            mealDetail.FOOD_PROTEIN = 0;
        }

        if (food.FOOD_CARBOHYDRATE != null) {
            mealDetail.FOOD_CARBOHYDRATE = Math.round((amount / food.UNIT_AMOUNT) * food.FOOD_CARBOHYDRATE);
        } else {
            mealDetail.FOOD_CARBOHYDRATE = 0;
        }

        if (food.FOOD_FAT != null) {
            mealDetail.FOOD_FAT = Math.round((amount / food.UNIT_AMOUNT) * food.FOOD_FAT);
        } else {
            mealDetail.FOOD_FAT = 0;
        }
        return mealDetail;
    }

    // 计算餐
    function calcMeal(meal) {
        var calories = 0;
        var protein = 0;
        var carbohydrate = 0;
        var fat = 0;

        for (var i = 0; i < meal.DETAIL.length; i++) {
            calories += meal.DETAIL[i].FOOD_CALORIES;
            protein += meal.DETAIL[i].FOOD_PROTEIN;
            carbohydrate += meal.DETAIL[i].FOOD_CARBOHYDRATE;
            fat += meal.DETAIL[i].FOOD_FAT;
        }

        meal.DIET_CALORIES = calories;
        meal.DIET_PROTEIN = protein;
        meal.DIET_CARBOHYDRATE = carbohydrate;
        meal.DIET_FAT = fat;

        return meal;
    }

    //#region 初始化变量
    function initDailyDiet() {
        $scope.dailyDiet = {
            DIET_CALORIES: 0,
            DIET_PROTEIN: 0,
            DIET_CARBOHYDRATE: 0,
            DIET_FAT: 0,
            MEAL_ID_1: null,
            MEAL_ID_2: null,
            MEAL_ID_3: null
        }
    }
    initDailyDiet();

    function initMealDiet(type, name) {
        $scope.mealDiet = {
            DIET_MEAL_ID: '',
            DIET_CALORIES: 0,
            DIET_PROTEIN: 0,
            DIET_CARBOHYDRATE: 0,
            DIET_FAT: 0,
            MEAL_TIME: '',
            DETAIL: []
        }
    }

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        $ionicSlideBoxDelegate.$getByHandle('slideDiet').enableSlide(false);
    });
    //#endregion

    //#region 就诊人那堆东西，粘贴来粘贴去的
    // 读取就诊人信息
    $scope.loadVPInfo = function () {
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
            }
        })
    }

    // 加载就诊人列表
    $scope.loadVpList = function () {
        // 就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                $scope.vpList = data.data;
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    }

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        $scope.vpList = [];
        // 获取就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                // 若无就诊人
                if (data.data.length == 0) {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("未找到绑定的就诊人信息");
                    return;
                }

                // 第一就诊人
                var vpid = "";
                for (var i = 0; i < data.data.length; i++) {
                    $scope.vpList.push(data.data[i]);
                    if (vpid == "") {
                        vpid = data.data[i].VISIT_PATIENT_ID;
                    }
                }

                // 若参数无就诊人信息
                if ($scope.vpId == "") {
                    // 默认第一就诊人
                    $scope.vpId = vpid;
                }

                $scope.loadVPInfo();
                $scope.loadDailyDiet();
                $scope.loadSrvyInfo();
                $scope.getDietGoal();
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    })

    // 显示弹出菜单
    $scope.openPopoverVpList = function ($event) {
        $scope.popVplist.show($event);
    }
    //#endregion

    $scope.goBack = function () {
        $state.go('app.health', { vpid: $scope.vpId, from: $stateParams.from });
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            if ($scope.step == 0) {
                if ($stateParams.from.length > 0) {
                    // 2022-4-8 16:21:28 hzg 随访->健康记录->diet饮食
                    $state.go('app.health', { vpid: $scope.vpId, from: $stateParams.from });
                } else {
                    $rootScope.goBack();
                }
            }
            else {
                $scope.goBack();
            }
            e.preventDefault();
            return false;
        }, 135, 'diet');
    })

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'diet') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    })
})