angular.module('fwapp.controllers')

// 急诊预存重置
.controller('EmrChargeController', function ($scope, $rootScope, $state, $stateParams, $timeout
, $fwCordovaToast, RequestService, PaymentService, VisitPatientService, $ionicModal
, $ionicPopup, $ionicSlideBoxDelegate, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $ionicActionSheet, $cordovaInAppBrowser) {

    // 检查登录状态
    $rootScope.checkLogin();

    // vpId
    $scope.vpId = $stateParams.vpid;

    // 就诊人信息
    $scope.vpInfo = {};

    // 定义预付费滑块
    var slideMoneylist = $ionicSlideBoxDelegate.$getByHandle('slideMoneylist');

    // 初始滑块状态
    $scope.step = 0;

    // 按医生数据
    $scope.paymentInfo = new Object();
    $scope.paymentInfo.customAmount = 'no'; // 预约科室
    $scope.paymentInfo.patient = '-1'; //选择的就诊人
    $scope.paymentInfo.amount = 500; //预存金额
    $scope.paymentInfo.prepaidType = "3"; // 1=门诊 2=住院 3=急诊

    // 订单号
    $scope.outTradeNoEmr = "";
    // 支付时间
    $scope.payDateTime = "";

    // 加载就诊人信息
    $scope.loadVPInfo = function () {
        $ionicLoading.show();
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
                $scope.paymentInfo.patient = '1';
            }
        })
    }

    // 切换预存金额
    $scope.changeMoney = function (money) {
        $scope.paymentInfo.amount = money;
        $scope.paymentInfo.customAmount = 'no';
    }
    // 自定义金额
    $scope.customAmount = function () {
        $scope.paymentInfo.customAmount = 'yes';
    }

    // 确认充值提交
    $scope.checkData = function () {
        //防止连击
        if (isFastClick()) {
            return;
        }

        if ($scope.paymentInfo.patient == '-1') {
            $fwCordovaToast.showShortBottom("请选择就诊人");
            return false;
        }
        if (isNaN($scope.paymentInfo.amount)) {
            // 先判断是否为合法的数字
            $fwCordovaToast.showShortBottom("请输入合法的金额");
            return false;
        }
        var dot = String($scope.paymentInfo.amount).indexOf(".");
        if (dot != -1) {
            var dotCnt = String($scope.paymentInfo.amount).substring(dot + 1, String($scope.paymentInfo.amount).length);
            if(dotCnt.length > 2) {
                $fwCordovaToast.showShortBottom("自定义金额仅支持到分");
                return false;
            }
        }

        // 再验证一下 是否急诊患者
        $ionicLoading.show();
        RequestService.getEmrPatientInfo($scope.vpInfo.VISIT_PATIENT_ID).then(function (data) {
            $ionicLoading.hide();
            // 请求错误
            if (data.result == 0 || data.result == -99) {
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            // 请求成功
            if (data.result == 1) {
                // 无就诊人
                if (data.is_null == 1 || data.data.length <= 0) {
                    $fwCordovaToast.showShortBottom("未找到患者的急诊记录");
                }
                // 急诊状态
                else {
                    $scope.cashier("emrCharge", $scope.paymentInfo.amount, $scope.vpInfo.VISIT_PATIENT_ID).then(function (dataCashier) {
                        if (dataCashier.code == 1) {
                            // 需要订单号
                            $scope.outTradeNoEmr = dataCashier.data.OUT_TRADE_NO;
                            // 需要支付时间
                            $scope.payDateTime = dataCashier.data.UNIFIED_ORDER_TIME;

                            $scope.toSlide(1);
                        }
                        else {
                            $fwCordovaToast.showShortBottom("充值失败，请重试。");
                        }
                    })
                }
            }
        });
    }

    // 返回
    $scope.goBack = function () {
        if ($scope.step == 1){
            $scope.toSlide(0);
        }
        else {
            $state.go("app.dealWithCard", { go: "emrCharge" });
        }
    }

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        slideMoneylist.enableSlide(false);
    });

    // 滑到上一步
    $scope.lastSlide = function () {
        slideMoneylist.previous();
        $scope.step = slideMoneylist.currentIndex();
    }
    // 滑到下一步
    $scope.nextSlide = function () {
        slideMoneylist.next();
        $scope.step = slideMoneylist.currentIndex();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        slideMoneylist.slide(index);
        $scope.step = slideMoneylist.currentIndex();
        // 进入预约列表 重新计算高度
        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 获取就诊人
        $scope.loadVPInfo();
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'emrCharge');
    });

    // 页面离开
    $scope.$on('$ionicView.beforeLeave', function () {
        // 解除返回键绑定
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'emrCharge') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });

})