﻿angular.module('fwapp.controllers')

.controller('ExamExplainReportSatisController', function ($scope, $rootScope, $state, $stateParams, $interval, $timeout, $http
, $ionicPopup, $ionicPlatform, $ionicLoading, $fwCordovaToast
, SatisService) {

    if (localStorage.currentAccountId.length == 0) {
        $state.go("login");
        return;
    }

    // 视频诊疗ID
    $scope.treatApplyId = $stateParams.treatApplyId;
    // 满意度选择题选项键值对
    $scope.levels = [];
    // 满意度所有题目
    $scope.explainReportList = [];
    // 是否已填写过
    $scope.isSatisFinished = 0;
    // 加载
    $scope.isLoadFinished = false;

    // 检查满意度是否已填写过
    $scope.checkIsSatisFinished = function () {
        SatisService.checkIsSatisFinished($scope.treatApplyId).then(function (data) {
            $ionicLoading.hide();
            $scope.isLoadFinished = true;
            if (data.result == 1) {
                $ionicLoading.show();
                $scope.getSatisWord();
            } else if (data.result == 2) {
                $scope.isSatisFinished = 1;
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
        }, function (err) {
            $ionicLoading.hide();
            var alertPopup = $ionicPopup.alert({
                title: '提示',
                template: '获取体检报告解读满意度详情错误，请稍后再试',
                okText: "确定"
            });
        })
    }

    // 获取问卷题目
    $scope.getSatisWord = function () {
        SatisService.showExplainReportSatis().then(function (data) {
            $ionicLoading.hide();
            if (data.result == 1) {
                $scope.levels = data.dicList;
                $scope.explainReportList = data.data;
            } else {
                var alertPopup = $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
        }, function (err) {
            $ionicLoading.hide();
            var alertPopup = $ionicPopup.alert({
                title: '提示',
                template: '获取体检报告解读满意度调查错误',
                okText: "确定"
            });
        })
    }

    // 满意度选择题
    $scope.selectThis = function (index, value) {
        $scope.explainReportList[index]["QUESTION_ANSWER"] = value;
    }

    // 满意度问卷提交
    $scope.submitExplainReportSatis = function () {
        $ionicLoading.show();
        for (var i = 0; i < $scope.explainReportList.length; i++) {
            if ($scope.explainReportList[i]["QUESTION_ANSWER"] == "" || $scope.explainReportList[i]["QUESTION_ANSWER"] == undefined || $scope.explainReportList[i]["QUESTION_ANSWER"].length == 0) {
                $ionicLoading.hide();
                var alertPopup = $ionicPopup.alert({
                    title: '提示',
                    template: '请完成满意度问卷题目',
                    okText: "确定"
                });
                return;
            }
        }
        var jsonSubmit = JSON.stringify($scope.explainReportList);
        SatisService.submitExplainReportSatis(jsonSubmit, $scope.treatApplyId).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 1) {
                $fwCordovaToast.showShortBottom("体检报告解读满意度问卷填写成功");
                $rootScope.goBack();
            } else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        }, function (err) {
            $ionicLoading.hide();
            var alertPopup = $ionicPopup.alert({
                title: '提示',
                template: '提交体检报告解读满意度调查失败，请稍后再试',
                okText: "确定"
            });
        })
    }


    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        $ionicPlatform.registerBackButtonAction(function (e) {
            $rootScope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'examExplainReportSatis');
        $ionicLoading.show();
        $scope.checkIsSatisFinished();
    });

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'examExplainReportSatis') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
});