﻿angular.module('fwapp.controllers')

.controller('flupSrvyController', function ($scope, $rootScope, $state, $stateParams, $timeout,
    flupSrvyService, SrvyService, $ionicSlideBoxDelegate, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $ionicPopup, $ionicActionSheet, $ionicModal, $ionicPopover,
    $cordovaDatePicker, $fwCordovaToast) {

    // 图片服务器路径
    $scope.imgServerUrl = uploadUrl;

    // 专病随访滑动
    $scope.step = 0;
    var slideFlupList = $ionicSlideBoxDelegate.$getByHandle('slideFlupList');

    // 激活的随访患者index
    $scope.activeTask = 0;
    // 激活的患者的index
    $scope.patientIndex = 0;

    // 就诊人ID
    $scope.vpId = '';
    // 随访任务ID
    $scope.taskId = '';
    // 随访任务
    $scope.flupList = [];
    // 随访任务信息
    $scope.flupInfo = new Object();
    // 随访记录列表
    $scope.flupRecList = new Object();
    // 随访患者ID
    $scope.patientId = '';
    // 在线问诊医师列表
    $scope.doctorList = [];

    // 模板内容
    $scope.tmpl = new Object();
    // 模板信息
    $scope.tmplInfo = new Object();
    // 总题数
    $scope.qstnCount = 0;
    // 问卷结果
    $scope.srvyResult = new Object();
    // 当前问卷ID
    $scope.currentRec = new Object();
    // 反馈列表(评价)
    $scope.fbResultList = new Object();
    // 反馈列表(评分)
    $scope.fbCalcList = new Object();
    // 反馈TAB页
    $scope.feebbackTab = 0;
    // 问卷ID
    $scope.tmplId = '';
    // 问卷记录id
    $scope.recId = '';
    // 医师反馈内容
    $scope.manualFeedback = '';

    // #region 模态框口
    // 随访问卷
    $ionicModal.fromTemplateUrl('templates/srvyTmpl.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.srvyModal = modal;
    });
    // 建议反馈
    $ionicModal.fromTemplateUrl('templates/feedback.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.feedbackModal = modal;
    });
    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.srvyModal.remove();
        $scope.feedbackModal.remove();
    })
    // #endregion

    // #region 滑动方法
    // 滑到上一步
    $scope.lastSlide = function () {
        slideFlupList.previous();
        $scope.step = slideFlupList.currentIndex();
    }
    // 滑到下一步
    $scope.nextSlide = function () {
        slideFlupList.next();
        $scope.step = slideFlupList.currentIndex();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        slideFlupList.slide(index);
        $scope.step = slideFlupList.currentIndex();
    }
    // 页面切换
    $scope.slideChanged = function () {
        $ionicScrollDelegate.resize();
        $ionicScrollDelegate.scrollTop();
    }
    // 随访患者slide切换
    $scope.patientSlideChanged = function () {
        var index = $ionicSlideBoxDelegate.$getByHandle('flupPatientList').currentIndex();
        $scope.calcSlideHeight(index);
        $scope.patientIndex = $ionicSlideBoxDelegate.$getByHandle('flupPatientList').currentIndex();
        $scope.flupInfo = $scope.flupList[index];
        $scope.vpId = $scope.flupList[index].VISIT_PATIENT_ID; // APP患者ID
        $scope.patientId = $scope.flupList[index].PATIENT_ID; // 随访患者ID
        // 切换健康宣教
        $scope.changeArticleList();
    }
    // #endregion

    // 日期展示统一为：yyyy年mm月dd日
    $scope.dateFormat = function (date) {
        var arr = [];
        if (date.length > 10) {
            date = date.substring(0, 10);
        }
        if (date.indexOf("-") > 0) {
            arr = date.split("-");
        }
        if (date.indexOf(".") > 0) {
            arr = date.split(".");
        }
        return parseFloat(arr[0]) + "年" + parseFloat(arr[1]) + "月" + parseFloat(arr[2]) + "日";
    }

    // 重新计算slide高度，防止slide空白
    $scope.calcSlideHeight = function (index) {
        $timeout(function () {
            if ($scope.flupList.length > 1) {
                var dom = document.querySelectorAll('.flupPatientSlide .slider-slide')[index];
                var domHeight = dom.getBoundingClientRect().bottom - dom.getBoundingClientRect().top;
                $scope.customHeight = {
                    'height': domHeight + 'px'
                }
            }
            slideFlupList.update();
            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();
        }, 100);
    }

    //#region 随访相关
    // 是否同意加入专病随访
    $scope.confirmAgree = function (PATIENT_ID, isJoinFlup) {
        flupSrvyService.joinFlup(PATIENT_ID, isJoinFlup).then(function (data) {
            if (data.result != 1) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                for (var i = 0; i < $scope.flupList.length; i++) {
                    if ($scope.flupList[i].PATIENT_ID == PATIENT_ID) {
                        $scope.flupList[i].NOTICE = '';
                        $scope.calcSlideHeight(i);
                    }
                }
            }
        }, function () {
            $fwCordovaToast.showShortBottom("网络连接异常，请重试");
        });
        return true;
    }

    // 读取随访任务
    $scope.loadSrvyInfo = function () {
        $scope.flupList = [];
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        flupSrvyService.getFlupPatient().then(function (data) {
            if (data.result != 1) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.flupList = data.data;
                if (data.data.length > 0) {
                    if ($stateParams.vpId != '') {
                        for (var i = 0; i < data.data.length; i++) {
                            if (data.data[i].VISIT_PATIENT_ID == $stateParams.vpId) {
                                $scope.activeTask = i;
                            }
                        }
                    }
                    // 展示随访患者信息
                    $scope.flupInfo = data.data[$scope.activeTask];
                    $scope.vpId = data.data[$scope.activeTask].VISIT_PATIENT_ID;
                    $scope.patientId = data.data[$scope.activeTask].PATIENT_ID;

                    // 在线问诊医师列表
                    $scope.doctorList = data.doctorList;

                    // 更新页面
                    if (data.data.length > 1) {
                        $scope.calcSlideHeight($scope.activeTask);
                    }
                }
            }
            $scope.isLoadFinish = true;
            $ionicLoading.hide();
        }, function () {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络连接异常，请重试");
        });
    }

    // 进入随访记录
    $scope.flupRecord = function (PATIENT_ID) {
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        flupSrvyService.srvyRecordList(PATIENT_ID).then(function (data) {
            if (data.result != 1) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.flupRecList = data.data;
            }
            $scope.isLoadFinish = true;
            $ionicLoading.hide();
        }, function () {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络连接异常，请重试");
        });
        $scope.toSlide(1);
    }

    // 填写问卷
    $scope.showTmpl = function (tmplId, taskId, recId) {
        $scope.taskId = taskId;
        $scope.currentRec = recId;
        $scope.loadTmpl(tmplId);
    }

    // 加载模板信息
    $scope.loadTmpl = function (tmplId) {
        $scope.isLoadFinish_Tmpl = false;
        $ionicLoading.show();

        $scope.tmpl = new Object();
        var resultList = new Object();
        if ($scope.currentRec) {
            var keys = Object.keys($scope.srvyResult);
            for (var i = 0; i < keys.length; i++) {
                if (keys[i].indexOf('_UNIT') < 0) {
                    resultList[keys[i]] = $scope.srvyResult[keys[i]];
                }
            }
            $scope.feedbackModal.hide();
        }
        $scope.srvyResult = resultList;

        if ($scope.tmplInfo.display == "SLIDE") {
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').update();
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').slide(0);
        }

        // 加载模板
        SrvyService.items(tmplId).then(function (data) {
            $scope.tmpl = data.QSTN_LIST;
            $scope.tmplInfo.name = data.TMPL_NAME;
            $scope.tmplInfo.id = data.TMPL_ID;
            $scope.tmplInfo.display = data.TMPL_DISPLAY;
            $scope.qstnCount = $scope.tmpl.length;

            $scope.isLoadFinish_Tmpl = true;

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();

            if ($scope.tmplInfo.display == "SLIDE") {
                $timeout(function () {
                    $scope.$broadcast('slideTmplList.init');
                    $ionicLoading.hide();
                }, 300);
            } else {
                $ionicLoading.hide();
            }
        })

        $scope.srvyList = [];
        $scope.srvyModal.show();
    }

    // 隐藏问卷填写信息
    $scope.hideTmpl = function () {
        $scope.srvyModal.hide();
    }

    // 保存问卷结果
    $scope.saveResult = function () {
        $ionicPopup.confirm({
            title: '提交确认',
            template: '您已完成填写，请确认是否提交?',
            cancelText: '取消',
            okText: '确认'
        }).then(function (res) {
            if (res) {
                $ionicLoading.show();
                flupSrvyService.saveRecord($scope.tmplInfo.id, $scope.currentRec, $scope.vpId, $scope.taskId, $scope.patientId, $scope.srvyResult).then(function (data) {
                    if (data.result == 1) {
                        if (data.nTmplId != '') {
                            $scope.loadTmpl(data.nTmplId);
                        } else {
                            $scope.initTmpl();
                            $scope.showFeedback(data.recId);
                            if ($scope.taskId != '') {
                                $scope.loadSrvyInfo();
                            }
                        }
                    } else {
                        $fwCordovaToast.showShortBottom(data.msg);
                    }
                    $ionicLoading.hide();
                });
            }
        });
    }

    // 初始化题目信息（防止再次进入显示混乱）
    $scope.initTmpl = function () {
        $fwCordovaToast.showShortBottom("问卷填写完成！");
        $scope.tmpl = new Object();
        $scope.tmplInfo = new Object();
        $scope.qstnCount = 0;
        $scope.tmplId = '';
        $scope.recId = '';
        $scope.hideTmpl();
    }

    // 显示反馈信息
    $scope.showFeedback = function (recId) {
        $ionicLoading.show();
        SrvyService.getFeedBack(recId).then(function (data) {
            $scope.feebbackTab = 0;
            $scope.tmplId = data.TMPL_ID;
            $scope.manualFeedback = data.MANUAL_FEEDBACK;
            $scope.fbResultList = data.FB_RESULT_LIST;
            $scope.fbCalcList = data.FB_CALC_LIST;
            $scope.fbResultCount = Object.getOwnPropertyNames($scope.fbResultList).length;
            $scope.tmpl = data.QSTN_LIST;
            $scope.srvyResult = data.REC_QSTN;
            $scope.recId = recId;

            $scope.feedbackModal.show();
            $ionicSlideBoxDelegate.$getByHandle('slideFeedback').enableSlide(false);
            $scope.feedbackTabChange(0);
            $ionicLoading.hide();
        }, function () {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络连接异常，请重试");
        });
    }

    // 切换
    $scope.feedbackTabChange = function (index) {
        $scope.feebbackTab = index;
        $ionicSlideBoxDelegate.$getByHandle('slideFeedback').slide(index);
        $ionicSlideBoxDelegate.$getByHandle('slideFeedback').update();
        $ionicScrollDelegate.$getByHandle("scrollFeedback").resize();
        $ionicScrollDelegate.$getByHandle("scrollFeedback").scrollTop();
    }

    // 隐藏反馈信息
    $scope.hideFeedback = function () {
        $scope.feedbackModal.hide();
        $scope.tmpl = new Object();
        $scope.srvyResult = new Object();
        // 更新问卷记录列表
        $scope.flupRecord($scope.patientId);
        $scope.manualFeedback = '';
    }
    //#endregion


    // #region 健康记录 健康宣教
    // 健康记录跳转
    $scope.goHealth = function (HLTH_NAME) {
        var tileHrefSrvy = '';
        switch (HLTH_NAME) {
            case '':
                // 2022-4-8 16:12:26 hzg 直接跳转到健康记录模块
                $state.go("app.health", { vpid: $scope.vpId, from: "app.flupSrvy" });
                // $scope.toSlide(2);
                break;
            case '血压':
            case '心率':
            case '血糖':
            case '身高体重':
            case '特殊事件':
                $state.go("app.health", { vpid: $scope.vpId, from: "app.flupSrvy", titleName: HLTH_NAME });
                break;
            case '饮食':
                $state.go('app.diet', { vpid: $scope.vpId, from: "app.flupSrvy" });
                break;
            case '吸烟':
                tileHrefSrvy = 'FAGERSTORM';
            case '运动':
                tileHrefSrvy = 'IPAQ';
            case '睡眠':
                tileHrefSrvy = 'PSQI';
            case '焦虑':
                tileHrefSrvy = 'SAS';
                $state.go('app.srvy', { vpid: $scope.vpId, type: tileHrefSrvy, from: "app.flupSrvy" });
                break;
            case '风险预测':
                $state.go('app.cvdriskList', { vpId: $scope.vpId, from: "app.flupSrvy" });
                break;
        }
    }

    $scope.changeArticleList = function () {

    }
    //#endregion

    // 进入在线问诊
    $scope.goConsultation = function (doctorCode) {
        $state.go("app.consultation", { vpid: $scope.flupInfo.VISIT_PATIENT_ID, from: "app.flupSrvy", doctorCode: doctorCode });
    }

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        // 加载随访任务
        $scope.loadSrvyInfo();
    })

    // 后退
    $scope.goBack = function () {
        if ($scope.step > 0) {
            $scope.toSlide(0);
            for (var i = 0; i < $scope.flupList.length; i++) {
                if ($scope.patientId == $scope.flupList[i].PATIENT_ID) {
                    $scope.activeTask = i;
                }
            }
        } else {
            $state.go('app.home');
        }
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'flupSrvy');
    })

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        slideFlupList.enableSlide(false);
    })

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'flupSrvy') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    })
});