﻿angular.module('fwapp.controllers')

// 医院介绍
.controller('HospitalController', function ($scope, $rootScope, $state, HospitalService, $ionicPlatform, $ionicLoading, $ionicPopup, $ionicModal, $ionicScrollDelegate, $cordovaGeolocation, $fwCordovaToast) {
    $scope.description = "加载中……";
    $scope.location = "加载中……";

    // 地图实例
    $scope.map = {}
    $scope.mapSearch = {}
    // 地图模式
    $scope.mapMode = 'map';
    // 上一次地图模式
    $scope.mapLastMode = $scope.mapMode;
    // GCJ坐标
    $scope.locationGCJ = { lng: 0, lat: 0 };
    // 医院中心
    $scope.locationFWCenter = { lng: 116.351256, lat: 39.925325 };
    // 医院门诊
    $scope.locationFWOutpatient = { lng: 116.34998, lat: 39.925289 };
    // 医院停车场
    $scope.locationFWParking = { lng: 116.349711, lat: 39.925087 };
    // 天安门(测试用)
    $scope.locationTAM = { lng: 116.39732405, lat: 39.90874581 };
    // 天津之眼(测试用)
    $scope.locationTJZY = { lng: 117.18631, lat: 39.154161 };
    // 导航实例
    $scope.pathPlan = {};
    $scope.pathPlan.driving = {};
    $scope.pathPlan.transfer = {};
    $scope.pathPlan.riding = {};
    $scope.pathPlan.walking = {};
    // 地图总高度
    $scope.mapTotalHeight = $(window).height() - ($rootScope.currentPlatform == "iOS" ? 108 : 88);
    // 起点
    $scope.startPoint = {};
    $scope.startPoint.keyword = "";
    $scope.startPoint.name = "";
    $scope.startPoint.location = { lng: 0, lat: 0 };
    // 搜索
    $scope.mapSearcData = {};
    $scope.mapSearcData.province = "";
    $scope.mapSearcData.city = "";
    $scope.mapSearcData.provinceList = {};
    $scope.mapSearcData.cityList = {};

    // 注册模态窗口 来院导航
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('map.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.amapModal = modal;
    });
    // 注册模态窗口 搜索起点
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('mapSearch.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.amapSearchModal = modal;
    });
    $scope.$on('$destroy', function () {
        $scope.amapModal.remove();
        $scope.amapSearchModal.remove();
    })

    // 弹出来院导航
    $scope.amapShow = function () {
        $scope.mapMode = 'map';
        $scope.mapLastMode = $scope.mapMode;
        $scope.startPoint.keyword = "我的位置";
        $scope.startPoint.name = "我的位置";
        $scope.amapModal.show();
        // 初始化地图
        $scope.initMap();
    }

    // 初始化地图
    $scope.initMap = function () {
        if (typeof (AMap) == "undefined") {
            return false;
        }
        $ionicLoading.show();
        // 初始化地图
        $scope.map = new AMap.Map('aMapContainer', {
            resizeEnable: true,
            zoom: 15,
            center: [$scope.locationFWCenter.lng, $scope.locationFWCenter.lat]
        });
        // 工具栏
        $scope.map.plugin(["AMap.ToolBar"], function () {
            var toolBar = new AMap.ToolBar({
                locate: true// 定位按钮
                //autoPosition: true// 自动定位
            });
            $scope.map.addControl(toolBar);
        });
        // 比例尺
        $scope.map.plugin(["AMap.Scale"], function () {
            var scale = new AMap.Scale();
            $scope.map.addControl(scale);
        });
        // 医院标记点
        var marker = new AMap.Marker({
            icon: "lib/amap/mark_r.png",
            position: [$scope.locationFWCenter.lng, $scope.locationFWCenter.lat]
        });
        marker.setMap($scope.map);
        $ionicLoading.hide();
    }

    // 切换地图模式
    $scope.changeMapMode = function (mapMode) {
        if ($scope.mapLastMode == mapMode) {
            return;
        }
        $scope.mapMode = mapMode;
        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();
        // 上次和本次都是导航
        if ($scope.mapLastMode != "map" && mapMode != "map") {
            // 清除所有导航结果
            for (var i in $scope.pathPlan) {
                if ($scope.pathPlan[i].clear) {
                    $scope.pathPlan[i].clear();
                }
            }
        }
        // 上次是地图 这次是导航 或 上次是导航 这次是地图
        else if (typeof (AMap) != "undefined") {
            // 销毁地图重新初始化 ps:iOS不触发resize事件
            $scope.map.destroy();
            $("#aMapContainer").css("height", mapMode == "map" ? ($scope.mapTotalHeight + "px") : "61.8vw");
            $scope.initMap();
            console.log('地图大小变为：' + $scope.map.getSize().width + "*" + $scope.map.getSize().height);
        }
        $scope.mapLastMode = mapMode;
        if (mapMode != "map") {
            if ($scope.startPoint.name == "我的位置") {
                // 根据定位导航
                $scope.getLocation(mapMode);
            }
            else {
                // 从起点开始导航
                $scope.planPath(mapMode, $scope.startPoint.location);
            }
        }
    }

    // 获取定位信息
    $scope.getLocation = function (mapMode) {
        if (window.cordova && $cordovaGeolocation) {
            $ionicLoading.show();
            // 插件定位
            console.log('定位开始');
            $cordovaGeolocation.getCurrentPosition({
                enableHighAccuracy: true, // 高精度
                timeout: 5000, // 超时时间
                maximumAge: 10000// 缓存有效时间
            }).then(function (position) {
                console.log('定位成功');
                console.log('WGS坐标：' + position.coords.longitude + ', ' + position.coords.latitude);
                // 高德坐标转换 WGS -> GCJ
                AMap.convertFrom(new AMap.LngLat(position.coords.longitude, position.coords.latitude), 'gps', function (status, result) {
                    if (status == 'complete' && result.info == 'ok') {
                        console.log('坐标转换成功');
                        $scope.locationGCJ.lng = result.locations[0].lng;
                        $scope.locationGCJ.lat = result.locations[0].lat;
                        // 天安门坐标（测试用）
                        //$scope.locationGCJ.lng = $scope.locationTAM.lng;
                        //$scope.locationGCJ.lat = $scope.locationTAM.lat;
                        console.log('GCJ坐标：' + $scope.locationGCJ.lng + ', ' + $scope.locationGCJ.lat);
                        // 赋值给起点位置
                        $scope.startPoint.location.lng = $scope.locationGCJ.lng;
                        $scope.startPoint.location.lat = $scope.locationGCJ.lat;
                        // 2024-03-21 18:31:00 CGZ #hzfwx-813 如果是dev，不规划路径，判断当前坐标是否支持远程签到，弹窗显示坐标信息及结果
                        if (mapMode == 'dev') {
                            // 获取远程签到范围坐标
                            HospitalService.getRemoteCheckInRange().then(function (data) {
                                $ionicLoading.hide();
                                if (data.result == 1) {
                                    var locationRange = data.data;
                                    console.log('远程签到范围：' + 'N: ' + locationRange.N + ', S: ' + locationRange.S + ', W: ' + locationRange.W + ', E: ' + locationRange.E);
                                    // 判断当前坐标是否在远程签到范围内
                                    var inRange = false;
                                    if (position.coords.longitude >= locationRange.W && position.coords.longitude <= locationRange.E
                                        && position.coords.latitude >= locationRange.S && position.coords.latitude <= locationRange.N) {
                                        inRange = true;
                                    }
                                    var alertPopup = $ionicPopup.alert({
                                        title: '定位成功',
                                        template: 'WGS坐标：' + position.coords.longitude + ', ' + position.coords.latitude + '<br/>' + 'GCJ坐标：' + $scope.locationGCJ.lng + ', ' + $scope.locationGCJ.lat + '<br/>' + '是否在远程签到范围内：' + inRange,
                                        okText: '确定'
                                    });
                                }
                                else {
                                    $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
                                }
                            }, function (data) {
                                $ionicLoading.hide();
                                $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
                            });
                        }
                        else {
                            // 规划路径
                            $scope.planPath(mapMode, $scope.startPoint.location);
                            $ionicLoading.hide();
                        }
                    }
                    else {
                        console.log('坐标转换失败');
                        console.log(status);
                        console.log(result);
                        $fwCordovaToast.showShortBottom('坐标转换失败，请稍后再试');
                        $ionicLoading.hide();
                    }
                });
            }, function (error) {
                console.log('定位失败');
                console.log(error);
                $fwCordovaToast.showShortBottom('定位失败，请开启定位权限后再试');
                $ionicLoading.hide();
            });
        }
    }

    // 导航
    $scope.planPath = function (mapMode, locationStart) {
        // 驾车
        if (mapMode == "driving") {
            $scope.planDriving(locationStart, $scope.locationFWParking);
        }
        // 公交
        else if (mapMode == "transfer") {
            $scope.planTransfer(locationStart, $scope.locationFWOutpatient);
        }
        // 骑行
        else if (mapMode == "riding") {
            $scope.planRiding(locationStart, $scope.locationFWOutpatient);
        }
        // 步行
        else if (mapMode == "walking") {
            $scope.planWalking(locationStart, $scope.locationFWOutpatient);
        }
        else {
            console.log('导航方式错误');
        }
    }

    // 驾车导航
    $scope.planDriving = function (start, end) {
        $ionicLoading.show();
        console.log('规划驾车路线开始');
        AMap.plugin(["AMap.Driving"], function () {
            $scope.pathPlan.driving = new AMap.Driving({
                map: $scope.map,
                panel: "aMapPanel_driving"
            });
            //根据起终点坐标规划路线
            $scope.pathPlan.driving.search(new AMap.LngLat(start.lng, start.lat), new AMap.LngLat(end.lng, end.lat), function (status, result) {
                if (status == 'complete') {
                    console.log('规划驾车路线成功');
                    //console.log(result);
                    //$scope.map.panBy
                }
                else {
                    console.log('规划驾车路线失败');
                    console.log(status);
                    console.log(result);
                    $fwCordovaToast.showShortBottom('规划驾车路线失败，请稍后再试');
                }
                $ionicLoading.hide();
            });

        });
    }

    // 公交导航
    $scope.planTransfer = function (start, end) {
        $ionicLoading.show();
        console.log('计算起点所在城市开始');
        AMap.plugin(["AMap.Geocoder"], function () {
            var geocoder = new AMap.Geocoder();
            geocoder.getAddress(new AMap.LngLat(start.lng, start.lat), function (status, result) {
                // TODO:  && result.info === 'OK'
                if (status == 'complete') {
                    console.log('计算起点所在城市成功');
                    console.log('起点为：' + result.regeocode.addressComponent.province + ',' + result.regeocode.addressComponent.city + ',' + result.regeocode.addressComponent.citycode + ',' + result.regeocode.addressComponent.adcode);
                    console.log('规划公交路线开始');
                    AMap.plugin(["AMap.Transfer"], function () {
                        $scope.pathPlan.transfer = new AMap.Transfer({
                            map: $scope.map,
                            panel: "aMapPanel_transfer",
                            city: result.regeocode.addressComponent.citycode,
                            cityd: "010"
                        });
                        //根据起终点坐标规划路线
                        $scope.pathPlan.transfer.search(new AMap.LngLat(start.lng, start.lat), new AMap.LngLat(end.lng, end.lat), function (status, result) {
                            if (status == 'complete') {
                                console.log('规划公交路线成功');
                                //console.log(result);
                            }
                            else {
                                console.log('规划公交路线失败');
                                console.log(status);
                                console.log(result);
                                $fwCordovaToast.showShortBottom('规划公交路线失败，请稍后再试');
                            }
                        });

                    });
                }
                else {
                    console.log('计算起点所在城市失败');
                    console.log(status);
                    console.log(result);
                    $fwCordovaToast.showShortBottom('计算起点所在城市失败，请稍后再试');
                }
                $ionicLoading.hide();
            });
        });
    }

    // 骑行导航
    $scope.planRiding = function (start, end) {
        $ionicLoading.show();
        console.log('规划骑行路线开始');
        AMap.plugin(["AMap.Riding"], function () {
            $scope.pathPlan.riding = new AMap.Riding({
                map: $scope.map,
                panel: "aMapPanel_riding"
            });
            //根据起终点坐标规划路线
            $scope.pathPlan.riding.search(new AMap.LngLat(start.lng, start.lat), new AMap.LngLat(end.lng, end.lat), function (status, result) {
                if (status == 'complete') {
                    console.log('规划骑行路线成功');
                    //console.log(result);
                }
                else {
                    console.log('规划骑行路线失败');
                    console.log(status);
                    console.log(result);
                    $fwCordovaToast.showShortBottom('规划骑行路线失败，请稍后再试');
                }
                $ionicLoading.hide();
            });

        });
    }

    // 步行导航
    $scope.planWalking = function (start, end) {
        $ionicLoading.show();
        console.log('规划步行路线开始');
        AMap.plugin(["AMap.Walking"], function () {
            $scope.pathPlan.walking = new AMap.Walking({
                map: $scope.map,
                panel: "aMapPanel_walking"
            });
            //根据起终点坐标规划路线
            $scope.pathPlan.walking.search(new AMap.LngLat(start.lng, start.lat), new AMap.LngLat(end.lng, end.lat), function (status, result) {
                if (status == 'complete') {
                    console.log('规划步行路线成功');
                    //console.log(result);
                }
                else {
                    console.log('规划步行路线失败');
                    console.log(status);
                    console.log(result);
                    $fwCordovaToast.showShortBottom('规划步行路线失败，请稍后再试');
                }
                $ionicLoading.hide();
            });

        });
    }

    // 隐藏来院导航
    $scope.amapHide = function () {
        $("#aMapContainer").css("height", $scope.mapTotalHeight + "px");
        $scope.amapModal.hide();
        $scope.mapLastMode = 'map';
        $scope.map.destroy();
    }

    // 弹出起点搜索
    $scope.amapSearchShow = function () {
        //$scope.mapSearcData = {};
        $ionicLoading.show();
        $scope.amapSearchModal.show();
        if ($scope.mapSearch._amap_id) {
            console.log("搜索地图已初始化，id: " + $scope.mapSearch._amap_id);
            $scope.searchStart();
        }
        else {
            console.log("搜索地图未初始化");
            $scope.initMapSearch();
        }
    }

    // 初始化起点搜索地图
    $scope.initMapSearch = function () {
        if (typeof (AMap) == "undefined") {
            $ionicLoading.hide();
            return false;
        }
        // 初始化地图
        $scope.mapSearch = new AMap.Map('aMapSearchContainer', {
            resizeEnable: true,
            zoom: 10,
            center: [$scope.locationTAM.lng, $scope.locationTAM.lat]
        });
        // 工具栏
        $scope.mapSearch.plugin(["AMap.ToolBar"], function () {
            var toolBar = new AMap.ToolBar({
                locate: true// 定位按钮
                //autoPosition: true// 自动定位
            });
            $scope.mapSearch.addControl(toolBar);
        });
        // 比例尺
        $scope.mapSearch.plugin(["AMap.Scale"], function () {
            var scale = new AMap.Scale();
            $scope.mapSearch.addControl(scale);
        });
        // 省市搜索
        AMap.service('AMap.DistrictSearch', function () {
            //实例化DistrictSearch
            $scope.mapSearch.districtSearch = new AMap.DistrictSearch({
                level: 'country',
                subdistrict: 1,
                showbiz: false
            });
            // 获取全国省份列表
            $scope.mapSearch.districtSearch.search(100000, function (status, result) {
                console.log(status);
                console.log(JSON.stringify(result));
                if (status == "complete" && result.info == "OK") {
                    // 2019-5-6 11:04:14 高德返回数据加了个外国 增加筛选 中国 adcode=='100000'
                    var dataChina = result.districtList.filter(e => e.adcode == '100000');
                    if (dataChina.length > 0 && dataChina[0].districtList) {
                        $scope.mapSearcData.provinceList = dataChina[0].districtList;
                    } 
                    //$scope.mapSearcData.provinceList = result.districtList[0].districtList;
                    //$scope.mapSearcData.cityList = {};
                }
                $ionicLoading.hide();
            })
        }, function (error) {
            $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
            $ionicLoading.hide();
        })
        // 搜索地点
        $scope.mapSearch.plugin(["AMap.PlaceSearch"], function () {
            $scope.mapSearch.placeSearch = new AMap.PlaceSearch({
                pageSize: 20,
                pageIndex: 1
            });
        });
        // 搜索结果
        $scope.mapSearch.placeSearchRender = new Lib.AMap.PlaceSearchRender();
    }

    // 搜索所属城市
    $scope.searchCity = function () {
        // 清空原城市列表
        $scope.mapSearcData.city = "";
        $scope.mapSearcData.cityList.length = 0;
        // 设置地图中心
        $scope.mapSearch.setCenter($scope.mapSearcData.provinceList[$scope.mapSearcData.province].center)
        // 搜索当前省份所属城市
        $scope.mapSearch.districtSearch.setLevel("province");
        $scope.mapSearch.districtSearch.search($scope.mapSearcData.provinceList[$scope.mapSearcData.province].adcode, function (status, result) {
            console.log(status);
            console.log(JSON.stringify(result.districtList[0].districtList));
            if (status == "complete" && result.info == "OK") {
                $scope.$apply($scope.mapSearcData.cityList = result.districtList[0].districtList);
                //$scope.mapSearcData.cityList = {};
            }
        })
        // 在当前省份搜索
        $scope.searchStart();
    }

    // 选择城市
    $scope.selectCity = function () {
        console.log(JSON.stringify($scope.mapSearcData.cityList[$scope.mapSearcData.city]));
        // 设置地图中心
        $scope.mapSearch.setCenter($scope.mapSearcData.cityList[$scope.mapSearcData.city].center)
        // 在当前城市搜索
        $scope.searchStart();
    }

    // 清空关键词
    $scope.clearKeyword = function () {
        if ($scope.startPoint.keyword == "我的位置") {
            $scope.startPoint.keyword = "";
        }
    }

    // 搜索地点
    $scope.searchStart = function () {
        if (typeof (AMap) == "undefined") {
            return false;
        }
        console.log('搜索地点开始');
        if ($scope.startPoint.keyword == "" || $scope.startPoint.keyword.length == 0 || $scope.startPoint.keyword == "我的位置") {
            // 定位位置设置地图中心
            $scope.mapSearch.setCenter(new AMap.LngLat($scope.locationGCJ.lng, $scope.locationGCJ.lat));
            $scope.mapSearch.setZoom(16);
            // 清除搜索结果
            $scope.startPoint.keyword = "我的位置"
            document.getElementById('startName').value = "我的位置";
            document.getElementById('startLng').value = $scope.locationGCJ.lng;
            document.getElementById('startLat').value = $scope.locationGCJ.lat;
            $scope.mapSearch.placeSearch.clear();
            document.getElementById("aMapPanel_search").innerHTML = "";
            $ionicLoading.hide();
            return;
        }
        var adcode = "";
        // 已选城市
        if ($scope.mapSearcData.cityList && $scope.mapSearcData.city && $scope.mapSearcData.cityList[$scope.mapSearcData.city]) {
            adcode = $scope.mapSearcData.cityList[$scope.mapSearcData.city].adcode;
        }
        // 已选省份
        else if ($scope.mapSearcData.provinceList && $scope.mapSearcData.province && $scope.mapSearcData.provinceList[$scope.mapSearcData.province]) {
            adcode = $scope.mapSearcData.provinceList[$scope.mapSearcData.province].adcode;
        }
        // 设置搜索范围
        $scope.mapSearch.placeSearch.setCity(adcode);
        // 搜索地点
        $scope.mapSearch.placeSearch.search($scope.startPoint.keyword, function (status, result) {
            console.log(status);
            console.log(JSON.stringify(result));
            if (status == "complete") {
                if (result.info == "OK") {
                    $scope.mapSearch.placeSearchRender.autoRender({
                        placeSearchInstance: $scope.mapSearch.placeSearch,
                        methodName: "search",
                        methodArgumments: [adcode, $scope.searchStart],
                        data: result,
                        map: $scope.mapSearch,
                        panel: "aMapPanel_search"
                    });
                }
                else if (result.info == "TIP_CITIES") {
                    // 提示选择城市 缩小范围
                    $fwCordovaToast.showShortBottom('搜索范围过大，请选择省份、城市后再试');
                }
            }
            if (status == "no_data") {
                // 无搜索结果
                $fwCordovaToast.showShortBottom('无搜索结果');
            }
            $ionicLoading.hide();
        })
    }

    // 选择起点
    $scope.selectSatart = function () {
        // 从hidden取值赋值给起点
        if (document.getElementById('startName').value != "" && document.getElementById('startName').value.length > 0
        && document.getElementById('startLng').value != "" && document.getElementById('startLng').value.length > 0
        && document.getElementById('startLat').value != "" && document.getElementById('startLat').value.length > 0) {
            $scope.startPoint.name = document.getElementById('startName').value;
            $scope.startPoint.location.lng = document.getElementById('startLng').value;
            $scope.startPoint.location.lat = document.getElementById('startLat').value;
            console.log("起点：" + JSON.stringify($scope.startPoint));
            // 清除所有导航结果
            for (var i in $scope.pathPlan) {
                if ($scope.pathPlan[i].clear) {
                    $scope.pathPlan[i].clear();
                }
            }
            // 规划路径方式
            $scope.planPath($scope.mapMode, $scope.startPoint.location);
        }
        // 我的位置
        else if ($scope.startPoint.keyword == "" || $scope.startPoint.keyword.length == 0 || $scope.startPoint.keyword == "我的位置") {
            // 清除所有导航结果
            for (var i in $scope.pathPlan) {
                if ($scope.pathPlan[i].clear) {
                    $scope.pathPlan[i].clear();
                }
            }
            // 规划路径方式
            $scope.planPath($scope.mapMode, $scope.locationGCJ);
        }
        else {
            $fwCordovaToast.showShortBottom('请选择起点');
            return;
        }
        // 隐藏起点搜索
        $scope.amapSearchHide();
    }

    // 隐藏起点搜索
    $scope.amapSearchHide = function () {
        $scope.amapSearchModal.hide();
        if ($scope.startPoint.keyword == "" || $scope.startPoint.keyword.length == 0) {
            $scope.startPoint.keyword = "我的位置"
        }
        if (typeof (AMap) != "undefined") {
            // 清除搜索结果
            $scope.mapSearch.placeSearch.clear();
        }
        document.getElementById("aMapPanel_search").innerHTML = "";
        //$scope.mapSearcData = {};
        //$scope.mapSearch.destroy();
    }

    $ionicLoading.show();
    // 修改为视图全面进入后触发
    $scope.$on('$ionicView.enter', function () {
        HospitalService.description().then(function (data) {
            $scope.description = data;
            // 调整下加载顺序，防止LOCATION先回来加载大量图片卡住上面加载
            HospitalService.location().then(function (data) {
                $ionicLoading.hide();
                $scope.location = data;

                var originalTop = $("#ionic-content").css("top");
                console.log(originalTop);
                var headerbarHeight = $("#ionic-header-bar").css("height");
                var desc = $("#desc").css("height");
                console.log(desc);
                console.log(parseInt(desc) + parseInt(headerbarHeight));
                $("#ionic-content").css("top", parseInt(desc) + parseInt(headerbarHeight) - 2);
            });
        }, function (resp) {
            var alertPopup = $ionicPopup.alert({
                title: '网络错误',
                template: '加载失败,请检查网络'
            });
            $ionicLoading.hide();
        });
    });


    $scope.marginTop = function () {
        $("#top-div").css("top", $(".bar-header").css("height"));
        $("#middle-div").css("margin-top", $("#top-div").css("height"));
    }

    $scope.goBack = function () {
        $state.go("app.home");
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        //alert('hospital_enter');
        $ionicPlatform.registerBackButtonAction(function (e) {
            //alert('hospital_back');
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'hospital');
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'hospital') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
})