angular.module('fwapp.controllers')

.controller('LisController', function ($scope, $rootScope, $state, $ionicPlatform, $stateParams, $window, $timeout,
    $ionicPopup, $ionicModal, $ionicLoading, $ionicPopover, $ionicScrollDelegate, $cordovaInAppBrowser,
    AccountService, VisitPatientService, RequestService, ReportService, ChangePhoneNumberService, $fwCordovaToast) {
    // 检查登录状态
    $rootScope.checkLogin();

    // 就诊人ID
    $scope.vpId = $stateParams.vpid;
    // 打哪儿来
    $scope.from = $stateParams.from;
    // LIS列表
    $scope.lisList = [];
    // 当前检验类型
    $scope.lisType = 1;
    // 是否加载完成
    $scope.isLoadFinish = false;
    // 2021-11-5 19:19:12 检验结果仅显示异常
    $scope.screenFlag = true;
    $scope.showAvailable = false;
    // LIS结果
    $scope.lisResult = {
        INDEX: 0,
        TEST_ORDER_NAME: '',
        SAMPLING_TIME: '',
        SAMPLE_CLASS_NAME: '',
        LIS_RESULT: []
    }
    //手机验证成功的ID
    $scope.authId = "";
    //下载验证成功的ID
    $scope.downloadId = "";
    $scope.reqId = '';
    $scope.timespan = 0;
    // 验卡模型
    $scope.vpVerify = {
        phone_num: '',
        phone_num_show: '',
        imageVericode: '',
        messageVericode: ''
    };
    // 图片验证码
    $scope.imageVericode = {};
    $scope.imageVericode.status = 0;
    $scope.imageVericode.src = {};
    //手机验证后直接进入
    $scope.thisResultIndex = 0;
    $scope.thisResultFunc = "";
    // 防止多次获取验证码
    $scope.disableGetVericode = false;

    $scope.watermark = {};

    // 就诊人列表
    $scope.vpList = [];
    // 就诊人信息
    $scope.vpInfo = new Object();

    // 注册模态窗口:LIS结果
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('lis_result.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.lisResultModal = modal;
    });

    // 注册模态窗口:验证手机号
    $ionicModal.fromTemplateUrl('verifyPhone.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.getImageVericode();
        $scope.vpVerify.imageVericode = "";
        $scope.vpVerify.messageVericode = "";
        $scope.verifyPhoneModal = modal;
    });

    // 隐藏模态窗口:验证手机号
    $scope.verifyPhoneModalHide = function () {
        // 隐藏
        $scope.verifyPhoneModal.hide();
    }

    // 注册弹出菜单：就诊人列表
    $ionicPopover.fromTemplateUrl('pop_vplist.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popVplist = popover;
    });

    // 注销模态窗口
    $scope.$on('$destroy', function () {
        $scope.lisResultModal.remove();
        $scope.verifyPhoneModal.remove();
    });

    // 读取LIS列表
    $scope.loadLisList = function (type) {
        $scope.screenFlag = true;
        $scope.showAvailable = false;
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        $scope.lisList = [];

        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();

        RequestService.lisList($scope.vpId, type, localStorage.queryToken).then(function (data) {
            if (data.result == 99) {    // 链接超时
                loadFinish();
                $fwCordovaToast.showShortBottom("连接超时，请重试");
                return;
            }
            if (data.result == -2) {
                $ionicLoading.hide();
                $scope.queryPassword().then(function (data) {
                    if (data) {
                        $scope.loadLisList(type);
                    }
                })
                return;
            }
            if (data.result != 1 && data.result != -1) {  // 请求错误
                loadFinish();
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            if (data.result == -1) {
                $timeout(function () {
                    if (data.is_null != 1) {
                        $scope.lisList = data.data;
                    }
                    loadFinish();
                }, 1500);
                return;
            }
            if (data.is_null != 1) {
                $scope.lisList = data.data;
            }
            loadFinish();
        });
    }

    function loadFinish() {
        $ionicLoading.hide();
        $scope.isLoadFinish = true;
    }

    // 切换就诊人
    $scope.changeVp = function (vpid) {
        $scope.vpId = vpid;
        $scope.vpInfo = new Object();
        $scope.loadVPInfo();
        $scope.loadLisList($scope.lisType);
        $scope.popVplist.hide();
    }

    // 切换LIS类型
    $scope.changeType = function (type) {
        $scope.lisType = type;
        $scope.loadLisList(type);
    }

    // 仅显示异常
    $scope.screen = function () {
        $scope.screenFlag = !$scope.screenFlag;
        $scope.showAvailable = !$scope.showAvailable;
        $ionicScrollDelegate.resize();
        $ionicScrollDelegate.scrollTop();
    }

    // 读取就诊人信息
    $scope.loadVPInfo = function () {
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
            }
        })
    }

    // 查看LIS结果
    $scope.lisResultShow = function (index) {
        $scope.thisResultIndex = index;
        $scope.thisResultFunc = "lis";
        if ($scope.vpInfo.IS_SELF == 1) {
            $scope.getLisInfo(index);
            $scope.lisResultModal.show();
            AccountService.getWatermark().then(function (data) {
                $scope.watermark = data.data;
            });
        }
        else {
            //验证身份及授权
            ReportService.verify($scope.vpId).then(function (data) {
                //已验证过
                if (data.result == 1) {
                    $scope.getLisInfo(index);
                    $scope.lisResultModal.show();
                    AccountService.getWatermark().then(function (data) {
                        $scope.watermark = data.data;
                    });
                } else if (data.result == 0) {//没验证
                    $scope.verifyPhoneModal.show();
                    $scope.GetReservedPhone();
                } else {
                    $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                    return;
                }
            }, function () {
                $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                return;
            })
        }
    }

    // 关闭LIS结果查看
    $scope.lisResultHide = function () {
        $scope.lisResultModal.hide();
        $scope.lisResult = {
            INDEX: 0,
            TEST_ORDER_NAME: '',
            SAMPLING_TIME: '',
            SAMPLE_CLASS_NAME: '',
            LIS_RESULT: []
        }
    }

    // 获取LIS检验结果
    $scope.getLisInfo = function (index) {
        $ionicLoading.show();
        $scope.isLoadFinish = false;
        var lis = $scope.lisList[index];
        RequestService.lisResult($scope.vpId, lis.INSPECTION_ID, localStorage.queryToken).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 99) {    // 链接超时
                $fwCordovaToast.showShortBottom("连接超时，请重试");
                return;
            }
            if (data.result == -2) {
                $scope.queryPassword().then(function (data) {
                    if (data) {
                        $scope.loadLisList(index);
                    }
                })
                return;
            }
            if (data.result != 1 && data.result != -1) {  // 请求错误
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            if (data.is_null == 1) { // 空结果
                return;
            }
            $scope.reqId = data.data[0].REQUEST_ID;
            $scope.lisResult.INDEX = index;
            $scope.lisResult.TEST_ORDER_NAME = lis.TEST_ORDER_NAME;
            $scope.lisResult.SAMPLING_TIME = lis.SAMPLING_TIME;
            $scope.lisResult.SAMPLE_CLASS_NAME = lis.SAMPLE_CLASS_NAME;
            $scope.lisResult.LIS_RESULT = data.data;
            loadFinish();
        });
    }

    // #region 检查报告下载

    //下载PDF
    $scope.downloadPDF = function (reqId, index) {
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        if (reqId != null && reqId.length > 0) {
            ReportService.saveDownloadRecord($scope.vpId, $scope.thisResultFunc, reqId,
                $scope.thisResultFunc == "lis" ? $scope.lisList[index].TEST_ORDER_NAME : $scope.checkList[index].DESCRIPTION, "PDF",
                $scope.thisResultFunc == "lis" ? $scope.lisList[index].INSPECTION_ID : $scope.checkList[index].ID).then(function (data) {
                    $scope.downloadId = data.downloadId;
                })
            RequestService.downloadPDF(reqId, $scope.vpId).then(function (data) {
                if (data.result == 1) {
                    ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 1);
                    var url = data.data;
                    //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
                    //$cordovaInAppBrowser.open(url, '_system', option).then(function (event) { });
                    //2023.7.31 新插件原有调用方式参数不生效
                    showInAppBrowser(url, '_system');
                    loadFinish();
                    return;
                }
                // 链接超时
                else if (data.result == 99) {
                    ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 2);
                    loadFinish();
                    $fwCordovaToast.showShortBottom("连接超时，请重试");
                    return;
                } else {
                    ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 2);
                    loadFinish();
                    $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                    return;
                }
            });
        } else {
            loadFinish();
            $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
            return;
        }
    }

    // #endregion

    // #region 非本人授权浏览

    // 获取预留手机号
    $scope.GetReservedPhone = function () {
        $ionicLoading.show();
        RequestService.GetReservedPhone($scope.vpId).then(function (data) {
            // 圈消失
            $ionicLoading.hide();
            // 链接超时
            if (data.result == 99) {
                $fwCordovaToast.showShortBottom('获取预留手机号失败，服务繁忙，请重试');
                return;
            }
            // 请求错误
            if (data.result != 1 && data.result != -1) {
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            // 空结果
            if (data.is_null == 1) {
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            var phone = data.data[0].PHONENUM;
            $scope.vpVerify.phone_num = phone;
            $scope.vpVerify.phone_num_show = phone.toString().substring(0, 3) + "****" + phone.toString().substring(7, phone.toString().length);
        });
    }

    //获取短信验证码
    $scope.verifyToGetMsgVericode = function () {
        // 验证图片验证码
        if ($scope.vpVerify.imageVericode == null || $scope.vpVerify.imageVericode.length == 0) {
            var alertPopup = $ionicPopup.alert({
                title: '验证失败',
                template: '图片验证码不得为空'
            });
            return;
        }
        AccountService.sendVericodeByPhone($scope.vpVerify.phone_num, "10", $scope.vpVerify.imageVericode, $scope.vpId, $scope.thisResultFunc).then(function (data) {
            $ionicLoading.hide();
            // 发送成功
            if (data.result == 1) {
                //记录验证信息
                ReportService.saveVerifyInfo($scope.vpId, $scope.thisResultFunc).then(function (data) {
                    if (data.result == 1) {
                        $scope.authId = data.authId;
                        $scope.disableGetVericode = true;
                        $fwCordovaToast.showShortBottom("已向您的预留手机发送验证码，请填写验证码完成绑定");
                        // 倒计时
                        $scope.timespan = 60;
                        TimeCount();
                    } else {
                        $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                        return;
                    }
                })
            } else if (data.result == 0) {// 服务调用失败
                // 刷新图片验证码
                $scope.getImageVericode();
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: data.msg
                });
            } else {
                // 刷新图片验证码
                $scope.getImageVericode();
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: '获取验证码失败，请稍后重试'
                });
            }
            $scope.disableGetVericode = false;
        }, function () {
            $scope.disableGetVericode = false;
        });
    }

    //验证手机验证码
    $scope.verifyCardSubmit = function () {
        if ($scope.vpVerify.phone_num == '' || $scope.vpVerify.messageVericode == '') {
            $fwCordovaToast.showShortBottom('请完整填写预留手机验证信息');
            return false;
        }
        $scope.disableVerify = true;
        ChangePhoneNumberService.compareVericode($scope.vpVerify.phone_num, $scope.vpVerify.messageVericode, currentPlatform, deviceToken, "10").then(function (data) {
            if (data.result == 1) {
                $scope.timespan = 0; //倒计时清零
                $fwCordovaToast.showShortBottom("验证成功。");
                //记录验证信息
                ReportService.updateVerifyInfo($scope.vpId, $scope.authId).then(function (data) {
                    if (data.result == 1) {
                        $scope.verifyPhoneModal.hide();
                        if ($scope.thisResultFunc == "check") {
                            $scope.checkResult.TITLE = "检查报告";
                            $scope.getCheckInfo($scope.thisResultIndex);
                            $scope.checkResultModal.show();
                        } else if ($scope.thisResultFunc == "lis") {
                            $scope.getLisInfo($scope.thisResultIndex);
                            $scope.lisResultModal.show();
                            AccountService.getWatermark().then(function (data) {
                                $scope.watermark = data.data;
                            });
                        }
                    } else {
                        $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                        $scope.disableVerify = false;
                        return;
                    }
                }, function () {
                    $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                    $scope.disableVerify = false;
                    return;
                })
            } else {
                $scope.getImageVericode();
                $scope.vpVerify.imageVericode = "";
                $scope.vpVerify.messageVericode = "";
                var alertPopup = $ionicPopup.alert({
                    title: '验证失败',
                    template: data.msg
                });
            }
            $scope.disableVerify = false;
        }, function (data) {
            $scope.disableVerify = false;
        })
    }

    // 获取图片验证码
    $scope.getImageVericode = function () {
        AccountService.getImageVericode().then(function (data) {
            // 需要验证码
            if (data.result == 1) {
                $scope.imageVericode.src = "data:image/jpeg;base64," + data.data;
            }
            // 不需要验证码
            else {
                $scope.imageVericode.src = "";
            }
            $scope.imageVericode.status = data.result;
            $scope.vpVerify.imageVericode = "";
        }, function (data) {
            // 获取失败 显示 点击重新获取
            $scope.imageVericode.status = 1;
        });
    }

    // 重新发送倒计时
    function TimeCount() {
        if (!$scope.$$phase) {
            $scope.$apply($scope.timespan = $scope.timespan - 1);
        } else {
            $scope.timespan = $scope.timespan - 1;
        }
        resendTimeer = setTimeout(TimeCount, 1000);
        if ($scope.timespan <= 0) {
            clearTimeout(resendTimeer);
            $scope.disableGetVericode = false;
        }
    };

    // #endregion

    // 后退
    $scope.goBack = function () {
        if ($stateParams.vpid == "" || $scope.from == "app.message") {
            $window.history.back();
        } else {
            $state.go('app.visitPatient', { vpid: $scope.vpId });
        }
    }

    // 显示弹出菜单
    $scope.openPopoverVpList = function ($event) {
        $scope.popVplist.show($event);
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        if (!$rootScope.checkLogin()) {
            return;
        }

        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'lis');
    });

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        $scope.vpList = [];
        // 获取就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                // 若无就诊人
                if (data.data.length == 0) {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("未找到绑定的就诊人信息");
                    return;
                }

                // 第一就诊人
                var vpid = "";
                for (var i = 0; i < data.data.length; i++) {
                    if (data.data[i].IS_BIND_CARD == '1') {
                        $scope.vpList.push(data.data[i]);
                        if (vpid == "") {
                            vpid = data.data[i].VISIT_PATIENT_ID;
                        }
                    }
                }

                // 若参数无就诊人信息
                if ($scope.vpId == "") {
                    // 默认第一就诊人
                    $scope.vpId = vpid;
                }

                // 若vpid仍为空
                if ($scope.vpId == "") {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("请绑定就诊卡");
                    return;
                } else {
                    $scope.loadVPInfo();
                    $scope.queryPassword().then(function (data) {
                        if (data) {
                            $scope.loadLisList(1);
                        }
                    })
                }
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    })

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'lis') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
});
