﻿angular.module('fwapp.controllers')

// 开药详情
.controller('OlTreatRecipeListController', function ($scope, $rootScope, $state, $stateParams
, $ionicModal, $ionicPopup, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $fwCordovaToast
, OlTreatRecipeService, ExpressService, ConsultationService) {
    // 如果没登录 扔出去
    if (localStorage.currentAccountId.length == 0) {
        $state.go("login");
        return;
    }

    $scope.applyList = [];
    $scope.applyInfo = {
        index: 0
    };
    $scope.errMsg = "";
    $scope.status = $stateParams.status;
    // 打哪儿来
    $scope.from = $stateParams.from;
    // 判断是否进行了换药操作
    $scope.changeIndex = 0;
    // 物流信息
    $scope.orderRoute = [];
    // 定时器关闭
    $scope.timerStop = false;

    // 注册模态窗口：预约详情
    $ionicModal.fromTemplateUrl('applyDetail.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.applyDetailModal = modal;
    });

    // 注册模态窗口：查询快递信息
    $ionicModal.fromTemplateUrl('expressInfo.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.expressInfoModal = modal;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.applyDetailModal.remove();
        $scope.expressInfoModal.remove();
    })

    // 预约详情模态窗口显示
    $scope.applyDetailShow = function (index) {
        $scope.applyInfo.index = index;
        $scope.applyDetailModal.show();
    }
    // 预约详情模态窗口隐藏
    $scope.applyDetailHide = function () {
        $scope.applyDetailModal.hide();
        $scope.applyInfo.index = 0;
        if($scope.changeIndex != 0){
            // 读取预约挂号列表
            $scope.loadApplyList();
        }
        //$ionicScrollDelegate.scrollTop();
    }

    // 查询快递信息窗口显示
    $scope.expressInfoShow = function () {
        $scope.expressInfoModal.show();
    }

    // 查询快递信息窗口关闭
    $scope.expressInfoHide = function () {
        $scope.expressInfoModal.hide();
    }

    //console.log($scope.status);
    $scope.changeStatus = function (status) {
        $scope.status = status;
        $scope.loadApplyList();
    }

    // 获取合并预约挂号列表
    $scope.loadApplyList = function (treatApplyId) {
        $ionicLoading.show();
        OlTreatRecipeService.getApplyList($scope.status).then(function (data) {
            // 查询成功
            if (data.result == 1) {
                console.log(data.data);
                $scope.applyList = data.data;

                var payStatusUnPaid = false;
                var forFlag = false;
                for (var i = 0; i < $scope.applyList.length; i++) {
                    if ($scope.applyList[i].STATUS == "0") {
                        payStatusUnPaid = true;
                    }

                    if (treatApplyId != null && treatApplyId != "" && $scope.applyList[i].TREAT_APPLY_ID == treatApplyId && $scope.applyList[i].STATUS == "0") {
                        forFlag = true;
                    }
                }

                // 如果有未支付的申请，则开启倒计时，其实直接调用就行。可以少走一个ajax
                if (payStatusUnPaid == true) {
                    $scope.getTimeLimit();
                }

                // 前端递归调用
                if (forFlag == true) {
                    $scope.loadApplyList(treatApplyId);
                }
            }
            // 查询失败
            else {
                $scope.applyList = [];
                $scope.errMsg = data.msg;
            }
            // 重新计算高度
            $ionicScrollDelegate.scrollTop();
            $ionicScrollDelegate.resize();
            $ionicLoading.hide();
        })
    }

    // 2019-7-23 09:01:30 改为查看详情时加载
    // 获取申请会话
    $scope.getApplyConvr = function (index) {
        if ($scope.applyList == null || $scope.applyList.length <= index) {
            return false;
        }
        console.log($scope.applyList[index].TREAT_APPLY_ID);
        $ionicLoading.show();
        OlTreatRecipeService.getApplyConvr($scope.applyList[index].TREAT_APPLY_ID).then(function (data) {
            // 查询成功
            if (data.result == 1) {
                console.log(data.data);
                //$scope.applyList = data.data;
                $scope.applyList[index].CONVR_LIST = data.data.convrList;
                $scope.applyInfo.index = index;
                $scope.applyDetailModal.show();
            }
            // 查询失败
            else {
                //$scope.applyList = [];
                //$scope.errMsg = data.msg;
                $fwCordovaToast.showShortBottom(data.msg);
            }
            $ionicLoading.hide();
        }, function(err) {
            $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
        })
    }

    // 返回按钮
//    $scope.goBack = function () {
//        if ($scope.from == "app.message") {
//            $rootScope.goBack();
//        }
//        else {
//            $state.go('app.home');
//        }
//    }

    // 日期格式化
    $scope.getDateFormat = function (strDate, format) {
        return new Date(strDate.replace(/-/g, '/')).Format(format);
    }

    // 最近系统消息
    $scope.getLatestSysMsg = function (index) {
        //var list = $scope.applyList[index].CONVR_LIST.filter(e => e.ACCOUNT_TYPE == 0 );
        // 2020-2-13 18:54:34 HM 换药，增加医生发送确认文本
        var list = $scope.applyList[index].CONVR_LIST.filter(e => e.ACCOUNT_TYPE == 0 || (e.ACCOUNT_TYPE == 2 && e.MSG_TYPE == 5));
        var result =  list.length == 0 ? null : list[0].MSG_CONTENT;
        //console.log(result);
        return result;
    }

    // 取消开药申请
    $scope.cancelApply = function (index) {
        var confirmPopup = $ionicPopup.confirm({
            title: '取消申请确认',
            template: "此操作不可逆，您确定要取消当前申请吗？",
            cancelText: '取消',
            okText: '确定'
        }).then(function (res) {
            if (res) {
                $ionicLoading.show();
                OlTreatRecipeService.cancelApply($scope.applyList[index].TREAT_APPLY_ID).then(function (data) {
                    $ionicLoading.hide();
                    // 获取成功
                    if (data.result == 1) {
                        // 轮询成功
                        if (data.applyResult == 8) {
                            $fwCordovaToast.showShortBottom("取消申请成功");

                            // 读取预约挂号列表
                            $scope.loadApplyList();

                            $scope.getTimeLimit();
                        }
                        else if (data.applyResult == 15) {
                            // 读取预约挂号列表
                            $scope.loadApplyList();

                            $scope.getTimeLimit();

                            // 北京医保取消挂号
                            $scope.signOutApply(index);
                        }
                        else {
                            $fwCordovaToast.showShortBottom(data.msg);
                        }
                    }
                    // 超时
                    else if (data.result == 99) {
                        $fwCordovaToast.showShortBottom("服务繁忙，请稍后重试");
                    }
                    // 获取失败
                    else {
                        $fwCordovaToast.showShortBottom(data.msg);
                    }
                })
            }
        })
    }

    // 2020-2-13 14:38:32 HM 当在线处方无药时，进行换药待确认操作，changeIndex=1同意换药，2不同意换药
    $scope.applyChange = function (treatApplyId, changeIndex) {
        $ionicLoading.show();
        // 记录是否进行了换药操作
        $scope.changeIndex = changeIndex;
        OlTreatRecipeService.applyChange(treatApplyId, changeIndex).then(function (data){
            console.log(data);
            if(data.result == 1){
                // 轮询成功
                // 刷新一下模态窗口数据
                OlTreatRecipeService.getApplyConvr(treatApplyId).then(function (data) {
                    $ionicLoading.hide();
                    // 查询成功
                    if (data.result == 1) {
                        console.log(data.data);
                        $scope.applyList[$scope.applyInfo.index].CONVR_LIST = data.data.convrList;
                        $fwCordovaToast.showLongBottom("系统正在处理您的换药申请，请稍后。");
                    }
                    // 查询失败
                    else {
                        $fwCordovaToast.showShortBottom(data.msg);
                    }
                }, function(err) {
                    $ionicLoading.hide();
                    $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
                })
            }
            else if(data.result == 99){
                $ionicLoading.hide();
                $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
            }
            else{
                $ionicLoading.hide();
                $fwCordovaToast.showShortBottom(data.msg);
            }
        }, function(err) {
            $fwCordovaToast.showShortBottom("网络错误,请稍后重试");
        })   
    }

    // 2020-4-27 21:00:20 HM 增加支付页面跳转
    $scope.payApply = function (index) {
        $state.go('app.express', { applyId: $scope.applyList[index].TREAT_APPLY_ID });
    }

    // 查看物流信息
    $scope.getExpressInfo = function (index) {
        $ionicLoading.show();
        ExpressService.getOrderRoute($scope.applyList[index].TREAT_APPLY_ID).then(function (data){
            $ionicLoading.hide();
            if(data.result == 1){
                $scope.orderRoute = data.data.Result;
                $scope.expressInfoShow();
            }
            else{
                $fwCordovaToast.showShortBottom("暂无快递信息");
            }
        }, function (err) {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("获取物流信息，网络错误。");
        })
    }

    // 确认收货
    $scope.confirmExpress = function (index){
        $ionicLoading.show();
        ExpressService.confirmExpress($scope.applyList[index].TREAT_APPLY_ID).then(function (data){
            $ionicLoading.hide();
            if(data.result == 1){
                $fwCordovaToast.showShortBottom("确认收货成功");
                // 刷一下列表
                $scope.loadApplyList();
            }
            else{
                $fwCordovaToast.showShortBottom(data.msg);
            }
        }, function (err) {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("确认收货，网络错误。");
        })
    }

    // 支付互联网复诊费
    $scope.payDoctorApply = function (index) {
        var miPatient = false;
        if ($scope.applyList[index].MI_PATIENT == 1 || $scope.applyList[index].MI_PATIENT == "1") {
            miPatient = true;
        }

        // 收银台
        $scope.cashier("olTreat", $scope.applyList[index].TREAT_FEE, $scope.applyList[index].VISIT_PATIENT_ID, $scope.applyList[index].TREAT_APPLY_ID, "", "",
            $scope.applyList[index].DOCTOR_CODE, $scope.applyList[index].MI_PATIENT, "", "", $scope.applyList[index].TREAT_FEE).then(function (dataCashier) {

                // 支付成功 获取订单状态
                if (dataCashier.code == 1) {
                    // 刷新订单列表
                    $scope.loadApplyList($scope.applyList[index].TREAT_APPLY_ID);
                    // 重新获取定时器
                    $scope.getTimeLimit();
                }
                // 支付失败，或者放弃支付等等
                else {
                    // 什么都不做
                }
            })
    }

    // 自行退号
    $scope.signOutApply = function (index) {
        $ionicLoading.show();
        OlTreatRecipeService.getRefundBJYBUrlOlTreat($scope.applyList[index].TREAT_APPLY_ID, $scope.applyList[index].VISIT_PATIENT_ID).then(function (data) {
            $ionicLoading.hide();
            if (data.result == 0) {
                $ionicPopup.alert({
                    title: '提示',
                    template: data.msg,
                    okText: "确定"
                });
            }
            else {
                if (data.ybUrl != "") {
                    // 先用cordovaInAppBrowser的方式，后期还得切换到插件的形式
                    var herfUrl = "https://ds.alipay.com/?scheme=" + encodeURIComponent("alipays://platformapi/startapp?appId=2021003175643256&page=" + encodeURIComponent(data.ybUrl));

                    //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
                    //$cordovaInAppBrowser.open(herfUrl, '_system', option).then(function (event) { });
                    //2023.7.31 新插件原有调用方式参数不生效
                    showInAppBrowser(herfUrl, '_system');

                    // 注册个返回事件
                    document.addEventListener("resume", OnResumeYBCancel, false);
                }
                else {
                    $ionicPopup.alert({
                        title: '提示',
                        template: "网络错误，请稍后重试",
                        okText: "确定"
                    });
                }
            }
        }, function () {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "网络错误，请稍后重试",
                okText: "确定"
            });
        })
    }

    // app后台回到
    function OnResumeYBCancel() {
        setTimeout(function () {
            // 刷新订单列表
            $scope.loadApplyList();

            // 解绑后台唤醒事件监测
            document.removeEventListener("resume", OnResumeYBCancel, false);
        }, 1000);
    }

    // 获取支付时间限制
    $scope.getTimeLimit = function () {
        ConsultationService.getTimeLimitVideo("", "1").then(function (data) {
            console.log(data);
            // 获取成功
            if (data.result == 1) {
                $rootScope.payTimeLeftOlTreat = data.data;
                if ($rootScope.payStatusOlTreat != 1) {
                    $rootScope.payStatusOlTreat = 1;
                }
                // 倒计时
                $scope.timerStop = true;
                $scope.timeCountdown();
            }
            else {
                $scope.timerStop = false;
                $rootScope.payStatusOlTreat = 0;
                $rootScope.payTimeLeftOlTreat = 0;
            }
        }, function () {
            $ionicLoading.hide();
            $ionicPopup.alert({
                title: '提示',
                template: "网络错误，请稍后重试",
                okText: "确定"
            });
        })
    }

    // 倒计时
    $scope.timeCountdown = function () {
        if (!$scope.$$phase) {
            $scope.$apply($rootScope.payTimeLeftOlTreat = $rootScope.payTimeLeftOlTreat - 1);
        } else {
            $rootScope.payTimeLeftOlTreat = $rootScope.payTimeLeftOlTreat - 1;
        }
        clearTimeout($rootScope.payResendTimeerOlTreat);
        if ($rootScope.payTimeLeftOlTreat > 0) {
            $rootScope.payResendTimeerOlTreat = setTimeout($scope.timeCountdown, 1000);
        }
        else {
            if (!$scope.$$phase) {
                $scope.$apply($rootScope.payStatusOlTreat = 0);
            } else {
                $rootScope.payStatusOlTreat = 0;
            }
        }
    }

    $scope.$on('$ionicView.enter', function () {
        // 读取预约挂号列表
        $scope.loadApplyList();
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            if ($scope.step == 0) {
                if ($scope.from.length > 0) {
                    $state.go($scope.from);
                }
                else {
                    $state.go('app.personal');
                }
            }
            else {
                $scope.goBack();
            }
            e.preventDefault();
            return false;
        }, 135, 'olTreatRecipeList');
    });

    $scope.$on('$ionicView.beforeLeave', function () {
        // 解除返回键绑定
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'olTreatRecipeList') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
})