﻿angular.module('fwapp.controllers')

.controller('OpCallListController', function ($scope, $rootScope, $state, $stateParams, $timeout, $ionicPopup, $ionicModal, $ionicLoading, $ionicPopover,
    OpCallListService, VisitPatientService, PersonalService, RequestService, $fwCordovaToast, $ionicPlatform, $ionicSlideBoxDelegate) {
    // 检查登录状态
    $rootScope.checkLogin();

    // 加载结果，0为有记录，1为无就诊人，2=就诊人未绑卡，3=没有叫号信息
    $scope.loadResult = 0;
    // 候诊列表
    $scope.callList = [];
    // 卡号条形码列表
    $scope.barcodeList = [];
    // 两个ajax异步计数器
    $scope.requestCount = 0;
    // 检查叫号列表
    $scope.inspectList = [];
    // 康复叫号列表
    $scope.RHBList = [];
    // 显示等候人数及等待时间 开关
    $scope.opCallListPeopleTime = devMode ? true : false;

    // 初始化
    $scope.loadCallList = function () {
        $ionicLoading.show();
        // 直接广播刷新完毕，使下拉刷新隐藏
        $scope.$broadcast('scroll.infiniteScrollComplete');
        $scope.$broadcast('scroll.refreshComplete');
        // 就诊人列表
        VisitPatientService.visitPatientList().then(function (vpdata) {
            if (vpdata.result != 1) {
                $fwCordovaToast.showShortBottom(vpdata.msg);
                $ionicLoading.hide();
                return;
            }
            // 无就诊人
            if (vpdata.data.length == 0) {
                $scope.loadResult = 1;
                $ionicLoading.hide();
                return;
            }
            // 判断是否绑卡
            var hasBindCard = false;
            for (var i = 0; i < vpdata.data.length; i++) {
                if (vpdata.data[i].HIS_CARD_NUM != '') {
                    hasBindCard = true;
                }
            }
            // 无绑卡就诊人
            if (!hasBindCard) {
                $scope.loadResult = 2;
                // 隐藏LOADING页面
                $ionicLoading.hide();
                return;
            }

            // 初始化变量
            $scope.loadResult = 0;
            
            // 候诊叫号列表
            $scope.requestCount = 0;
            $scope.opCallList();
            $scope.getCheckCalllist();
            $scope.getRHBCallList();
        })
    }

    // 获取候诊叫号列表
    $scope.opCallList = function (){
        RequestService.opCallList().then(function (data) {
            console.log(data);
            // 若直接缓存结果
            if (data.result == -1) {
                // 无记录处理
                if (data.is_null == 1) {
                }
                else {
                    // 格式化候诊叫号数据
                    $scope.formatCallListData(data.data);
                }
            }

            if (data.result == 99) {    // 链接超时
                $fwCordovaToast.showShortBottom("连接超时，请重试");
            }
            if (data.result == -2) {
                // 这里应该不会出现让输入密码的情况了
                $scope.queryPassword().then(function (data) {
                    if (data) {
                        $scope.loadCallList();
                    }
                })
            }
            if (data.result != 1 && data.result != -1) {  // 请求错误
                $fwCordovaToast.showShortBottom(data.msg);
            }

            if (data.is_null == 1) { // 空结果
            }

            // 有数据的时候
            if(data.result == 1 && data.is_null == 0){
                // 格式化候诊叫号数据
                $scope.formatCallListData(data.data);
            }

            $scope.requestCount++;
            console.log("候诊叫号：" + $scope.requestCount);
            if($scope.requestCount == 3){
                // 都没数据的时候，为空
                if($scope.callList.length == 0 && $scope.inspectList.length == 0 && $scope.RHBList.length == 0){
                    $scope.loadResult = 3;
                }
                $ionicLoading.hide();
            }
        })
    }

    // 获取检查叫号列表
    $scope.getCheckCalllist = function (){
        // 检查叫号
        RequestService.getCheckCalllist().then(function(data){
            console.log(data);
            if(data.result != 1){
                //$fwCordovaToast.showShortBottom("未找到检查挂号信息");
                // return;
            }
            if(data.result == 1 && data.is_null == 1){
                //$fwCordovaToast.showShortBottom("未找到本日检查挂号信息");
                // return;
            }

            // 有数据
            if(data.result == 1 && data.is_null == 0){
                console.log(data.data);
                $scope.inspectList = data.data;
                // 循环获取code和name
                for(var i = 0;i < $scope.inspectList.length; i++){
                    $scope.inspectList[i].PoiName = "";
                    $scope.inspectList[i].PoiCode = "";
                    $scope.getNavigate($scope.inspectList[i].CHECK_QUEUE_NAME, "check", i);
                }
            }
            
            $scope.requestCount++;
            console.log("检查叫号：" + $scope.requestCount);
            if($scope.requestCount == 3){
                // 都没数据的时候，为空
                if($scope.callList.length == 0 && $scope.inspectList.length == 0 && $scope.RHBList.length == 0){
                    $scope.loadResult = 3;
                }
                $ionicLoading.hide();
            }
        },function(resp){
            $scope.requestCount++;
            $fwCordovaToast.showShortBottom("网络错误");
            $ionicLoading.hide();
        });
    }

    // 格式化候诊叫号数据
    $scope.formatCallListData = function (callListReuslt) {
        // 处理叫号信息
        for (var i = 0; i < callListReuslt.length; i++) {
            // 卡号二维码
            if (callListReuslt[i].hasOwnProperty("PATIENT_ID") && callListReuslt[i]["PATIENT_ID"] != null && callListReuslt[i]["PATIENT_ID"].length > 0) {
                $scope.getCardCodeBarcode(callListReuslt[i].PATIENT_ID, callListReuslt[i]);
            }
            // 日期格式化
            if (callListReuslt[i].hasOwnProperty("CZRQ") && callListReuslt[i]["CZRQ"] != null && callListReuslt[i]["CZRQ"].length > 0) {
                callListReuslt[i].CZRQ_FORMAT = new Date(callListReuslt[i].CZRQ).Format("yyyy年MM月dd日");
            }
        }
        $scope.callList = callListReuslt;
        // 循环获取code和name
        for(var i = 0;i < $scope.callList.length; i++){
            $scope.callList[i].PoiName = "";
            $scope.callList[i].PoiCode = "";
            // 2021-5-2 14:32:21 HM 候诊叫号改成诊室诊区
            $scope.getNavigate($scope.callList[i].ZSZQ, "op", i);
        }
    }

    // 获取卡号条形码
    $scope.getCardCodeBarcode = function (hisCardNo, obj) {
        var barcode = $scope.barcodeList.filter(e => e.HIS_CARD_NUM == hisCardNo);
        // 缓存中存在
        if (barcode.length > 0) { 
            // 有值
            if (barcode[0].BARCODE_SRC != "") {
                obj.BARCODE_SRC = barcode[0].BARCODE_SRC;
                return;
            }
            // 无值 且 失败次数 >= 5
            else if (barcode[0].FAILED_COUNT >= 5) {
                return;
            }
            // 请求未响应 延迟递归
            else if (barcode[0].IS_PENDING) {
                $timeout(function () {
                    $scope.getCardCodeBarcode(hisCardNo, obj);
                }, 100);
                return;
            }
            // 请求 成功后赋值并递归回调
            barcode[0].IS_PENDING = true;
            PersonalService.getCardCodeBarcode("", hisCardNo).then(function (data) {
                // 获取成功
                if (data.result == 1) {
                    barcode[0].BARCODE_SRC = "data:image/jpeg;base64," + data.data;
                    console.log($scope.barcodeList);
                }
                // 获取失败
                else {
                    barcode[0].FAILED_COUNT++;
                }
                barcode[0].IS_PENDING = false;
                $scope.getCardCodeBarcode(hisCardNo, obj);
            }, function (dataBarcode) {
                barcode[0].FAILED_COUNT++;
                barcode[0].IS_PENDING = false;
                $scope.getCardCodeBarcode(hisCardNo, obj);
            });
        }
        // 缓存中不存在 新建
        else {
            var barcodeInfo = {};
            barcodeInfo.HIS_CARD_NUM = hisCardNo;
            barcodeInfo.BARCODE_SRC = "";
            barcodeInfo.IS_PENDING = false;
            barcodeInfo.FAILED_COUNT = 0;
            $scope.barcodeList.push(barcodeInfo);
            $scope.getCardCodeBarcode(hisCardNo, obj);
            return;
        }
    }

    // 判断预计等候时间是否大于两小时
    $scope.checkWaitTime = function (waitTime){
        if(waitTime == ""){
            return "0";
        }

        var wait = parseFloat(waitTime);
        if(wait < 0){
            return "0";
        }
        else if(wait >= 120){
            return "2";
        }
        else{
            return "1";
        }
    }

    // 康复候诊叫号
    $scope.getRHBCallList = function (){
        RequestService.getRHBCallList().then(function (data) {
            console.log(data);
            // 若直接缓存结果
            if (data.result == -1) {
                // 无记录处理
                if (data.is_null == 1) {
                }
                else {
                    $scope.RHBList = data.data;
                }
            }
            if (data.result == 99) {    // 链接超时
                $fwCordovaToast.showShortBottom("连接超时，请重试");
            }

            if (data.result != 1 && data.result != -1) {  // 请求错误
                $fwCordovaToast.showShortBottom(data.msg);
            }

            if (data.is_null == 1) { // 空结果
            }

            // 有数据的时候
            if(data.result == 1 && data.is_null == 0){
                $scope.RHBList = data.data;
                // 循环获取code和name
                for(var i = 0;i < $scope.RHBList.length; i++){
                    $scope.RHBList[i].PoiName = "";
                    $scope.RHBList[i].PoiCode = "";
                    $scope.getNavigate($scope.RHBList[i].ZXKS, "RHB", i);
                }
            }

            $scope.requestCount++;
            console.log("康复叫号：" + $scope.requestCount);
            if($scope.requestCount == 3){
                // 都没数据的时候，为空
                if($scope.callList.length == 0 && $scope.inspectList.length == 0 && $scope.RHBList.length == 0){
                    $scope.loadResult = 3;
                }
                $ionicLoading.hide();
            }
        })
    }

    // 获取检查科室的道一循code和name
    $scope.getNavigate = function (aliasName, type, index){
        PersonalService.getNavigateCode(aliasName).then(function (data){
            if(data.result == 1){
                if(type == "op"){
                    $scope.callList[index].PoiName = data.data.PoiName;
                    $scope.callList[index].PoiCode = data.data.PoiCode;
                }
                else if (type == "check"){
                    $scope.inspectList[index].PoiName = data.data.PoiName;
                    $scope.inspectList[index].PoiCode = data.data.PoiCode;
                }
                else if (type == "RHB"){
                    $scope.RHBList[index].PoiName = data.data.PoiName;
                    $scope.RHBList[index].PoiCode = data.data.PoiCode;
                }
            }
        })
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        // 获取检查列表
        $scope.loadCallList();
        // 返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'opCall');

        // 获取配置
        OpCallListService.getConfig().then(function (data) {
            // 查询成功
            if (data.result == 1) {
                // 2021-4-27 20:03:04 候诊叫号显示等候人数及等待时间
                if (devMode || data.data.opCallListPeopleTime) {
                    $scope.opCallListPeopleTime = true;
                }
            }
        })
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'opCall') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
});