﻿angular.module('fwapp.controllers')

.controller('ReportMRIController', function ($scope, $rootScope, $state, $stateParams, $timeout, $interval, 
    $ionicPopup, $ionicModal, $ionicLoading, $ionicPopover, $ionicScrollDelegate, $ionicSlideBoxDelegate, $ionicPlatform, $cordovaInAppBrowser, ReportService, RequestService, $fwCordovaToast) {

    // 图片服务器路径
    $scope.imgServerUrl = uploadUrl;

    $scope.hasMoreData = false;
    $scope.startIndex = 0;
    $scope.pageSize = 20;
    // 随访滑动
    $scope.step = 0;
    var slideReportList = $ionicSlideBoxDelegate.$getByHandle('slideReportList');
    // 用户须知倒计时
    $scope.confirmCountdown = 5;
    // 配置
    $scope.configData = {};
    // 检查列表
    $scope.checkList = [];
    $scope.checkAllList = [];
    $scope.vpInfo = new Object();
    $scope.vpList = [];
    $scope.reqId = '';
    $scope.thisResultIndex = 0;
    // 检查结果
    $scope.checkResult = {
        INDEX: 0,
        REPORT_IMAGE: ''
    }
    $scope.pageIndex = 0;
    $scope.checkDataList = [];
    // 检查报告图像
    $scope.imgCheckResult = {};
    // 就诊人ID
    $scope.vpId = $stateParams.vpid;
    // 图像容器总高度
    $scope.imgBoxTotalHeight = $(window).height() - ($rootScope.currentPlatform == "iOS" ? 42 : 22);
    // 问卷状态ID
    $scope.agreeID = '';
    // 随访患者ID
    $scope.patientId = '';
    // 知情同意书
    $scope.tipsReportMRI = '';
    // 是否加载完成
    $scope.isLoadFinish = false;

    // 注册模态窗口:检查结果
    $ionicModal.fromTemplateUrl('checkResult.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.checkResultModal = modal;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.checkResultModal.remove();
    })
    // #endregion

    // #region 滑动方法
    // 滑到上一步
    $scope.lastSlide = function () {
        slideReportList.previous();
        $scope.step = slideReportList.currentIndex();
    }
    // 滑到下一步
    $scope.nextSlide = function () {
        slideReportList.next();
        $scope.step = slideReportList.currentIndex();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        slideReportList.slide(index);
        $scope.step = slideReportList.currentIndex();
    }
    // 页面切换
    $scope.slideChanged = function () {
        $ionicScrollDelegate.resize();
        $ionicScrollDelegate.scrollTop();
    }
    // #endregion

    function loadFinish() {
        $ionicLoading.hide();
        $scope.$broadcast('scroll.infiniteScrollComplete');
        $scope.$broadcast('scroll.refreshComplete');
        $scope.isLoadFinish = true;
    }

    // 同意
    $scope.agree = function () {
        $scope.saveAgreeStatus();
    }

    $scope.saveAgreeStatus = function () {
        RequestService.saveAgreeStatus($scope.vpId).then(function (data) {
            if (data.result == 1) {
                $scope.agreeID = data.data;
                $scope.toSlide(1);
                $scope.loadReportMRIList();
            }
            else {
                $fwCordovaToast.showShortBottom(data.data);
            }
        });
    }

    // 读取检查列表
    $scope.loadReportMRIList = function () {
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        $scope.checkList = [];

        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();

        RequestService.reportMRIList($scope.vpId).then(function (data) {
            // 无效Token
            if (data.result == -2) {
                $ionicLoading.hide();
                $scope.queryPassword().then(function (data) {
                    if (data) {
                        $scope.loadReportMRIList();
                    }
                })
                return;
            }
            // 链接超时
            if (data.result == 99) {
                loadFinish();
                $fwCordovaToast.showShortBottom("连接超时，请重试");
                return;
            }
            // 请求错误
            if (data.result != 1 && data.result != -1) {
                loadFinish();
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            // 非缓存
            if (data.result == -1) {
                // 延迟1秒隐藏LOADING
                $timeout(function () {
                    if (data.is_null != 1) {
                        $scope.checkAllList = data.data;
                        for (var i = 0; i < $scope.pageSize.length; i++) {
                            if ($scope.checkAllList[i] != undefined) {
                                $scope.checkList.push($scope.checkAllList[i]);
                            }
                        }
                        if ($scope.checkList.length == $scope.pageSize) {
                            $scope.hasMoreData = true;
                        } else {
                            $scope.hasMoreData = false;
                        }
                    }
                    loadFinish();
                }, 1500);
                return;
            }
            // 正常请求
            if (data.is_null != 1) {
                $scope.checkAllList = data.data;
                for (var i = 0; i < $scope.pageSize; i++) {
                    if ($scope.checkAllList[i] != undefined) {
                        $scope.checkList.push($scope.checkAllList[i]);
                    }
                }
                if ($scope.checkList.length == $scope.pageSize) {
                    $scope.hasMoreData = true;
                } else {
                    $scope.hasMoreData = false;
                }
            }
            loadFinish();
        });
    }

    // 加载更多
    $scope.loadList = function () {
        $scope.startIndex = $scope.startIndex + $scope.pageSize;
        for (var i = $scope.startIndex; i < $scope.startIndex + $scope.pageSize; i++) {
            if ($scope.checkAllList[i] != undefined) {
                $scope.checkList.push($scope.checkAllList[i]);
            }
        }
        if ($scope.checkList.length % $scope.pageSize == 0) {
            $scope.hasMoreData = true;
        } else {
            $scope.hasMoreData = false;
        }
        loadFinish();
    }

    // 查看核磁证明结果
    $scope.reportMRIResultShow = function (index) {
        $scope.thisResultIndex = index;
        // 清空图片
        $("#imgCheckResult").prop("src", "");
        // 释放内存
        delete $scope.imgCheckResult;
        $scope.imgCheckResult = {};
        $scope.getCheckInfo(index);
    }

    // 获取核磁证明结果报告图片
    $scope.getCheckInfo = function (index) {
        $ionicLoading.show();
        var check = $scope.checkList[index];
        RequestService.reportMRIResult($scope.vpId, check.IDA).then(function (checkResultData) {
            $ionicLoading.hide();
            $scope.reqId = checkResultData.reqId;
            if (checkResultData.result == 99) {    // 链接超时
                $fwCordovaToast.showShortBottom("连接超时，请重试");
                return;
            }
            if (checkResultData.result == -2) {
                $scope.queryPassword().then(function (dataQuery) {
                    if (dataQuery) {
                        $scope.getCheckInfo(index);
                    }
                })
                return;
            }
            if (checkResultData.result != 1 && checkResultData.result != -1) {  // 请求错误
                $fwCordovaToast.showShortBottom(checkResultData.msg);
                return;
            }
            if (checkResultData.is_null == 1) { // 空结果
                $fwCordovaToast.showShortBottom("系统暂未查询到核磁证明数据，请联系物资供应处。");
                return;
            }
            $scope.checkDataList = checkResultData.data;
            $scope.checkResultModal.show();
            // 有结果 显示base64图片
            $scope.checkResult.INDEX = index;
            $scope.checkResult.REPORT_IMAGE = "data:image/jpeg;base64," + checkResultData.data[0];
            // 创建图片手势控件
            $scope.createPinchZoom();
        }, function (err) {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("连接超时，请重试");
        });
    }

    // 创建图片手势控件
    $scope.createPinchZoom = function () {
        $timeout(function () {
            var src = $("#imgCheckResultOrigin").prop("src");
            // 防止赋值不同步
            if (src == "") {
                $timeout(function () {
                    // 创建图片手势控件
                    $scope.createPinchZoom();
                }, 0);
                return;
            }
            // 无图片
            if ($("#imgCheckResult").length != 1) {
                return;
            }
            // 初始化
            if ($("#divCheckResult>#imgCheckResult").length == 0) {
                // 还原节点位置
                $("#divCheckResult").append($("#imgCheckResult"));
                // 删除控件
                //$("#divCheckResult .pinch-zoom-container").remove();
                // 插件没有destory方法 控件删除会报错 暂时扔到隐藏的div里
                $("#divTrash").append($("#divCheckResult .pinch-zoom-container"));
            }
            // 复制图片路径
            $("#imgCheckResult").prop("src", src);
            // 计算最大放大倍数 图片实际尺寸/屏幕尺寸
            var img = document.querySelector("#imgCheckResult");
            var zoomOptions = {};
            var zoomBase = Math.max(img.naturalWidth / img.width, img.naturalHeight / img.height);
            if (zoomBase > 4) {
                zoomOptions.maxZoom = zoomBase;
                zoomOptions.tapZoomFactor = zoomBase / 2;
            }
            $scope.imgCheckResult = new PinchZoom.default(img, zoomOptions);
            $scope.imgCheckResult.enable();
            console.log($scope.imgCheckResult);
        }, 0);
    }

    //下载PDF
    $scope.downloadPDF = function (reqId, index) {
        $scope.isLoadFinish = false;
        $ionicLoading.show();
        if (reqId != null && reqId.length > 0) {
            var usage = "reportMRI";
            var fileName = "";
            var fileId = "";
            var columnName = "REPORT_PDF";
            var strReportTime = new Date().Format("yyyyMMddhhmmss");

            if ($scope.checkList[index].RYRQ != null && $scope.checkList[index].RYRQ != '') {
                strReportTime = new Date(Date.parse($scope.checkList[index].RYRQ)).Format("yyyyMMddhhmmss");
            }
            fileName = $scope.checkList[index].MC + "_" + strReportTime;
            fileId = $scope.checkList[index].IDA;

            ReportService.saveDownloadRecord($scope.vpId, usage, reqId, fileName, "PDF", fileId, columnName).then(function (data) {
                $scope.downloadId = data.downloadId;
                RequestService.downloadPDF(reqId, $scope.vpId, columnName, "核磁证明", fileName).then(function (dataPdf) {
                    if (dataPdf.result == 1) {
                        ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 1);
                        var url = dataPdf.data;
                        var inapp = showInAppBrowser(url, '_system');
                        loadFinish();
                        return;
                    }
                    // 链接超时
                    else if (dataPdf.result == 99) {
                        ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 2);
                        loadFinish();
                        $fwCordovaToast.showShortBottom("连接超时，请重试");
                        return;
                    }
                    else {
                        ReportService.changeDownloadStatus($scope.vpId, $scope.downloadId, 2);
                        loadFinish();
                        $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                        return;
                    }
                }, function (errPdf) {
                    $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                    console.log(errPdf);
                });
            }, function (err) {
                $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
                console.log(err);
            });
        }
        else {
            loadFinish();
            $fwCordovaToast.showShortBottom("当前请求失败，请稍后再试");
            return;
        }
    }

    $scope.nextPage = function (pageIndex, p) {
        if (p == 'p') {
            if (pageIndex == 0) {
                $scope.pageIndex = 0;
            } else {
                $scope.pageIndex = $scope.pageIndex - 1;
            }
        }
        else {
            $scope.pageIndex = $scope.pageIndex + 1;
            var pageCount = $scope.checkDataList.length;
            if ($scope.pageIndex == pageCount) {
                $scope.pageIndex = 0;
            }
        }
        $scope.checkResult.REPORT_IMAGE = "data:image/jpeg;base64," + $scope.checkDataList[$scope.pageIndex];
        // 赋值创建手势控件
        $scope.createPinchZoom();
    }

    // 关闭检查结果
    $scope.checkResultHide = function () {
        $scope.checkResultModal.hide();
        $scope.checkResult = {
            INDEX: 0,
            REPORT_IMAGE: ''
        }
        // 清空图片
        $("#imgCheckResult").prop("src", "");
        // 释放内存
        delete $scope.imgCheckResult;
        $scope.imgCheckResult = {};
    }

    $scope.getConfig = function () {
        // 获取配置
        ReportService.getConfig($scope.vpId).then(function (data) {
            // 查询成功
            if (data.result == 1) {
                $scope.tipsReportMRI = data.data.tipsReportMRI;
                $scope.infoReportMRI = data.data.infoReportMRI;
            }
        })
    }

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'reportMRI');
        // 开启用户须知倒计时
        $interval(function () {
            $scope.confirmCountdown -= 1;
        }, 1000, 10);
        $scope.getConfig();
    })

    // 后退
    $scope.goBack = function () {
        $state.go("app.dealWithCard", { go: "reportMRI" });
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'reportMRI');
    })

    // dom准备就绪 禁用滑动
    ionic.DomUtil.ready(function () {
        slideReportList.enableSlide(false);
    })

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'reportMRI') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    })
});