﻿angular.module('fwapp.controllers')

// 搜索
.controller('SearchController', function ($scope, $rootScope, $state, $timeout, $window
, $ionicScrollDelegate, $ionicSlideBoxDelegate, $ionicModal, $ionicPlatform, $ionicPopover, $ionicLoading, $ionicPopup, $cordovaInAppBrowser, $fwCordovaToast
, HospitalService, SchedulingService, ArticleService, PersonalService) {
    // 定义搜索滑块
    var slideSearch = $ionicSlideBoxDelegate.$getByHandle('slideSearch');
    // 定义预约申请滚动条
    var scrollSearch = $ionicScrollDelegate.$getByHandle('scrollSearch');
    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        slideSearch.enableSlide(false);
    });
    // 初始滑块状态
    $scope.step = 0;
    // 搜索数据
    $scope.searchData = {};
    // 搜索关键词
    $scope.searchData.keyword = '';
    // 搜索历史记录
    $scope.searchData.history = [];
    if (localStorage.searchHistory != null && localStorage.searchHistory.length > 0) {
        $scope.searchData.history = JSON.parse(localStorage.searchHistory);
    }
    // 分类选项
    $scope.searchData.types = [{ code: '1', name: '医生', slide: [1] }, { code: '2', name: '专长/症状', slide: [2, 3] }, { code: '3', name: '健康科普', slide: [4]}];
    // 已选分类序列 默认0
    $scope.searchData.typeSelected = $scope.searchData.types[0];
    // 分类页码
    $scope.searchData.pages = {};
    // 上次搜索关键词
    $scope.searchData.lastKeywords = {};
    // 列表滚动条位置
    $scope.searchData.scrollPosition = {};
    for (var i in $scope.searchData.types) {
        $scope.searchData.pages[$scope.searchData.types[i].code] = 1;
        $scope.searchData.lastKeywords[$scope.searchData.types[i].code] = '';
        $scope.searchData.scrollPosition[$scope.searchData.types[i].code] = { left: 0, top: 0, zoom: 1 };
    }
    // 搜索结果
    $scope.searchData.info = {};
    // 注册弹出窗口：弹出搜索类别
    $ionicPopover.fromTemplateUrl('popupSearchType.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popupSearchTypePopover = popover;
    });
    // 注册模态窗口：健康科普内容
    $ionicModal.fromTemplateUrl('knowledgeDetail.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.knowledgeDetailModal = modal;
    });
    // 销毁弹出窗口
    $scope.$on('$destroy', function () {
        $scope.popupSearchTypePopover.remove();
        $scope.knowledgeDetailModal.remove();
    })
    // 滑到指定页
    $scope.toSlide = function (index) {
        // 返回的列表页滚到记录高度
        if ($scope.step == 1 || $scope.step == 2 || $scope.step == 4) {
            var code = '';
            for (var i in $scope.searchData.types) {
                if ($scope.searchData.types[i].slide.indexOf($scope.step) > -1) {
                    code = $scope.searchData.types[i].code;
                    break;
                }
            }
            $scope.searchData.scrollPosition[code] = scrollSearch.getScrollPosition();
            console.log($scope.searchData.scrollPosition["1"].top, $scope.searchData.scrollPosition["2"].top, $scope.searchData.scrollPosition["3"].top);
        }
        slideSearch.slide(index);
        $scope.step = slideSearch.currentIndex();
    }
    // 滑块切换
    $scope.slideChanged = function () {
        var stepCurrent = slideSearch.currentIndex();
        // 重新计算滚动条高度
        $ionicScrollDelegate.resize();
        // 返回的列表页滚到记录高度
        if (stepCurrent == 1 || stepCurrent == 2 || stepCurrent == 4) {
            var code = '';
            for (var i in $scope.searchData.types) {
                if ($scope.searchData.types[i].slide.indexOf(stepCurrent) > -1) {
                    code = $scope.searchData.types[i].code;
                    break;
                }
            }
            var position = $scope.searchData.scrollPosition[code]
            scrollSearch.scrollTo(position.left, position.top);
        }
        // 内容页滚到顶
        else {
            $ionicScrollDelegate.scrollTop();
        }
    }
    // 后退 重写goBack
    $scope.goBack = function () {
        // 第3页 (专长/症状对应的医师列表) 返回第2页 专长/症状
        if ($scope.step == 3) {
            $scope.toSlide(2);
        }
        // 其他页 返回首页
        else {
            // 搜索关键词
            $scope.searchData.keyword = '';
            // 已选分类序列 默认0
            $scope.searchData.typeSelected = $scope.searchData.types[0];
            // 分类页码
            $scope.searchData.pages = {};
            // 上次搜索关键词
            $scope.searchData.lastKeywords = {};
            // 列表滚动条位置
            $scope.searchData.scrollPosition = {};
            for (var i in $scope.searchData.types) {
                $scope.searchData.pages[$scope.searchData.types[i].code] = 1;
                $scope.searchData.lastKeywords[$scope.searchData.types[i].code] = '';
                $scope.searchData.scrollPosition[$scope.searchData.types[i].code] = { left: 0, top: 0, zoom: 1 };
            }
            // 搜索结果
            $scope.searchData.info = {};
            //$rootScope.goBack();
            $state.go('app.home');
        }
    }
    // 显示搜索类别
    $scope.showSearchTypePopover = function ($event) {
        $scope.popupSearchTypePopover.show($event);
    }
    // 选择搜索类别
    $scope.selectType = function (index) {
        if ($scope.searchData.typeSelected != $scope.searchData.types[index]) {
            $scope.searchData.typeSelected = $scope.searchData.types[index];
        }
        $scope.popupSearchTypePopover.hide();
    }
    // 切换搜索类别
    $scope.changeType = function (index) {
        if ($scope.searchData.typeSelected != $scope.searchData.types[index]) {
            $scope.searchData.typeSelected = $scope.searchData.types[index];
            $scope.searchSubmit();
        }
    }
    // 搜索提交
    $scope.searchSubmit = function (isMore) {
        // 2021-12-06 18:07:45 HM 如果搜索关爱模式，提示是否切换
        if (($scope.searchData.keyword == "关爱模式" || $scope.searchData.keyword == "亲情版" || $scope.searchData.keyword == "关爱版" || $scope.searchData.keyword == "关怀版") && $rootScope.checkLogin() && $rootScope.elderly != true) {
            $state.go("app.setting");
            return;
        }

        var code = $scope.searchData.typeSelected.code;
        console.log(isMore, $scope.searchData.keyword, code, $scope.searchData.pages[code]);
        // 如果无结果 或 关键词变更 或 获取更多 提交搜索
        if ($scope.searchData.info[code] == null || $scope.searchData.lastKeywords[code] != $scope.searchData.keyword || isMore) {
            $ionicLoading.show();
            // 搜索历史记录
            if ($scope.searchData.keyword != null && $scope.searchData.keyword.length > 0) {
                // 删除原有关键词
                for (var i in $scope.searchData.history) {
                    if ($scope.searchData.history[i] == $scope.searchData.keyword) {
                        $scope.searchData.history.splice(i, 1);
                    }
                }
                // 在首位追加关键词
                $scope.searchData.history.unshift($scope.searchData.keyword);
                // 仅保留最近10次
                if ($scope.searchData.history.length > 10) {
                    $scope.searchData.history.length = 10;
                }
                localStorage.searchHistory = JSON.stringify($scope.searchData.history);
            }
            // 获取更多
            if (isMore) {
                // 保证页码不超过总页数
                if ($scope.searchData.info[code].pageNum < $scope.searchData.info[code].pageCount) {
                    $scope.searchData.pages[code]++;
                }
                else {
                    return;
                }
            }
            // 重新加载
            else {
                $scope.searchData.pages[code] = 1;
            }
            HospitalService.search($scope.searchData.keyword, code, $scope.searchData.pages[code]).then(function (data) {
                // 获取成功
                if (data.result == 1) {
                    // 获取更多
                    if (isMore) {
                        $scope.searchData.info[code].totalCount = data.data.totalCount;
                        $scope.searchData.info[code].pageCount = data.data.pageCount;
                        $scope.searchData.info[code].pageNum = data.data.pageNum;
                        $scope.searchData.info[code].pageSize = data.data.pageSize;
                        for (var i in data.data.page) {
                            $scope.searchData.info[code].page.push(data.data.page[i]);
                        }
                        $scope.$broadcast('scroll.infiniteScrollComplete');
                        $scope.$broadcast('scroll.refreshComplete');
                    }
                    // 首次获取
                    else {
                        $scope.searchData.info[code] = {};
                        $scope.searchData.info[code] = data.data;
                        $scope.searchData.scrollPosition[code] = { left: 0, top: 0, zoom: 1 };
                        $ionicScrollDelegate.scrollTop();
                    }
                    // 更新上次搜索关键词
                    $scope.searchData.lastKeywords[code] = $scope.searchData.keyword;
                    console.log($scope.searchData);
                    // 当前页面不符 跳转到对应结果页
                    if ($scope.step != $scope.searchData.typeSelected.slide[0]) {
                        $scope.toSlide($scope.searchData.typeSelected.slide[0]);
                    }
                }
                // 获取失败
                else {
                    $fwCordovaToast.showShortBottom(data.msg);
                }
                $ionicLoading.hide();
            }, function (resp) {
                $ionicLoading.hide();
                $fwCordovaToast.showShortBottom("加载失败, 请检查网络");
            })
        }
        // 仅跳转
        else {
            $scope.toSlide($scope.searchData.typeSelected.slide[0]);
        }
    }
    // 搜索更多
    $scope.searchMore = function () {
        console.log($scope.searchData.typeSelected.code, $scope.searchData.pages[$scope.searchData.typeSelected.code]);
        $scope.searchSubmit(true);
    }
    // 搜索历史
    $scope.searchHistory = function (keyword) {
        $scope.searchData.keyword = keyword;
        $scope.searchSubmit();
    }
    // 清空搜索历史记录
    $scope.emptyHistory = function () {
        $scope.searchData.history.length = 0;
        localStorage.removeItem('searchHistory');
        $ionicScrollDelegate.resize();
    }
    // 跳转到医师介绍
    $scope.doctorInfo = function (doctorId, doctorCode, doctorName, doctorLevel) {
        $state.go("app.doctorInfo", { doctorId: doctorId, deptId: '', doctorCode: doctorCode, deptName: '', doctorName: doctorName, doctorLevel: doctorLevel });
    }
    // 获取指定科别医师列表
    $scope.getDoctorList = function (speciality) {
        console.log(speciality);
        $ionicLoading.show();
        // 获取指定科别医师列表
        SchedulingService.getDoctorListBySpeciality(speciality).then(function (data) {
            // 查询成功
            if (data.result == 1) {
                $scope.searchData.info.doctorList = [];
                $scope.searchData.info.doctorList = data.data;
                $scope.toSlide(3);
            }
            // 无结果
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            $ionicLoading.hide();
        }, function (data) {
            $ionicLoading.hide();
        })
    }
    // 显示健康科普详情
    $scope.knowledgeDetailShow = function (articleId) {
        console.log(articleId);
        $ionicLoading.show();
        ArticleService.detail(articleId).then(function (data) {
            if (data.result == 1) {
                $scope.articleDetail = {};
                if (data.data.ExternalLink == '') {
                    $scope.articleDetail = data.data;
                    $scope.knowledgeDetailModal.show();
                }
                else {
                    //var option = { location: 'yes', clearcache: 'no', toolbar: 'yes' }
                    //$cordovaInAppBrowser.open(data.data.ExternalLink, '_blank', option).then(function (event) { });
                    //2023.7.31 新插件原有调用方式参数不生效
                    var inapp = showInAppBrowser(data.data.ExternalLink, '_blank');
                    $ionicLoading.hide();
                    return;
                }
            }
            else {
                $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
            }
            $ionicLoading.hide();
        }, function (data) {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
        })
    }
    // 显示健康科普详情
    $scope.knowledgeDetailHide = function () {
        $ionicScrollDelegate.resize();
        $scope.knowledgeDetailModal.hide();
        $scope.articleDetail = {};
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'search');
        // 搜索框自动获得焦点
        //$timeout(function () {
        document.getElementById("searchInput").focus();
        //}, 500);
        /*
        // 获取搜索分类
        HospitalService.searchType().then(function (data) {
        // 获取成功
        if (data.result == 1) {
        $scope.searchData.types = data.data;
        // 已选分类序列 默认0
        $scope.searchData.typeSelected = $scope.searchData.types[0];
        // 分类页码
        $scope.searchData.pages = {};
        for(var i in data.data){
        $scope.searchData.pages[data.data[i].code] = 1;
        }
        }
        // 获取失败
        else {
        //$fwCordovaToast.showShortBottom(data.msg);
        }
        })
        */
    });

    // 页面离开之前
    $scope.$on('$ionicView.beforeLeave', function () {
        // 解除返回键绑定
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'search') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
})