﻿angular.module('fwapp.controllers')

// 个人设置
.controller('SettingController', function ($scope, $rootScope, $state, $fwCordovaToast, $ionicLoading, $ionicPlatform, $ionicPopup, PersonalService) {
    // 检查登录状态
    //$rootScope.checkLogin();
    // 如果没登录 扔出去
    if (localStorage.currentAccountId.length == 0) {
        $state.go("login");
        return;
    }

    $scope.setting = {};

    // 字体大小
    $scope.elderly = {};
    $scope.elderly.sizeRankNum = $rootScope.getSizeRankNum();
    $scope.elderly.switch = $rootScope.elderly;
    $scope.english = {};
    $scope.english.switch = localStorage.isEnglishMode == 1 ? true : false;

    $scope.toggleSetting = function (index) {
        if ($scope.setting.length < index || $scope.setting[index] == null || typeof ($scope.setting[index].configValue) != "boolean") {
            return;
        }
        // 不允许取消
        if ($scope.setting[index].configLevel == "1" && $scope.setting[index].configValue) {
            //$fwCordovaToast.showLongBottom("为确保您的就诊过程顺利，重要消息推送不支持主动关闭");
            var alertPopup = $ionicPopup.alert({
                title: '提示',
                template: '为确保您的就诊过程顺利，重要消息推送不支持主动关闭',
                okText: '确认'
            });
            return;
        }
        $scope.saveSetting($scope.setting[index].configKey, !$scope.setting[index].configValue, index);
    }

    $scope.saveSetting = function (key, value, index) {
        $ionicLoading.show();
        PersonalService.saveSetting(key, value).then(function (data) {
            $ionicLoading.hide();
            // 保存成功
            if (data.result == 1) {
                $scope.setting[index].configValue = value;
            }
            // 保存失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    }

    // 修改字体设置
    $scope.$watch('elderly.sizeRankNum', function (newValue, oldValue) {
        if (newValue == oldValue) {
            return;
        }

        if ($rootScope.elderly == true || $rootScope.elderly == 'true') {
            if ($scope.elderly.sizeRankNum == 1) {
                // 如果是1号字，提示是否切换至普通版本
                var confirmPopup = $ionicPopup.confirm({
                    title: "切换标准版",
                    template: "您将切换至标准版，是否要进行切换？",
                    cancelText: '稍后再说',
                    okText: '立即切换'
                });
                // 立即填写, 跳转
                confirmPopup.then(function (res) {
                    if (res) {
                        $scope.changeElderlyCommon(false, "S");
                    }
                    else {
                        $scope.elderly.sizeRankNum = $rootScope.getSizeRankNum();
                    }
                })
            }
            else if ($scope.elderly.sizeRankNum == 2) {
                $scope.changeElderlyCommon(true, "M");
            }
            else if ($scope.elderly.sizeRankNum == 3) {
                $scope.changeElderlyCommon(true, "L");
            }
            else if ($scope.elderly.sizeRankNum == 4) {
                $scope.changeElderlyCommon(true, "XL");
            }
        }
        else {
            if ($scope.elderly.sizeRankNum == 1) {
                $scope.changeElderlyCommon(false, "S");
            }
            else if ($scope.elderly.sizeRankNum > 1) {
                var confirmPopup = $ionicPopup.confirm({
                    title: "开启关爱模式",
                    template: "您将切换至关爱模式，大字体、大图标，功能更简洁。",
                    cancelText: '稍后再说',
                    okText: '立即切换'
                });
                // 立即填写, 跳转
                confirmPopup.then(function (res) {
                    if (res) {
                        if ($scope.elderly.sizeRankNum == 2) {
                            $scope.changeElderlyCommon(true, "M");
                        }
                        else if ($scope.elderly.sizeRankNum == 3) {
                            $scope.changeElderlyCommon(true, "L");
                        }
                        else if ($scope.elderly.sizeRankNum == 4) {
                            $scope.changeElderlyCommon(true, "XL");
                        }
                    }
                    else {
                        $scope.elderly.sizeRankNum = $rootScope.getSizeRankNum();
                    }
                })
            }
        }
    })

    // 加字号
    $scope.sizePlus = function () {
        if ($scope.elderly.sizeRankNum == 4) {
            return;
        }
        else {
            $scope.elderly.sizeRankNum++;
        }
    }

    // 减字号
    $scope.sizeReduce = function () {
        if ($scope.elderly.sizeRankNum == 1) {
            return;
        }
        else {
            $scope.elderly.sizeRankNum--;
        }
    }

    // 公共切换模式
    $scope.changeElderlyCommon = function (elderly, sizeRank) {
        // 可以改字号
        $rootScope.sizeRank = sizeRank;
        localStorage.sizeRank = $rootScope.sizeRank;

        if (elderly == true) {
            // 2023-9-26 17:37:36 HM 得把英文版本给关上
            localStorage.isEnglishMode = 0;
        }

        // 这个是异步的
        PersonalService.saveSetting("PUSH_ELDERLY", elderly).then(function (data) {
            PersonalService.saveSetting("APP_SIZE_RANK", sizeRank).then(function (data) {
                // 如果不一样，需要重新加载页面
                if (eval($rootScope.elderly) != elderly) {
                    $state.go("app.home");
                }
            });
        });
    }

    // 切换关爱模式
    $scope.elderlySwitch = function () {
        $scope.elderly.switch = !$scope.elderly.switch;
        // 切换至适老版
        if ($scope.elderly.switch){
            $scope.changeElderlyCommon(true, "L");
        }
        else {
            $scope.changeElderlyCommon(false, "S");
        }
    }

    // 切换英文模式
    $scope.englishSwitch = function () {
        $scope.english.switch = !$scope.english.switch;
        localStorage.isEnglishMode = $scope.english.switch ? 1 : 0;
        $rootScope.isEnglishMode = localStorage.isEnglishMode;
        $state.go("app.home");
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        $ionicLoading.show();
        // 绑定返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'setting');

        PersonalService.getSetting().then(function (data) {
            $ionicLoading.hide();
            // 获取成功
            if (data.result == 1) {
                //$scope.setting = data.data;
                $scope.setting = data.configDic;
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    });

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        // 解除返回键绑定
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'setting') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
})