﻿angular.module('fwapp.controllers')

.controller('SmokingController', function ($scope, $rootScope, $state, $stateParams, $timeout,
    VisitPatientService, HealthService, SrvyService,
    $ionicSlideBoxDelegate, $ionicScrollDelegate, $ionicLoading, $ionicPlatform, $ionicPopup, $ionicActionSheet, $ionicModal, $ionicPopover,
    $cordovaDatePicker, $fwCordovaToast) {

    // 就诊人ID
    $scope.vpId = $stateParams.vpid;
    // 就诊人信息
    $scope.vpInfo = new Object();
    // 就诊人列表
    $scope.vpList = [];

    // 问卷调查信息
    $scope.srvyInfo = [];
    // 个人填写问卷信息
    $scope.selfSrvyList = [];

    // 模板内容
    $scope.tmpl = new Object();
    // 模板信息
    $scope.tmplInfo = new Object();
    // 总题数
    $scope.qstnCount = 0;
    // 问卷结果
    $scope.srvyResult = new Object();
    // 当前问卷ID
    $scope.currentRec = new Object();
    // 反馈列表(评价)
    $scope.fbResultList = new Object();
    // 反馈列表(评分)
    $scope.fbCalcList = new Object();
    // 反馈TAB页
    $scope.feebbackTab = 0;

    // 注册模态窗口：量表评估
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('srvyTmpl.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.srvyModal = modal;
    });

    // 注册模态窗口：建议反馈
    $ionicModal.fromTemplateUrl($rootScope.getElderlyUrl('feedback.html'), {
        scope: $scope
    }).then(function (modal) {
        $scope.feedbackModal = modal;
    });

    // 注册弹出菜单：就诊人列表
    $ionicPopover.fromTemplateUrl('pop_vplist.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popVplist = popover;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.srvyModal.remove();
        $scope.feedbackModal.remove();
    })

    // 切换就诊人
    $scope.changeVp = function (vpid) {
        $scope.vpId = vpid;
        $scope.vpInfo = new Object();
        $scope.loadVPInfo();
        $scope.loadSrvyInfo();
    }

    //#region 问卷信息
    // 读取问卷信息
    $scope.loadSrvyInfo = function () {
        $scope.srvyInfo = [];
        SrvyService.srvyInfo('FAGERSTORM', $scope.vpId).then(function (data) {
            if (data.result == 1) {
                $scope.srvyInfo.push(data.data);
            }
            SrvyService.selfSrvyList('FAGERSTORM', $scope.vpId).then(function (sData) {
                $scope.selfSrvyList = sData.data;
            });
        })
    }

    // 显示问卷填写信息
    $scope.showTmpl = function (tmplId, recId, available) {
        $scope.currentRec = recId;
        $scope.loadTmpl(tmplId);
    }

    // 加载模板信息
    $scope.loadTmpl = function (tmplId) {
        $scope.isLoadFinish_Tmpl = false;
        $ionicLoading.show();

        $scope.tmpl = new Object();

        if ($scope.tmplInfo.display == "SLIDE") {
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').update();
            $ionicSlideBoxDelegate.$getByHandle('slideTmplList').slide(0);
        }

        // 加载模板
        SrvyService.items(tmplId).then(function (data) {
            $scope.tmpl = data.QSTN_LIST;
            $scope.tmplInfo.name = data.TMPL_NAME;
            $scope.tmplInfo.id = data.TMPL_ID;
            $scope.tmplInfo.display = data.TMPL_DISPLAY;
            $scope.qstnCount = $scope.tmpl.length;

            $scope.isLoadFinish_Tmpl = true;

            $ionicScrollDelegate.resize();
            $ionicScrollDelegate.scrollTop();

            if ($scope.tmplInfo.display == "SLIDE") {
                $timeout(function () {
                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').enableSlide(false);

                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').update();
                    $ionicSlideBoxDelegate.$getByHandle('slideTmplList').slide(0);
                    $scope.cQstn = 0;

                    $ionicLoading.hide();
                }, 500);
            } else {
                $ionicLoading.hide();
            }
        })

        $scope.srvyList = [];
        $scope.srvyModal.show();
    }

    // 隐藏问卷填写信息
    $scope.hideTmpl = function () {
        $scope.srvyModal.hide();
    }

    // 保存问卷结果
    $scope.saveResult = function () {
        $ionicLoading.show();
        SrvyService.saveRecord($scope.tmplInfo.id, $scope.currentRec, $scope.vpId, $.param($scope.srvyResult)).then(function (data) {
            if (data.result == 1) {
                if (data.nTmplId != '') {
                    $scope.loadTmpl(data.nTmplId);
                } else {
                    $fwCordovaToast.showShortBottom("问卷填写完成！");

                    // 初始化题目信息（防止再次进入显示混乱）
                    $scope.tmpl = new Object();
                    $scope.tmplInfo = new Object();
                    $scope.qstnCount = 0;

                    $scope.hideTmpl();
                    $scope.showFeedback(data.recId);
                    $scope.loadSrvyInfo();
                }
            } else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            $ionicLoading.hide();
        });
    }

    // 显示反馈信息
    $scope.showFeedback = function (recId) {
        SrvyService.getFeedBack(recId).then(function (data) {
            $scope.tmpl = data.QSTN_LIST;
            $scope.srvyResult = data.REC_QSTN;
            $scope.fbResultList = data.FB_RESULT_LIST;
            $scope.fbCalcList = data.FB_CALC_LIST;
            $scope.fbResultCount = Object.getOwnPropertyNames($scope.fbResultList).length;

            $ionicScrollDelegate.$getByHandle("scrollFeedback").resize();
            $ionicScrollDelegate.$getByHandle("scrollFeedback").scrollTop();
            $scope.feebbackTab = 0;

            $ionicSlideBoxDelegate.$getByHandle('slideFeedback').enableSlide(false);

            $scope.feedbackModal.show();
        });
    }

    // 切换
    $scope.feedbackTabChange = function (index) {
        $scope.feebbackTab = index;
        $ionicSlideBoxDelegate.$getByHandle('slideFeedback').slide(index);

        $ionicScrollDelegate.$getByHandle("scrollFeedback").resize();
        $ionicScrollDelegate.$getByHandle("scrollFeedback").scrollTop();
    }

    // 隐藏反馈信息
    $scope.hideFeedback = function () {
        $scope.feedbackModal.hide();
        $scope.tmpl = new Object();
        $scope.srvyResult = new Object();
    }

    // 显示个人填写的问卷信息
    $scope.showTmplSelf = function (srvy) {
        if (srvy.SRVY_STATUS == 1) {
            $scope.showFeedback(srvy.REC_ID);
        } else {
            $scope.showTmpl(srvy.LAST_TMPL_ID, srvy.REC_ID, true);
        }
    }

    //#endregion

    //#region 就诊人那堆东西，粘贴来粘贴去的
    // 读取就诊人信息
    $scope.loadVPInfo = function () {
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
            }
        })
    }

    // 加载就诊人列表
    $scope.loadVpList = function () {
        // 就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                $scope.vpList = data.data;
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    }

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        $scope.vpList = [];
        // 获取就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                // 若无就诊人
                if (data.data.length == 0) {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("未找到绑定的就诊人信息");
                    return;
                }

                // 第一就诊人
                var vpid = "";
                for (var i = 0; i < data.data.length; i++) {
                    $scope.vpList.push(data.data[i]);
                    if (vpid == "") {
                        vpid = data.data[i].VISIT_PATIENT_ID;
                    }
                }

                // 若参数无就诊人信息
                if ($scope.vpId == "") {
                    // 默认第一就诊人
                    $scope.vpId = vpid;
                }

                $scope.loadVPInfo();
                $scope.loadSrvyInfo();
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    })

    // 显示弹出菜单
    $scope.openPopoverVpList = function ($event) {
        $scope.popVplist.show($event);
    }
    //#endregion

    $scope.goBack = function () {
        $state.go('app.health', { vpid: $scope.vpId, from: $stateParams.from });
    }

    // 页面进入
    $scope.$on('$ionicView.enter', function () {
        // 绑定返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            if ($scope.step == 0) {
                if ($stateParams.from == 'flupSrvy') {
                    // 2022-4-8 16:21:28 hzg 专病随访->健康记录->吸烟
                    $state.go('app.health', { vpid: $scope.vpId, from: 'flupSrvy' });
                } else {
                    $rootScope.goBack();
                }
            }
            else {
                $scope.goBack();
            }
            e.preventDefault();
            return false;
        }, 135, 'smoking');
    })

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'smoking') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    })
});