﻿angular.module('fwapp.controllers')

.controller('SurgicalController', function ($scope, $rootScope, $state, $stateParams, $timeout, $ionicPopup, $ionicModal, $ionicLoading, $ionicPopover,
    VisitPatientService, RequestService, $fwCordovaToast, $ionicPlatform) {
    // 检查登录状态
    $rootScope.checkLogin();

    // 加载结果
    $scope.loadResult = 0;
    // 就诊人列表
    $scope.vpList = [];
    // 候诊列表
    $scope.surgicalList = [];

    // 初始化
    $scope.loadSurgical = function () {
        $ionicLoading.show();
        // 直接广播刷新完毕，使下拉刷新隐藏
        $scope.$broadcast('scroll.infiniteScrollComplete');
        $scope.$broadcast('scroll.refreshComplete');
        // 就诊人列表
        VisitPatientService.visitPatientList().then(function (vpdata) {
            if (vpdata.result != 1) {
                $fwCordovaToast.showShortBottom(vpdata.msg);
                $ionicLoading.hide();
                return;
            }
            // 无就诊人
            if (vpdata.data.length == 0) {
                $scope.loadResult = 1;
                $ionicLoading.hide();
                return;
            }
            // 就诊人列表赋值
            $scope.vpList = vpdata.data;
            // 判断是否绑卡
            var hasBindCard = false;
            for (var i = 0; i < $scope.vpList.length; i++) {
                if ($scope.vpList[i].HIS_CARD_NUM != '') {
                    hasBindCard = true;
                }
            }
            // 无绑卡就诊人
            if (!hasBindCard) {
                $scope.loadResult = 2;
                // 隐藏LOADING页面
                $ionicLoading.hide();
                return;
            }

            RequestService.surgicalState().then(function (data) {

                // 若直接缓存结果
                if (data.result == -1) {
                    // 延迟1秒隐藏LOADING（假装我有很认真的查询）
                    $timeout(function () {
                        // 无记录处理
                        if (data.is_null == 1) {
                            $scope.surgicalList = [];
                            $scope.loadResult = 3;
                        } else {
                            // 有记录
                            $scope.surgicalList = data.data;
                            $scope.loadResult = 0; 

                            console.log($scope.surgicalList);
                        }
                        $ionicLoading.hide();
                    }, 1000);
                    return;
                }

                // 非缓存处理 隐藏LOADING页面
                $ionicLoading.hide();

                if (data.result == 99) {    // 链接超时
                    $scope.surgicalList = [];
                    $fwCordovaToast.showShortBottom("连接超时，请重试");
                    return;
                }
                if (data.result == -2) {
                    $scope.queryPassword().then(function (data) {
                        if (data) {
                            $scope.loadSurgical();
                        }
                    })
                    return;
                }
                if (data.result != 1 && data.result != -1) {  // 请求错误
                    $scope.surgicalList = [];
                    $fwCordovaToast.showShortBottom(data.msg);
                    return;
                }

                if (data.is_null == 1) { // 空结果
                    $scope.surgicalList = [];
                    $scope.loadResult = 3;
                    return;
                }

                $scope.surgicalList = data.data;
                $scope.loadResult = 0; 
            })
        })
    }

    $scope.goBack = function () {
        $state.go('app.home');
    }

    // 日期格式化
    $scope.getDateFormat = function (strDate, format) {
        return new Date(strDate.replace(/-/g, '/')).Format(format);
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        // 获取检查列表
        $scope.loadSurgical();
        // 返回键
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'surgical');
    });

    // 页面退出，解除后退绑定
    // 可能绑定的事件得改
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'surgical') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });
});