﻿angular.module('fwapp.controllers')

.controller('UploadMIController', function ($scope, $rootScope, $state, $http, $window, $ionicPopup, $ionicLoading, $ionicModal, $ionicScrollDelegate, $ionicPlatform, $ionicSlideBoxDelegate
, $cordovaAppVersion, $cordovaFileTransfer, $cordovaFileOpener2, $fwCordovaToast, $cordovaDatePicker, $timeout, $cordovaCamera, $cordovaImagePicker, $ionicActionSheet
, VisitPatientService, CasePrintService, OlTreatRecipeService, RequestService) {

    // 检查登录状态
    $rootScope.checkLogin();
    // 医保信息
    $scope.MI = {};

    $scope.imgServerUrl = uploadUrl;

    // 注册模态窗口：医保认证帮助
    $ionicModal.fromTemplateUrl('MI_HELP.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.MIHelpModal = modal;
    });

    // 图片上传选择ActionSheet显示
    $scope.imgAddActionSheet = function (type) {
        // type == 0 --> 头像面, type == 1 --> 国徽面, type == 2 --> 户口簿, type == -1 --> 正面医保卡照片, type == -2 --> 手持医保卡照片,
        // 显示ActionSheet
        $ionicActionSheet.show({
            titleText: "请选择上传图片方式",
            buttons: [
                { text: '<i class="icon ion-camera"></i> 拍照上传' },
                { text: '<i class="icon ion-image"></i> 由相册选择' }
            ],
            cancelText: "取消",
            cancel: function () {
                return true;
            },
            buttonClicked: function (index) {
                switch (index) {
                    case 0:     // 拍照上传
                        $scope.cameraImg(type);
                        return true;
                        break;
                    case 1:     // 由相册选择
                        $scope.selectImg(type);
                        return true;
                        break;
                }
            }
        })
    }

    // 由相册选择图片
    $scope.selectImg = function (type) {
        var options = {
            quality: 50,
            maximumImagesCount: 1,
            width: 0,
            height: 0
        };
        $cordovaImagePicker.getPictures(options).then(function (imageDataList) {
            console.log(imageDataList[0]);
            $scope.uploadImg(imageDataList[0], type);
        }, function (err) {
        });
    }

    // 调用摄像头拍照
    $scope.cameraImg = function (type) {
        var options = {
            quality: 50,
            destinationType: Camera.DestinationType.FILE_URI,
            sourceType: Camera.PictureSourceType.CAMERA,
            allowEdit: false,
            encodingType: Camera.EncodingType.JPEG,
            popoverOptions: CameraPopoverOptions,
            saveToPhotoAlbum: false,
            correctOrientation: true
        };
        $cordovaCamera.getPicture(options).then(function (imageData) {
            console.log(imageData);
            $scope.uploadImg(imageData, type);
        }, function (err) {
        });
    }

    // 上传图片
    $scope.uploadImg = function (imageData, type) {
        // 上传图片参数
        var options = new FileUploadOptions();
        options.fileKey = "fileAddPic";
        options.fileName = imageData.substr(imageData.lastIndexOf("/") + 1);
        options.mimeType = "text/plain";
        options.params = { urlExt: "CASE_PRINT", ifDES: "1" };
        // 上传图片路径
        var uri = encodeURI(uploadUrl + "/UploadHandler.ashx");

        // 显示上传等待
        $ionicLoading.show();
        // 上传图片
        //$fwCordovaToast.showShortBottom(uri);
        $cordovaFileTransfer.upload(uri, imageData, options, true).then(function (result) {
            if (result.response == undefined) {
                $ionicLoading.hide();
                $fwCordovaToast.showLongBottom("上传失败");
            }
            else {
                if (result.response.indexOf('上传失败') >= 0) {
                    $ionicLoading.hide();
                    $fwCordovaToast.showLongBottom(result.response);
                }
                else {
                    $ionicLoading.hide();
                    if (type == -1) {
                        $scope.MI.MI_IMG_URL = result.response;
                    }
                    else {
                        $scope.MI.MI_PATIENT_IMG_URL = result.response;
                    }
                }
            }
        }, function (error) {
            // 错误处理
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("上传失败，错误：" + angular.toJson(error) + "。请稍后重试");
            console.log(angular.toJson(error));
        }, function (progress) {
            ;
        });
    }

    // 删除图片
    $scope.detUrl = function (index) {
        // url清空
        if (index == -1) {
            $scope.MI.MI_IMG_URL = "";
        }
        else {
            $scope.MI.MI_PATIENT_IMG_URL = "";
        }
    }

    // 医保部分提交
    $scope.addMIPatientInfo = function () {
        // 2024-4-19 14:58:08 ZZL #hzfwx-908 添加证件照校验
        if (window.cordova && ($scope.MI.MI_IMG_URL == undefined || $scope.MI.MI_PATIENT_IMG_URL == undefined)) {
            $fwCordovaToast.showShortBottom("请上传您的证件照片");
            return;
        }

        // 2024-4-22 14:37:43 ZZL #hzfwx-908 视频问诊医保类型跳过首信验证
        $scope.addMIPatientInfoImg();
        //if ($scope.isPatientMI == true) {
        //    $ionicLoading.show();
        //    // 2024-2-23 13:46:25  ZZL hzfwx-714 三代医保卡升级，无需填写医保卡号，默认传""
        //    // 验证医保首信接口
        //    RequestService.verifyMIPatientCode($scope.MI.VISIT_PATIENT_ID, $scope.MI.MI_PATIENT_CODE).then(function (data) {
        //        console.log(data);
        //        if (data.result == 99) {    // 链接超时
        //            $ionicLoading.hide();
        //            $ionicPopup.alert({
        //                title: "提示",
        //                template: "连接超时，请重试",
        //                okText: "确定"
        //            });
        //            return;
        //        }

        //        if (data.result != 1 || data.is_null == 1) {
        //            $ionicLoading.hide();
        //            $ionicPopup.alert({
        //                title: "提示",
        //                template: "网络错误，请重试",
        //                okText: "确定"
        //            });
        //            return;
        //        }

        //        // 首信验证失败
        //        if (data.data[0].VERIFY_STATUS == 0) {
        //            $ionicLoading.hide();
        //            $ionicPopup.alert({
        //                title: "提示",
        //                template: data.verifyMsg,
        //                okText: "确定"
        //            });
        //            return;
        //        }

        //        // 这里有可能是院内的ybkh
        //        $scope.MI.MI_PATIENT_CODE = data.data[0].YBKH;

        //        $ionicLoading.hide();
        //        $scope.addMIPatientInfoImg(data.data[0].REQUEST_ID);
        //    })
        //}
        //else {
        //    $scope.addMIPatientInfoImg();
        //}
    }

    // 提交医保卡照片，这里提出个公共方法
    $scope.addMIPatientInfoImg = function (rid) {
        $ionicLoading.show();
        OlTreatRecipeService.addMIPatientInfo($scope.MI.VISIT_PATIENT_ID, $scope.MI.REQUESTID, $scope.MI.IS_PATIENT_MI,
            $scope.MI.MI_PATIENT_CODE, $scope.MI.MI_IMG_URL, $scope.MI.MI_PATIENT_IMG_URL, rid).then(function (result) {
            $ionicLoading.hide();
            if (result.result == 1) {
                // 保存成功
                $scope.goBack("submit");
            }
            // 这里应该是 院内医保号 != 患者手输入号
            else {
                $fwCordovaToast.showShortBottom(result.msg);
            }
        })
    }

    // 帮助相关
    $scope.MIHelpModalShow = function () {
        $scope.MIHelpModal.show();
    }
    $scope.MIHelpModalHide = function () {
        $scope.MIHelpModal.hide();
    }

    // 返回
    $scope.goBack = function (type) {
        var data = {
            type: type
        };

        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'uploadMIBackbutton') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
        $scope.$emit("uploadMIHide", data);
    }

    // 由父级作用于传来的
    $scope.$on('uploadMIShow', function (event, data) {
        // 初始化
        $scope.MI = {};
        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();

        // 赋值
        $scope.MI = data;

        // 2020-10-23 19:12:04 处理返回键事件
        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
        }, 250, 'uploadMIBackbutton');
    });
});