﻿angular.module('fwapp.services')

// 在线问诊/复诊诊疗
.service('ConsultationService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查服务状态
        checkServerStatus: function () {
            return BaseService.post("/Consultation/CheckServerStatus");
        },
        // 获取医师列表
        getDoctorList: function (showAvailable, doctorSearchName, divisionCode, doctorDivisionCode, doctorType, groupCode, groupType) {
            return BaseService.post("/Consultation/GetDoctorList", { showAvailable: showAvailable, doctorSearchName: doctorSearchName, divisionCode: divisionCode, doctorDivisionCode: doctorDivisionCode, doctorType: doctorType, groupCode: groupCode, groupType, groupType });
        },
        // 获取医师列表V2
        getDoctorListV2: function (showAvailable, doctorSearchName, divisionCode, doctorDivisionCode, doctorType, groupCode, groupType, videoType) {
            return BaseService.post("/Consultation/GetDoctorListV2", { showAvailable: showAvailable, doctorSearchName: doctorSearchName, divisionCode: divisionCode, doctorDivisionCode: doctorDivisionCode, doctorType: doctorType, groupCode: groupCode, groupType, groupType, videoType: videoType });
        },
        // 提交支付申请
        submitApply: function (vpId, treatDoctorId, isConsultation, consultationWay, isPatientMI) {
            var deferred = $q.defer();

            // 异步等待通用方法
            function RespApply(applyData, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/RespApply',
                        data: { applyId: applyData.data },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            // 伪造一个SubmitApply的返回值
                            applyData.status = 2;// 已走完轮询，伪支付成功
                            deferred.resolve(applyData);
                        }
                        else {
                            if (count <= 10) {
                                RespApply(applyData, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99, mgs: "网络超时，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/SubmitApply',
                data: { vpId: vpId, treatDoctorId: treatDoctorId, isConsultation: isConsultation, consultationWay: consultationWay, isPatientMI: isPatientMI },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                else {
                    // 不收费，这里需要等轮询
                    if (data.treatFee == -1) {
                        RespApply(data, 0);
                    }
                    else {
                        deferred.resolve(data);
                    }
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;

            // return BaseService.post("/Consultation/SubmitApply", { vpId: vpId, treatDoctorId: treatDoctorId, isConsultation: isConsultation, consultationWay: consultationWay });
        },
        visitPatientInfo: function (vpId) {
            return BaseService.post("/Consultation/VisitPatientInfo", { vpId: vpId });
        },
        // 获取会话状态
        consultationStatus: function (vpId, doctorCode, treatType, verifyFlag, examListInfo) {
            return BaseService.post("/Consultation/ConsultationStatus", { vpId: vpId, doctorCode: doctorCode, treatType: treatType, verifyFlag: verifyFlag, examListInfo: examListInfo });
        },
        // 获取支付结果
        respApply: function (applyId, infomationId) {
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespApply(applyId, infomationId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/RespApply',
                        data: { applyId: applyId, infomationId: infomationId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespApply(applyId, infomationId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/RespApply',
                data: { applyId: applyId, infomationId: infomationId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1) {
                    RespApply(applyId, infomationId, 0);
                }
                else if (data.result == 0) {    // 若返回缓存结果为空 || 报错
                    deferred.resolve(data);
                }
                else if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    RespApply(applyId, infomationId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取配置
        getConfig: function () {
            return BaseService.post("/Consultation/GetConfig");
        },
        // 上传病情描述
        submitInfomation: function (disease, infomation, help, visitHospital, isDrug, drug, isAllergy, allergy, isPreviousDisease, previousDisease, purpose, visitPatientId, doctorCode, infomationId, must, isGuardian, guardianName, guardianPhone, currentAreaCode, treatType, takeMedWay) {
            return BaseService.post("/Consultation/SubmitInfomation", {
                disease: disease,
                infomation: infomation,
                help: help,
                visitHospital: visitHospital,
                isDrug: isDrug,
                drug: drug,
                isAllergy: isAllergy,
                allergy: allergy,
                isPreviousDisease: isPreviousDisease,
                previousDisease: previousDisease,
                purpose: purpose,
                visitPatientId: visitPatientId,
                doctorCode: doctorCode,
                infomationId: infomationId,
                must: must,
                isGuardian: isGuardian,
                guardianName: guardianName,
                guardianPhone: guardianPhone,
                currentAreaCode: currentAreaCode,
                treatType: treatType,
                takeMedWay: takeMedWay
            });
        },
        // 获取病情描述列表
        getInfomationList: function (vpId) {
            return BaseService.post("/Consultation/GetInfomationList", { vpId: vpId });
        },
        // 获取预问诊病历列表  cfw 2022年12月26日16:13:58 增加获取预问诊病历列表
        getAutoInquiryInfoList: function (vpId, inquiry_info_id) {
            return BaseService.post("/Consultation/GetAutoInquiryInfoList", { vpId: vpId, inquiry_info_id: inquiry_info_id });
        },
        // 获取病历信息详情
        selectInfomation: function (infomationId) {
            return BaseService.post("/Consultation/SelectInfomation", { infomationId: infomationId });
        },
        // 获取百洋会话状态
        getBYStatus: function (applyId) {
            return BaseService.post("/Consultation/GetBYStatus", { applyId: applyId });
        },
        // 复制图片
        copyImg: function (newId, oldId) {
            return BaseService.post("/Consultation/CopyImg", { newId: newId, oldId: oldId });
        },
        // 回写RECID
        writeBackRecId: function (recId, infomationId) {
            return BaseService.post("/Consultation/WriteBackRecId", { recId: recId, infomationId: infomationId });
        },
        // 查询所患疾病
        searchDisease: function (name, vpId) {
            return BaseService.post("/Consultation/SearchDisease", { name: name, vpId: vpId });
        },
        // 获取上一次诊断
        getDiseaseResp: function (requestId) {
            var deferred = $q.defer();

            // 异步等待通用方法
            function RespGetDisease(requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/GetDiseaseResp',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                RespGetDisease(requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/GetDiseaseResp',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 0) {
                    RespGetDisease(requestId, 0);
                }
                else if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    RespApply(requestId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 判断是否可以使用复诊续方资质延长
        checkOLCondition: function (vpId){
            return BaseService.post("/Consultation/CheckOLCondition", { vpId: vpId });
        },
        // 获取会话列表
        getChatInfoList: function (consultationType) {
            return BaseService.post("/Consultation/GetChatInfoList", { consultationType: consultationType, miPatientBJYBFlag: "1" });
        },
        // 获取会话详情
        getChatInfo: function (applyId) {
            return BaseService.post("/Consultation/GetChatInfo", { applyId: applyId });
        },
        // 获取检查单列表
        getCheckList: function (applyId) {
            return BaseService.post("/Consultation/GetCheckList", { applyId: applyId });
        },
        // 获取病情描述KEY
        getInfomationKey: function (applyId) {
            return BaseService.post("/Consultation/GetInfomationKey", { applyId: applyId });
        },
        // 获取视频问诊排班
        getVideoSchedList: function (doctorCode) {
            return BaseService.post("/Consultation/GetVideoSchedList", { doctorCode: doctorCode });
        },
        // 获取最终问诊医生或排班
        getDoctorInfo: function (vpId, treatType, doctorCode, schedId) {
            return BaseService.post("/Consultation/GetDoctorInfo", { vpId: vpId, treatType: treatType, doctorCode: doctorCode, schedId: schedId });
        },
        // 提交视频问诊申请
        submitVideoApply: function (vpId, schedId, isPatientMI, examInfo) {
            return BaseService.post("/Consultation/SubmitVideoApply", { vpId: vpId, schedId: schedId, isPatientMI: isPatientMI, examInfo: examInfo });
        },
        // 视频签到
        videoSignIn: function (vpId, treatApplyId){
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespVideoSignIn(treatApplyId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/VideoSignInResp',
                        data: { treatApplyId: treatApplyId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1 || data.result == 0) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespVideoSignIn(treatApplyId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/VideoSignInReq',
                data: { vpId: vpId, treatApplyId: treatApplyId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                else {
                    RespVideoSignIn(treatApplyId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 进入视频
        videoGetIntoRoom: function (vpId, treatApplyId) {
            return BaseService.post("/Consultation/VideoGetIntoRoom", { vpId: vpId, treatApplyId: treatApplyId });
        },
        // 获取视频问诊详情
        loadTreatApply: function (treatApplyId, vpId){
            return BaseService.post("/Consultation/LoadTreatApplyVideo", { treatApplyId: treatApplyId, vpId: vpId });
        },
        // 取消视频
        overTimeVideoApply: function (treatApplyId, vpId){
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespVideoCancel(count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/OverTimeVideoApplyResp',
                        data: { treatApplyId: treatApplyId, vpId: vpId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else if (data.result == 0){
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                RespVideoCancel(count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/OverTimeVideoApplyReq',
                data: { vpId: vpId, treatApplyId: treatApplyId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                else if (data.result == 2) {
                    deferred.resolve(data);
                }
                else {
                    RespVideoCancel(0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取支付时间限制
        getTimeLimitVideo: function (treatApplyId, treatType) {
            return BaseService.post("/Consultation/GetTimeLimitVideo", { treatApplyId: treatApplyId, treatType: treatType });
        },
        // 获取诊疗资料
        getTreatApplyVideoConvr: function (treatApplyId){
            return BaseService.post("/Consultation/GetTreatApplyVideoConvr", { treatApplyId: treatApplyId });
        },
        // 确认选择药品快递方式
        confirmVideoMedWay: function (treatApplyId, vpId){
            return BaseService.post("/Consultation/ConfirmVideoMedWay", { treatApplyId: treatApplyId, vpId: vpId });
        },
        // 查看历史会话
        getHistoryChatInfo: function (treatApplyId, vpId) {
            return BaseService.post("/Consultation/GetHistoryChatInfo", { treatApplyId: treatApplyId, vpId: vpId });
        },
        // 叫醒模板消息服务
        initServiceTmplMessage: function () {
            return BaseService.post("/Consultation/InitServiceTmplMessage");
        },
        // 获取DICOM列表
        getDicomList: function (vpId, infomationId) {
            return BaseService.post("/Consultation/GetDicomList", { vpId: vpId, infomationId: infomationId });
        },
        // 引用DICOM
        quoteDicom: function (dicomId, informationId, vpId) {
            return BaseService.post("/Consultation/QuoteDicom", { dicomId: dicomId, informationId: informationId, vpId: vpId });
        },
        // 删除DICOM
        delDicom: function (dicomContactId, vpId) {
            return BaseService.post("/Consultation/DelDicom", { dicomContactId: dicomContactId, vpId: vpId });
        },
        // 查询已关联DICOM列表
        getDicomImgList: function (informationId, vpId) {
            return BaseService.post("/Consultation/GetDicomImgList", { informationId: informationId, vpId: vpId });
        },
        // 获取护理咨询专长分组列表
        getSpecialityGroupList: function () {
            return BaseService.post("/Consultation/GetSpecialityGroupList");
        },
        // 获取医学影像科别分组列表
        getCategoryGroupList: function () {
            return BaseService.post("/Consultation/GetCategoryGroupList");
        },
        // 判断是否为荣耀健康研究患者
        isHonorPatient: function (vpId) {
            return BaseService.post("/Consultation/IsHonorPatient", { vpId: vpId });
        },
        // 北京医保自行退费
        getRefundBJYBUrlBYTreat: function (treatApplyId, vpId) {
            return BaseService.post("/Consultation/GetRefundBJYBUrlBYTreat", { treatApplyId: treatApplyId, vpId: vpId });
        },
        // 图文问诊取消申请
        cancelBYTreatApply: function (treatApplyId, vpId) {
            return BaseService.post("/Consultation/CancelBYTreatApply", { treatApplyId: treatApplyId, vpId: vpId });
        }
    }
})