﻿angular.module('fwapp.services')

.service('FlupINRService', function ($q, $http, BaseService) {
    return {
        // 获取回顾信息(三合一)
        getRecord: function (recordType, patientId) {
            return BaseService.post("/FlupINR/GetRecord", { recordType: recordType, patientId: patientId });
        },
        // 获取当前用药信息
        getDrugPersent: function (patientId) {
            return BaseService.post("/FlupINR/GetDrugPersent", { patientId: patientId });
        },
        // 获取INR统计信息
        getINRInfo: function (patientId) {
            return BaseService.post("/FlupINR/GetINRInfo", { patientId: patientId });
        },
        // 获取并发症统计信息
        getComplicationInfo: function (patientId) {
            return BaseService.post("/FlupINR/GetComplicationInfo", { patientId: patientId });
        },
        // 获取药物字典
        getMedicalList: function (key) {
            return BaseService.post("/FlupINR/GetMedicalList", { key: key });
        },
        // 获取图片
        getImage: function (recordId, type) {
            return BaseService.post("/FlupINR/GetImage", { recordId: recordId, type: type });
        },
        // 获取咨询
        getContent: function (pid) {
            return BaseService.post("/FlupINR/GetContent", { patientId: pid });
        },
        // 图片路由上传
        saveImg: function (vpId, recordId, display, imgStr) {
            return BaseService.post("/FlupINR/SaveImg", { vpId: vpId, recordId: recordId, display: display, imgStr: imgStr });
        },
        // INR提交
        submitINR: function (INR) {
            return BaseService.post("/FlupINR/SubmitINR", INR);
        },
        // 并发症提交
        submitComplication: function (complication) {
            return BaseService.post("/FlupINR/SubmitComplication", complication);
        },
        // 药物提交
        submitDrug: function (drug) {
            return BaseService.post("/FlupINR/SubmitDrug", drug);
        },
        // 咨询提交
        submitAsk: function (pid, content) {
            return BaseService.post("/FlupINR/SubmitAsk", { patientId: pid, content: content });
        },
        // 删除回顾信息（三合一）
        deleteRecord: function (recordType, id) {
            return BaseService.post("/FlupINR/DeleteRecord", { recordType: recordType, id: id });
        },
        // 停用当前药物
        deleteDrugPersent: function (id, date, patientId, accountId) {
            return BaseService.post("/FlupINR/DeleteDrugPersent", { id: id, date: date, patientId: patientId, accountId: accountId });
        },
        // 开始：检查患者是否入选INR随访
        checkPatient: function (hisCardNum) {
            return BaseService.post("/FlupINR/CheckPatient", { hisCardNum: hisCardNum });
        },
        // INR提交前检查
        checkINR: function (INR) {
            return BaseService.post("/FlupINR/CheckINR", INR);
        },
        // 药物提交前检查
        checkDrug: function (drug, drugSubmitAfterINR) {
            return BaseService.post("/FlupINR/CheckDrug", { drug: drug, drugSubmitAfterINR: drugSubmitAfterINR });
        },
        // 添加用药计划
        addDrugPlan: function (modelMP) {
            return BaseService.post("/FlupINR/AddDrugPlan", modelMP);
        },
        // 首页折线图
        INRchart: function (patientId, chartType) {
            return BaseService.post("/FlupINR/INRchart", { patientId: patientId, type: chartType });
        },
        // 检查新消息
        checkMessage: function (patientId) {
            return BaseService.post("/FlupINR/CheckMessage", { patientId: patientId });
        },
        // 发送INR危险警告
        sentDangerINR: function (patientId, INRdate, INRvalue) {
            return BaseService.post("/FlupINR/SentDangerINR", { patientId: patientId, INRdate: INRdate, INRvalue: INRvalue });
        },
        // 删除用药计划
        deleteDrugPlan: function (drugId, vpid) {
            return BaseService.post("/FlupINR/DeleteDrugPlan", { drugId: drugId, vpid: vpid });
        },
        // 获取曾用药信息 
        getLastDrug: function (patientId) {
            return BaseService.post("/FlupINR/GetLastDrug", { patientId: patientId });
        },
        // 获取过往药品信息
        getPerDrugInfo: function (patientId, date) {
            return BaseService.post("/FlupINR/GetPerDrugInfo", { patientId: patientId, date: date });
        },
        // 获取帮助
        getColumns: function (key) {
            return BaseService.post("/FlupINR/GetColumns", { key: key });
        },
        // 获取个人信息
        getSelf: function (patientId) {
            return BaseService.post("/FlupINR/GetSelf", { patientId: patientId });
        },
        // 提交个人信息
        submitSelf: function (self, patientId) {
            return BaseService.post("/FlupINR/SubmitSelf", { self: self, patientId: patientId });
        },
        // 提交外联表
        submitLongQuestion: function (inr_id, complication_id, drug_id, life_id, patientId) {
            return BaseService.post("/FlupINR/SubmitLongQuestion", { inr_id: inr_id, complication_id: complication_id, drug_id: drug_id, life_id, patientId: patientId });
        },
        // 提交生活信息
        submitLife: function (life) {
            return BaseService.post("/FlupINR/SubmitLife", { life: life });
        },
        // 从长问卷删除并发症/药物信息
        lq_delete: function (type, id, patientId) {
            return BaseService.post("/FlupINR/Lq_delete", { type: type, id: id, patientId: patientId });
        },
        // 长问卷反馈
        lq_feedback: function(patientId) {
            return BaseService.post("/FlupINR/Lq_feedback", { patientId: patientId });
        }
     }
})