﻿angular.module('fwapp.services')

// 住院登记
.service('IpRegService', function ($q, $http, $timeout, BaseService) {
    return {
        // 获取用户须知数据
        agreement: function () {
            return BaseService.post("/IpReg/Agreement");
        },
        // 检查拟入院日期、床位类型服务状态
        checkDateBedServerStatus: function () {
            return BaseService.post("/IpReg/CheckDateBedServerStatus");
        },
        // 获取字典
        getDict: function (type, pcode) {
            return BaseService.post("/IpReg/GetDict", { type: type, pcode: pcode });
        },
        // 获取绑卡帮助
        getBindCardHelp: function () {
            return BaseService.post("/IpReg/GetBindCardHelp");
        },
        // 添加预约信息
        addIPNoticeExpectedDate: function (date,bed,name,num,inid) {
            return BaseService.post("/IpReg/AddIPNoticeExpectedDate", { EXPECTED_IP_DATE : date, EXPECTED_BED_TYPE : bed,
             VISIT_PATIENT_NAME : name, HIS_CARD_NUM : num, HIS_IP_NOTICE_ID : inid});
        },
        // 查询预约信息
        getIPNoticeExpectedDate: function (num,inid) {
            return BaseService.post("/IpReg/GetIPNoticeExpectedDate", { HIS_CARD_NUM : num, HIS_IP_NOTICE_ID : inid});
        },
        // 获取住院单状态
        checkIPNotice: function (vpId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/CheckIPNotice",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取当前用户住院单
        getIPNotice: function () {
            var deferred = $q.defer();
            // 2021-12-17 16:06:29 WX 住院单流调返回时带上白名单
            function WaitIpRegWhiteList(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetIpRegWhiteList',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitIpRegWhiteList(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetIPNotice",
                data: { 1: 1 },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitIpRegWhiteList(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 验证住院登记信息V2
        checkIpRegV2: function (hisCardNum, ipNoticeId, kh, noticeFinishList) {
            return BaseService.post("/IpReg/CheckIpRegV2", { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId, kh: kh, noticeFinishList: noticeFinishList });
        },
        // 获取当前用户住院单
        getIPNoticeV2: function (hisCardNum, ipNoticeId) {
            var deferred = $q.defer();
            // 2021-12-17 16:06:29 WX 住院单流调返回时带上白名单
            function WaitIpRegWhiteList(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetIpRegWhiteList',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitIpRegWhiteList(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetIPNoticeV2",
                data: { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitIpRegWhiteList(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取最近一次住院登记信息
        getLastIPRegInfo: function (vpId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetLastIPRegInfo",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    // WaitResponse(deferred, data.data, 0);
                    //cfw 2023年3月25日13:49:19 增加新响应方法，后台处理省市县逻辑
                    WaitResponse_HisIPreg(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取最近一次住院登记信息V2
        getLastIPRegInfoV2: function (vpId, hisCardNum, ipNoticeId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetLastIPRegInfoV2",
                data: { visitPatientId: vpId, hisCardNum: hisCardNum, ipNoticeId: ipNoticeId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    // WaitResponse(deferred, data.data, 0);
                    //cfw 2023年3月25日13:49:19 增加新响应方法，后台处理省市县逻辑
                    WaitResponse_HisIPreg(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院登记信息
        getIpReg: function (vpid, ipNoticeId, kh, hisCardNum, finishList) {
            return BaseService.post("/IpReg/GetIpReg", { vpid: vpid, ipNoticeId: ipNoticeId, kh: kh, hisCardNum: hisCardNum, finishList: finishList });
        },
        // 获取住院登记信息V2
        getIpRegV2: function (hisCardNum, ipNoticeId, patientName, kh, idCard_code, noticeFinishList) {
            return BaseService.post("/IpReg/GetIpRegV2", { hisCardNum: hisCardNum, ipNoticeId: ipNoticeId, patientName: jsencrypt.encrypt(patientName), kh: kh, idCard_code: jsencrypt.encrypt(idCard_code), noticeFinishList: noticeFinishList });
        },
        // 保存住院登记信息
        saveIpReg: function (ipRegInfo, vpid, hisCardNum, ipNoticeId, from, isBaby, age, commitFlag, isEmr) {
            // 2019-5-31 11:16:12 jsencrypt.js 加密
            // 深度复制
            var data = {};
            $.extend(data, ipRegInfo);
            if (data) {
                var keyList = ["BIRTH_HOSPITAL", "NEWBORN_WEIGHT", "WORK_ADDRESS", "WORK_TEL", "WORK_POSTCODE", "HOUSEHOLD_DETAIL", "HOUSEHOLD_POSTCODE", "ADDRESS_DETAIL", "ADDRESS_POSTCODE", "TEL", "EMAIL", "CONTACT_NAME", "CONTACT_TEL", "CONTACT_ADDRESS"]
                Object.keys(data).forEach(e => {
                    if (keyList.indexOf(e) >= 0 && data[e] != null && data[e] != "") {
                        data[e] = jsencrypt.encrypt(data[e]);
                    }
                })
            }
            data.vpid = vpid;
            data.hisCardNum = hisCardNum;
            data.ipNoticeId = ipNoticeId;
            data.from = from;
            data.isBaby = isBaby;
            data.age = age;
            data.commitFlag = commitFlag;
            data.isEmr = isEmr;
            return BaseService.post("/IpReg/SaveIpReg", data);
        },
        // 2024-11-9 20:05:01  ZZL 新增陪同码保存
        saveIpAccompany: function (vpid, ipNoticeId, contactTel, hisCardNum) {
            return BaseService.post("/IpReg/SaveIpAccompany", { vpid: vpid, ipNoticeId: ipNoticeId, contactTel: contactTel, hisCardNum: hisCardNum});
        },
        // 院后流程，入库his住院登记信息 cfw 2023年3月24日10:06:15
        ipRegInfo_Save: function (ipRegInfo, vpid, hisCardNum, ipNoticeId, from, isBaby, age, commitFlag) {
            // 2019-5-31 11:16:12 jsencrypt.js 加密
            // 深度复制
            var data = {};
            $.extend(data, ipRegInfo);
            if (data) {
                var keyList = ["BIRTH_HOSPITAL", "NEWBORN_WEIGHT", "WORK_ADDRESS", "WORK_TEL", "WORK_POSTCODE", "HOUSEHOLD_DETAIL", "HOUSEHOLD_POSTCODE", "ADDRESS_DETAIL", "ADDRESS_POSTCODE", "TEL", "EMAIL", "CONTACT_NAME", "CONTACT_TEL", "CONTACT_ADDRESS"]
                Object.keys(data).forEach(e => {
                    if (keyList.indexOf(e) >= 0 && data[e] != null && data[e] != "") {
                        data[e] = jsencrypt.encrypt(data[e]);
                    }
                })
            }
            data.vpid = vpid;
            data.hisCardNum = hisCardNum;
            data.ipNoticeId = ipNoticeId;
            data.from = from;
            data.isBaby = isBaby;
            data.age = age;
            data.commitFlag = commitFlag;
            return BaseService.post("/IpReg/IpRegInfo_Save", data);
        },
        // 获取患者新冠告知书是否签字
        getSignFlag_XG: function (vpid) {
            return BaseService.post("/IpReg/GetSignFlag_XG", { vpid: vpid });
        },
        // 获取病历图片
        getRecordPic: function (apply_id) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/IpReg/GetRecordPic",
                data: { apply_id: apply_id },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 保存签名信息
        SaveRecordSign: function (stringArr, HIS_APPLY_ID, IP_RECORD_SIGN_ID) {
            return BaseService.post("/IpReg/SaveRecordSign", { stringArr: stringArr, HIS_APPLY_ID: HIS_APPLY_ID, IP_RECORD_SIGN_ID: IP_RECORD_SIGN_ID });
        },
        // cfw 2023年4月12日16:01:31 保存特需知情同意书签名信息
        saveRecordSign_special: function (stringArr, his_ip_notice_id, his_apply_id, kh) {
            return BaseService.post("/IpReg/SaveRecordSign_Special", { stringArr: stringArr, his_ip_notice_id: his_ip_notice_id, his_apply_id: his_apply_id, kh: kh });
        },
        // cfw 2023年3月2日19:47:41 上传图片方法
        imgUpload: function (url, imgdata) {
            var deferred = $q.defer();
            $.ajax({
                type: "POST",
                url: url,
                data: { "base64string": imgdata },
                success: function (result) {
                    deferred.resolve(result);
                    console.log(result);
                }, error: function (error) {
                    deferred.resolve(result);
                }
            })
            return deferred.promise;

            // var deferred = $q.defer();
            // $http({
            //     method: 'POST',
            //     // dataType: 'JSON',
            //     url: url,
            //     data: { "base64string": imgdata },
            //     withCredentials: true
            // }).success(function (result, status) {
            //     deferred.resolve(result);
            // }).error(function (result, status) {
            //     deferred.reject(result);
            // });
            // return deferred.promise;
        },
        // 身份校验
        confirmPatient: function (name, sfz) {
            return BaseService.post("/IpReg/ConfirmPatient", { name: name, sfz: sfz });
        },
        // 获取排班数据
        confirmPatientYYInfo: function (name, sfz) {
            return BaseService.post("/IpReg/ConfirmPatientYYInfo", { name: name, sfz: sfz });
        },
        // 提交预约
        saveAppointment: function (yyid, patient_name, orgname, his_time_slot, vis_name, vis_tel, vis_sfz, yy_time, time_slot, type, his_idb) {
            return BaseService.post("/IpReg/SaveAppointment", { yyid: yyid, patient_name: patient_name, orgname: orgname, his_time_slot: his_time_slot, vis_name: vis_name, vis_tel: vis_tel, vis_sfz: vis_sfz, yy_time: yy_time, time_slot: time_slot, type: type, his_idb: his_idb });
        },
        // 取消预约
        cancelAppointment: function (yyid, patient_name, patient_org, vis_name, time_slot, type, his_idb) {
            return BaseService.post("/IpReg/CancelAppointment", { yyid: yyid, patient_name: patient_name, patient_org: patient_org, vis_name: vis_name, time_slot: time_slot, type: type, his_idb: his_idb });
        }
    }
    // 异步等待通用方法
    function WaitResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        WaitResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
    // 异步等待通用方法
    function WaitResponse_HisIPreg(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse_HisIPreg',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        WaitResponse_HisIPreg(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
})