﻿angular.module('fwapp.services')

// 预约挂号-缴费版
.service('OpApptService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查服务状态
        checkServerStatus: function () {
            return BaseService.post("/OpAppt/CheckServerStatus");
        },
        // 获取配置
        getConfig: function (opInfoId) {
            return BaseService.post("/OpAppt/GetConfig", { opInfoId: opInfoId });
        },
        // 获取预约挂号出诊排班
        getScheduling: function (divisionCode, schedDate, schedTime, doctorLevel, speciality, doctorName) {
            return BaseService.post("/OpAppt/GetScheduling", { divisionCode: divisionCode, schedDate: schedDate, schedTime: schedTime, doctorLevel: doctorLevel, speciality: speciality, doctorName: doctorName, isWaitList: "1" });
        },
        // 获取预约挂号出诊排班
        getDoctorScheduling: function (doctorCode) {
            return BaseService.post("/OpAppt/DoctorNew", { doctorCode: doctorCode, halfday: true, isWaitList: "1" });
        },
        // 获取预约信息
        getOpSchedInfo: function (id) {
            return BaseService.post("/OpAppt/GetOpSchedInfo", { id: id, isWaitList: "1" });
        },
        // 获取预约信息
        getDoctorListBySpeciality: function (speciality) {
            return BaseService.post("/OpAppt/GetDoctorListBySpeciality", { speciality: speciality });
        },
        // 提交预约挂号申请
        submitReg: function (vpId, opSchedId, seq, isWaitList) {
            var deferred = $q.defer();
            // 异步等待 获取当日号申请状态
            function WaitResponse(deferred, opRegId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpAppt/RegStatus',
                        data: { opRegId: opRegId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        // 申请单号无效，报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 18) {
                                WaitResponse(deferred, opRegId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/OpAppt/SubmitReg',
                data: { vpId: vpId, opSchedId: opSchedId, seq: seq, isWaitList: isWaitList },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取当日号申请状态
        regStatus: function (opRegId) {
            var deferred = $q.defer();
            // 异步等待 获取当日号申请状态
            function WaitResponse(deferred, opRegId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpAppt/RegStatus',
                        data: { opRegId: opRegId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        // 申请单号无效，报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 10) {
                                WaitResponse(deferred, opRegId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            WaitResponse(deferred, opRegId, 0);
            return deferred.promise;
        },
        // 获取挂号列表
        getOpRegList: function (status) {
            return BaseService.post("/OpAppt/GetOpRegList", { status: status });
        },
        // 获取合并预约挂号列表
        getOpApptList: function (status, doctorName) {
            return BaseService.post("/OpAppt/GetOpApptList", { status: status, doctorName: doctorName });
        },
        // 获取特色技术/病种列表
        getSpecialityGroupList: function (groupType) {
            return BaseService.post("/OpAppt/GetSpecialityGroupList", { groupType: groupType });
        },
        // 获取预约挂号出诊排班_按特色技术/病种
        getSchedulingBySpecialityGroup: function (groupType, groupCode, schedDate, schedTime) {
            return BaseService.post("/OpAppt/GetSchedulingBySpecialityGroup", { groupType: groupType, groupCode: groupCode, schedDate: schedDate, schedTime: schedTime, isWaitList: "1" });
        },
        // 根据医生名称刷新医生列表
        getSchedulingByDoctorName: function (doctorName) {
            return BaseService.post("/OpAppt/GetSchedulingByDoctorName", { doctorName: doctorName });
        },
        // 获取预约挂号前置温馨提示
        getPreNotice: function () {
            return BaseService.post("/OpAppt/GetPreNotice");
        },
        // 获取号序列表
        getSchedSeq: function (schedId) {
            return BaseService.post("/OpAppt/GetSchedSeq", { schedId: schedId });
        },
        // 提交代开药人信息
        submitAgent: function (opRegId, agentPhone, agentName, agentIdCardNo, agentRelation) {
            return BaseService.post("/OpAppt/SubmitAgent", { opRegId: opRegId, agentPhone: jsencrypt.encrypt(agentPhone), agentName: jsencrypt.encrypt(agentName), agentIdCardNo: jsencrypt.encrypt(agentIdCardNo), agentRelation: agentRelation });
        },
        // 提交婚姻状况
        updatePatientInfo: function (vpId, maritalStatus) {
            return BaseService.post("/OpAppt/UpdatePatientInfo", { vpId: vpId, maritalStatus: maritalStatus });
        },
        // 获取北京医保取消小程序连接
        BJYBMobileCancelReg: function (opRegId) {
            return BaseService.post("/OpAppt/BJYBMobileCancelReg", { opRegId: opRegId });
        }
    }
})