﻿angular.module('fwapp.services')

// 门诊缴费
.service('OpPaymentService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查服务状态
        checkServerStatus: function () {
            return BaseService.post("/OpPayment/CheckServerStatus");
        },
        // 获取用户须知数据
        agreement: function () {
            return BaseService.post("/OpPayment/Agreement");
        },
        // 获取绑卡帮助
        getBindCardHelp: function () {
            return BaseService.post("/OpPayment/GetBindCardHelp");
        },
        // 获取门诊待缴费项目列表 (4001)
        opPendingPayment: function (vpId) {
            var deferred = $q.defer();
            // 异步等待 获取住院单状态
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + "/Request/RespOPPendingPayment",
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        //console.log(data);
                        data.requestId = requestId;
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/OPPendingPayment",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 校验门诊待缴费项目金额 (4005)
        opPaymentAmountCalc: function (vpId, feeItems, totalFee) {
            var deferred = $q.defer();
            // 异步等待 获取住院单状态
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + "/Request/GetResponse",
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        //console.log(data);
                        data.requestId = requestId;
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            // 
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/OPPaymentAmountCalc",
                data: { visitPatientId: vpId, feeItems: feeItems, totalFee: totalFee },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 添加门诊缴费记录
        orderPayment: function (vpId, feeItem, totalFee, paymentRoute, req4001, req4005, inspectStaffStatus, bjybMobilePaymentStatus) {
            var deferred = $q.defer();
            // 异步等待 获取当日号申请状态
            function WaitResponse(deferred, opPaymentInfo, count) {
                var opPaymentId = opPaymentInfo.OP_PAYMENT_ID;
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpPayment/GetPaymentStatus',
                        data: { opPaymentId: opPaymentId },
                        withCredentials: true
                    }).success(function (data, status) {
                        data.data = opPaymentInfo;
                        console.log(data);
                        // 异常报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 20) {
                                WaitResponse(deferred, opPaymentInfo, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                        // 待支付(微信/支付宝)
                        else if (data.result == 3) {
                            deferred.resolve(data);
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/OpPayment/OrderPayment',
                data: { vpId: vpId, feeItem: feeItem, totalFee: totalFee, paymentRoute: paymentRoute, req4001: req4001, req4005: req4005, inspectStaffStatus: inspectStaffStatus, bjybMobilePaymentStatus: bjybMobilePaymentStatus },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊缴费状态
        opPaymentStatus: function (opPaymentId) {
            var deferred = $q.defer();
            // 异步等待 获取门诊缴费状态
            function WaitResponse(deferred, opPaymentId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpPayment/GetPaymentStatus',
                        data: { opPaymentId: opPaymentId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        // 异常报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 20) {
                                WaitResponse(deferred, opPaymentId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                        // 待支付(微信/支付宝)
                        else if (data.result == 3) {
                            deferred.resolve(data);
                        }
                    })
                }, 1100);
            }
            WaitResponse(deferred, opPaymentId, 0);
            return deferred.promise;
        },
        // 获取门诊待缴费项目列表V2 (4001)
        opPendingPaymentV2: function (vpId, rlatObjId, rlatObjType) {
            var deferred = $q.defer();
            // 异步等待 获取住院单状态
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + "/Request/RespOPPendingPayment",
                        data: { requestId: requestId, rlatObjType: rlatObjType, inspectStaffStatus: "1", bjybMobilePaymentStatus: "1" },
                        withCredentials: true
                    }).success(function (data, status) {
                        //console.log(data);
                        data.requestId = requestId;
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/OPPendingPaymentV2",
                data: { vpId: vpId, rlatObjId: rlatObjId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 保健医报销分解计算
        getGoldCardChargeDivide: function (vpId, feeItems, realFee) {
            return BaseService.post("/OpPayment/GetGoldCardChargeDivide", { vpId: vpId, feeItems: feeItems, realFee: realFee });
        },
        // 互联互通
        checkRecipeWithoutRegistration: function (vpId, feeItems, req4001) {
            return BaseService.post("/OpPayment/CheckRecipeWithoutRegistration", { vpId: vpId, feeItems: feeItems, req4001: req4001 });
        },
        // 北京医保获取小程序路径
        bjybMobilePayment: function (vpId, opPaymentId) {
            return BaseService.post("/OpPayment/BJYBMobilePayment", { vpId: vpId, opPaymentId: opPaymentId });
        },
        ybBindCard: function (type, vpId) {
            return BaseService.post("/OpPayment/YBBindCard", { vpId: vpId, type: type });
        }
    }
})
