﻿angular.module('fwapp.services')

// 当日预约
.service('OpRegService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查服务状态
        checkServerStatus: function () {
            return BaseService.post("/OpReg/CheckServerStatus");
        },
        // 获取配置
        getConfig: function () {
            return BaseService.post("/OpReg/GetConfig", { v: 1 });
        },
        // 获取办卡状态
        checkCardBuilt: function (vpId) {
            var deferred = $q.defer();
            // 异步等待 获取办卡状态
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespCheckCardBuilt',
                        data: { requestId: requestId, visitPatientId: vpId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckCardBuilt',
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 患者信息校验查询
        patientCheck: function (vpId) {
            var deferred = $q.defer();
            // 异步等待 获取办卡状态
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespPatientCheck',
                        data: { requestId: requestId, visitPatientId: vpId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count < 20) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/PatientCheck',
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                // 缓存
                // 2019-6-3 09:14:38 不应判断缓存中is_null状态 统一交给controller处理
                else if (data.result == -1 && data.data != null && data.data.length > 0) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 创建建卡申请
        createCardApply: function (vpId, type) {
            return BaseService.post("/OpReg/CreateCardApply", { vpId: vpId, type: type });
        },
        // 提交建卡申请
        submitCardApply: function (applyId, vpId, address, phonenum, isSelf, isActiveEcard, idType, insuranceType, MIPatientCode, marital) {
            var deferred = $q.defer();
            // 异步等待 建卡申请结果
            function WaitResponse(deferred, applyId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpReg/CardApplyResult',
                        data: { applyId: applyId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponse(deferred, applyId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/OpReg/SubmitCardApply',
                data: { applyId: applyId, vpId: vpId, address: jsencrypt.encrypt(address), phonenum: jsencrypt.encrypt(phonenum), isSelf: isSelf, isActiveEcard: isActiveEcard, idType: idType, insuranceType: insuranceType, MIPatientCode: MIPatientCode, marital: marital },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取当日号出诊排班
        getScheduling: function (divisionCode, schedTime, doctorLevel, speciality, doctorName) {
            return BaseService.post("/OpReg/GetScheduling", { divisionCode: divisionCode, schedTime: schedTime, doctorLevel: doctorLevel, speciality: speciality, doctorName: doctorName });
        },
        // 提交当日号挂号申请
        submitReg: function (vpId, opSchedId) {
            var deferred = $q.defer();
            // 异步等待 获取当日号申请状态
            function WaitResponse(deferred, opRegId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpReg/RegStatus',
                        data: { opRegId: opRegId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        // 申请单号无效，报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 10) {
                                WaitResponse(deferred, opRegId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/OpReg/SubmitReg',
                data: { vpId: vpId, opSchedId: opSchedId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 创建支付订单
        unifiedOrder: function (opRegId, paymentMethod) {
            return BaseService.post("/OpReg/UnifiedOrder", { opRegId: opRegId, paymentMethod: paymentMethod });
        },
        // 取消当日号挂号申请
        cancelReg: function (opRegId) {
            return BaseService.post("/OpReg/CancelReg", { opRegId: opRegId });
        },
        // 获取支付时间限制
        getTimeLimit: function () {
            return BaseService.post("/OpReg/GetTimeLimit");
        },
        // 获取最近挂号
        getLatestReg: function () {
            return BaseService.post("/OpReg/GetLatestReg");
        },
        // 获取当日号申请状态
        regStatus: function (opRegId) {
            var deferred = $q.defer();
            // 异步等待 获取当日号申请状态
            function WaitResponse(deferred, opRegId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/OpReg/RegStatus',
                        data: { opRegId: opRegId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        // 申请单号无效，报错
                        if (data.result == 0) {
                            deferred.resolve(data);
                        }
                        // 轮询成功
                        else if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        // 轮询中，1秒后重新发起请求(挂号轮询/支付冻结轮询)
                        else if (data.result == 2) {
                            if (count <= 10) {
                                WaitResponse(deferred, opRegId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            WaitResponse(deferred, opRegId, 0);
            return deferred.promise;
        },
        // 获取挂号列表
        getOpRegList: function (status) {
            return BaseService.post("/OpReg/GetOpRegList", { status: status });
        },
        // 删除身份证照片
        deleteIDCard: function (id, type) {
            return BaseService.post("/OpReg/DeleteIDCard", { id: id, type: type });
        }
    }
})