﻿angular.module('fwapp.services')

// 
.service('PaymentDetailsService', function ($q, $http, $timeout, BaseService) {
    return {
        // 获取充值列表
        list: function (vpId) {
            return BaseService.post("/PaymentDetails/List", { vpID: vpId });
        },
        unifiedOrder: function (vpId, hisNum, fee) {
            return BaseService.post("/Payment/UnifiedOrder", { vpId: vpId, hisNum: hisNum, fee: fee });
        },
        refundInstruction: function () {
            return BaseService.post("/PaymentDetails/RefundInstruction");
        },
        // 申请查询余额
        requestBalance: function (vpId, paymentId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/RequestBalance",
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    GetRefundAmount(deferred, data.data, paymentId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 退费申请提交
        refund: function (vpId, paymentId, refundFee) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/PaymentDetails/Refund",
                data: { vpId: vpId, paymentId: paymentId, refundFee: refundFee },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result != 1) {    // 报错
                    deferred.resolve(data);
                } else {
                    GetRefundResult(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 查看退款记录
        refundList: function (paymentId) {
            return BaseService.post("/PaymentDetails/RefundList", { paymentId: paymentId });
        }
    }

    // 异步等待获取可退费金额
    function GetRefundAmount(deferred, requestId, paymentId, count) {
        console.log("获取可退费金额,id=" + paymentId + ",count=" + count);
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetRefundAmount",
                data: { requestId: requestId, paymentId: paymentId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        GetRefundAmount(deferred, requestId, paymentId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // 异步等待获取退费申请状态
    function GetRefundResult(deferred, reqId, count) {
        console.log("获取退费申请状态,id=" + reqId + ",count=" + count);
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/PaymentDetails/RefundResult",
                data: { reqId: reqId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 10) {
                        GetRefundResult(deferred, reqId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
})