﻿angular.module('fwapp.services')

.service('RequestService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查就诊卡
        checkPatientCard: function (visitPatientId, cardNum, phoneNum) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckPatientCard',
                data: { visitPatientId: visitPatientId, cardNum: cardNum, phoneNum: phoneNum },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取电话
        GetReservedPhone: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetReservedPhone',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取LIS检验项目列表
        lisList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/LisList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取LIS检验项目结果
        lisResult: function (visitPatientId, sampleNo, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/LisResult',
                data: { visitPatientId: visitPatientId, sampleNo: sampleNo, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        //下载PDF
        downloadPDF: function (reqId, vpID, columnName, checkType, fileName) {
            var deferred = $q.defer();
            // 异步等待 检查PDF是否存在
            function WaitResponsePDF(deferred, reqId, count, vpID, columnName, fileName) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/CheckResponsePDF',
                        data: { requestId: reqId, vpID: vpID, columnName: columnName, checkType: checkType, fileName: fileName },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1 && data.is_null == 0) {
                            console.log(data);
                            deferred.resolve(data);
                        } else {
                            if (count <= 20) {
                                WaitResponsePDF(deferred, reqId, count + 1, vpID);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    }).error(function (data, status) {
                        deferred.reject(data);
                    });
                }, 1100);
            }
            WaitResponsePDF(deferred, reqId, 0, vpID, columnName, fileName);
            return deferred.promise;
        },
        // 获取检查报告图片
        checkResult: function (visitPatientId, accnoId, checkType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResult',
                data: { visitPatientId: visitPatientId, accnoId: accnoId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 2023-04-07 ZZL 获取多张图片
        // 获取检查报告图片列表(新)
        checkResultList: function (visitPatientId, accnoId, checkType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImageNew(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseMultiplelImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImageNew(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResult',
                data: { visitPatientId: visitPatientId, accnoId: accnoId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImageNew(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImageNew(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查报告图片 --- 自助机接口
        unClearResult: function (visitPatientId, sqdbh, queryToken, printType) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: "APPL_DATA" },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnclearResult',
                data: { visitPatientId: visitPatientId, sqdbh: sqdbh, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取候诊叫号信息
        opCallList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpCallList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查列表
        checkList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取核医学科检查列表 --- 自助机接口
        unClearList: function (visitPatientId, type, queryToken, printType) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnClearList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 查询手术状态
        surgicalState: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/SurgicalState',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 院外病历浏览授权
        outRecordAuth: function (visitPatientId, auth) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OutRecordAuth',
                data: { visitPatientId: visitPatientId, auth: auth },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取外院诊疗医院列表
        getOutRecordHosp: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOutRecordHosp',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 同步院外病历医院授权状态
        syncOutRecordHospAuth: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/SyncOutRecordHospAuth',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查预约列表
        checkApptList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApptList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    // WaitResponse(deferred, data.data, 0);
                    //cfw 2023年2月28日09:33:24 屏蔽WaitResponse，增加新response方法：获取检查预约列表轮训数据后，后台处理数据，增加签字标识
                    WaitCheckListResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查预约列表
        getCheckItemSched: function (hisCardNum, checkApptId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckItemSched',
                data: { hisCardNum: hisCardNum, checkApptId: checkApptId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 检查预约改期提交
        // 2019-12-2 08:23:40 HM 支持缴费前检查预约
        checkApptUpdate: function (hisCardNum, checkApptId, orderDate, timeAreaId, checkListNum) {

            // 2019-12-2 08:23:40 HM 支持缴费前检查预约
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApptUpdate',
                data: { hisCardNum: hisCardNum, checkApptId: checkApptId, orderDate: orderDate, timeAreaId: timeAreaId, checkListNum: checkListNum },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // cfw 2023年2月23日09:22:38 获取特需知情同意书病历图片
        getRecordPic_special: function (his_ip_notie_id) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetRecordPic_Special",
                data: { his_ip_notie_id: his_ip_notie_id },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    // WaitResponse(deferred, data.data, 0);
                    //cfw 2023年2月28日11:01:38 屏蔽WaitResponse ，增加新response方法
                    WaitConsentSpecialSignResponse(deferred, data.data, his_ip_notie_id, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // cfw 2023年2月23日09:22:38 获取检查知情同意书病历图片
        getRecordPic: function (check_no) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + "/Request/GetRecordPic",
                data: { check_no: check_no },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    // WaitResponse(deferred, data.data, 0);
                    //cfw 2023年2月28日11:01:38 屏蔽WaitResponse ，增加新response方法
                    WaitCheckListSignResponse(deferred, data.data, check_no, 0);
                }
                else if (data.result == -1) {
                    deferred.resolve(data);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // cfw 2023年2月23日16:08:53 保存签名信息
        saveRecordSign: function (stringArr, check_no) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/SaveRecordSign',
                data: { stringArr: stringArr, check_no: check_no },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve({ result: 1 });
                }
                else if (data.result == 0) {
                    deferred.resolve({ result: 0 });
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // cfw 2023年3月3日08:30:46 上传图片方法
        imgUpload: function (url, imgdata) {
            var deferred = $q.defer();
            $.ajax({
                type: "POST",
                url: url,
                data: { "base64string": imgdata },
                success: function (result) {
                    deferred.resolve(result);
                    console.log(result);
                }, error: function (error) {
                    deferred.resolve(result);
                }
            })
            return deferred.promise;
        },
        // 获取门诊处方
        getOpPrescription: function (visitPatientId, queryToken) {
            var deferred = $q.defer();
            function RespOpPrescription(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespOpPrescription',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespOpPrescription(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOpPrescription',
                data: { visitPatientId: visitPatientId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    RespOpPrescription(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊药品
        getOpDrug: function (visitPatientId, queryToken) {
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespOPDrug(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespOPDrug',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                RespOPDrug(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetOpDrug',
                data: { visitPatientId: visitPatientId, queryToken: queryToken, ipDrugFlag: devMode ? "1" : "0" },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    RespOPDrug(deferred, data.data[0].REQUEST_ID, 0);
                }
                else if (data.result == -1 || data.result == 0) {    // 若返回缓存结果为空 || 报错
                    deferred.resolve(data);
                }
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    RespOPDrug(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院结算审核信息
        getIPDischargeAudit: function (data) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                data: data,
                url: serviceUrl + '/Request/GetIPDischargeAudit',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查叫号信息
        getCheckCalllist: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckCalllist',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查申请单列表
        checkApplList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckApplList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查申请单图片
        checkApplImage: function (hisCardNum, checkApplId) {
            var deferred = $q.defer();
            // 异步等待 获取检查申请单图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: 'APPL_DATA' },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckApplImg',
                data: { hisCardNum: hisCardNum, checkApplId: checkApplId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 住院满意度：住院号及姓名 =>换 患者信息 =>后台保存 住院满意度表
        ipSatisCheckPatient: function (inpatientId, name) {
            var deferred = $q.defer();
            function WaitResponseIpSatis(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseIpSatis',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功、且存成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, satisId: data.satisId });
                        }
                        // 成功、但存失败
                        else if (data.result == 0) {
                            deferred.resolve({ result: 0, msg: data.msg });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未能查到就诊人，请核实病案号及患者姓名" });
                        }
                        // 并发(应该仅缓存rid出现...所以是count+1还是是0..)
                        else if (data.result == 50003) {
                            console.log("!");
                            WaitResponseIpSatis(deferred, requestId, count + 1);
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count <= 10) {
                                WaitResponseIpSatis(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpSatisCheckPatient',
                data: { inpatientId: inpatientId, name: name },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseIpSatis(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院患者信息
        getIPPatientInfo: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetIPPatientInfo',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院预存充值明细
        getIPChargeList: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetIPChargeList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 病案复印：patient_name/id_code =>换 患者信息 =>后台对比out_date =>妥 保存病案复印表
        casePrintCheckPatient: function (patient_name, id_code, out_date) {
            var deferred = $q.defer();
            function WaitResponseCasePrint(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseCasePrint',
                        data: { requestId: requestId, out_date: out_date },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, applyId: data.applyId });
                        }
                        // 存表过程中，出现错误
                        else if (data.result == 0) {
                            deferred.resolve({ result: 0, msg: data.msg });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到此就诊人，请核查所填姓名/身份证号" });
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count <= 10) {
                                WaitResponseCasePrint(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CasePrintCheckPatient',
                data: { patient_name: patient_name, id_code: id_code },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseCasePrint(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取可预约时间
        preCheckAppt: function (vpId, checkListNum) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/PreCheckAppt',
                data: { vpId: vpId, checkListNum: checkListNum },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 消息流号序
        MessageStreamNumberSenquence: function (requestId) {
            var deferred = $q.defer();
            WaitResponse(deferred, requestId, 0);
            return deferred.promise;
        },
        // 等候人数(不要了)
        opWaitCount: function (vpId, bloodType, myIndex) {
            var deferred = $q.defer();
            function WaitResponseWaitCount(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseWaitCount',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, wait_count: data.wait_count, wait_time: data.wait_time });
                        }
                        // 未查到就诊人 =>显示原等待人数
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到就诊人" });
                        }
                        // 根本没查到
                        else {
                            // 再试试
                            if (count < 5) {
                                WaitResponseWaitCount(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "根本没查到" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpWaitCount',
                data: { vpId: vpId, bloodType: bloodType, myIndex: myIndex },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseWaitCount(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 医保患者
        checkMI: function (vpid) {
            var deferred = $q.defer();
            function WaitResponseCheckMI(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/WaitResponseCheckMI',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 成功
                        if (data.result == 1) {
                            deferred.resolve({ result: 1, descr: data.descr, help: data.help, isMI: data.isMI, requestId: requestId, isMIVerify: data.isMIVerify });
                        }
                        // 未查到就诊人
                        else if (data.result == 50002) {
                            deferred.resolve({ result: 0, msg: "未查到就诊人的医保信息" });
                        }
                        // 根本没查到
                        else {
                            // 再试一次
                            if (count < 20) {
                                WaitResponseCheckMI(deferred, requestId, count + 1);
                            }
                            // 算了吧
                            else {
                                deferred.resolve({ result: 0, msg: "网络原因，请稍后重试" });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckMI',
                data: { vpid: vpid },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseCheckMI(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 医保金额拆分
        miPreDivideRevisit: function (vpId, doctorCode) {
            var deferred = $q.defer();
            function WaitResponseMIPre(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponse',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/MIPreDivideRevisit',
                data: { vpId: vpId, doctorCode: doctorCode },
                withCredentials: true
            }).success(function (data, status) {
                // 报错
                if (data.result == 0) {
                    deferred.resolve(data);
                }
                // 缓存 || 成功
                else {
                    WaitResponseMIPre(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 修改预留手机号
        changeReservedPhone: function (requestId, vpId, oldPhone, newPhone, vericodeOld, vericodeNew) {
            var deferred = $q.defer();
            function WaitResponseReservedPhone(deferred, logId, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespReservedPhone',
                        data: { logId: logId, requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponseReservedPhone(deferred, logId, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/ChangeReservedPhone',
                data: { requestId: requestId, vpId: vpId, oldPhone: oldPhone, newPhone: newPhone, vericodeOld: jsencrypt.encrypt(vericodeOld), vericodeNew: jsencrypt.encrypt(vericodeNew) },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseReservedPhone(deferred, data.data.logId, data.data.requestId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊病历列表
        opRecordList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpRecordList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院列表
        ipList: function (visitPatientId, type, queryToken, find_time) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken, find_time: find_time },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院病历
        ipRecordList: function (vpId, idb, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpRecordList',
                data: {
                    vpId: vpId,
                    idb: idb,
                    type: type,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    // WaitResponse(deferred, data.data, 0);
                    WaitIpRecordListResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院病历详情
        ipRecordDetail: function (vpId, idr, idb, type, oldnew, queryToken) {
            var deferred = $q.defer();

            // 异步等待 获取病历图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        //cfw 2023年3月8日14:27:36 修改获取住院病历内容，后台调用终端打印接口，response表结构修改
                        url: serviceUrl + '/Request/GetResponseImage1',
                        data: { 
                            requestId: requestId,
                            tableName: "RESP_IP_RECORD_DETAIL_NEW",
                            columnName: "REPORT_DATA"
                        },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/IpRecordDetail',
                data: {
                    vpId: vpId,
                    idr: idr,
                    idb: idb,
                    type: type,
                    oldnew: oldnew,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseImage(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊病历详情
        opRecordDetail: function (vpId, idb, idr, lb, kh, zyh, idt, filePath, queryToken) {
            var deferred = $q.defer();

            // 异步等待 获取病历图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: {
                            requestId: requestId,
                            columnName: "RECORD_DATA"
                        },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OpRecordDetail',
                data: {
                    vpId: vpId,
                    idb: idb,
                    idr: idr,
                    lb: lb,
                    kh: kh,
                    zyh: zyh,
                    idt: idt,
                    filePath: filePath,
                    queryToken: queryToken
                },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseImage(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查影像
        checkResultImg: function (visitPatientId, accnoId, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResultImg',
                data: { visitPatientId: visitPatientId, accnoId: accnoId, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取检查报告影像
        checkResultDicom: function (visitPatientId, idp, dicomType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseDicom(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseDicom',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseDicom(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/CheckResultDicom',
                data: { visitPatientId: visitPatientId, idp: idp, dicomType: dicomType, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取影像 新请求
                if (data.result == 1) {
                    WaitResponseDicom(deferred, data.data, 0);
                }
                // 轮询获取影像 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseDicom(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 查询影像采集状态
        getDicomCollectStatus: function (requestId) {
            return BaseService.post("/Request/GetDicomCollectStatus", { requestId: requestId });
        },
        // 康复候诊叫号
        getRHBCallList: function () {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRHBCallList',
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        //获取康复治疗计划
        getRHBPlan: function (visitPatientId) {
            var deferred = $q.defer();
            function WaitResponseRHB(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseRHB',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseRHB(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRHBPlan',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else {
                    WaitResponseRHB(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取核医学检查报告或门诊病历
        getNuClearList: function (visitPatientId, sqdbh, printType, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage',
                        data: { requestId: requestId, columnName: "REPORT_DATA" },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/UnclearList',
                data: { visitPatientId: visitPatientId, sqdbh: sqdbh, queryToken: queryToken, printType: printType },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImage(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取门诊处方PDF
        getDrugRecord: function (visitPatientId, recipeNum) {
            var deferred = $q.defer();
            function WaitResponseDrugRecord(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponse',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        // 单独把requestId吐出来，后续需要这个requestID，下载PDF
                        data.requestId = requestId;
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                WaitResponseDrugRecord(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetDrugRecord',
                data: { visitPatientId: visitPatientId, recipeNum: recipeNum },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询成功
                if (data.result == 1) {
                    WaitResponseDrugRecord(deferred, data.data, 0);
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 美康合理用药
        getRationalMadication: function (visitPatientId, recipeNum, recipeType) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetRationalMadication',
                data: { visitPatientId: visitPatientId, recipeNum: recipeNum, recipeType: recipeType },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 体检报告解读获取身份
        examList: function (visitPatientId) {
            var deferred = $q.defer();

            // 体检报告解读验证身份
            function WaitResponseExamList(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespExamList',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        } else {
                            if (count <= 10) {
                                WaitResponseExamList(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetExamList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    WaitResponseExamList(deferred, data.data, 0);
                } else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 患者信息校验查询
        patientCheck: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/PatientCheck',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                // 缓存
                // 2019-6-3 09:14:38 不应判断缓存中is_null状态 统一交给controller处理
                else if (data.result == -1 && data.data != null && data.data.length > 0) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 请求上次就诊信息
        getLastOpInfo: function (vpId) {
            var deferred = $q.defer();
            // 异步等待通用方法(获取上次就诊信息 专用)
            function WaitResponseLastInfo(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + "/Request/RespLastOpInfo_New",
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseLastInfo(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    }).error(function (data, status) {
                        deferred.reject(status);
                    });
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetLastOpInfo',
                data: { visitPatientId: vpId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponseLastInfo(deferred, data.data, 0);
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 健康教育处方列表
        hlthRecipeList: function (visitPatientId, type, queryToken) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/HlthRecipeList',
                data: { visitPatientId: visitPatientId, type: type, queryToken: queryToken },
                withCredentials: true
            }).success(function (data, status) {
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseTbName(deferred, data.data, 0, "RESP_PRINT_DISPLAY_DATALIST");
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 健康教育处方详情
        hlthRecipeResult: function (visitPatientId, orderNo, queryToken) {
            var deferred = $q.defer();
            // 异步等待 获取检查报告图片
            function WaitResponseImage(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseImage1',
                        data: { requestId: requestId, tableName: "RESP_PRINT_FILE_DATE", columnName: "FILE_CONTENT" },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImage(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/HlthRecipeResult',
                data: { visitPatientId: visitPatientId, queryToken: queryToken, orderNo: orderNo },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImage(deferred, data.data, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取住院费用清单
        getIpConsumptionList: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/RespIpConsumptionList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                deferred.resolve(data);
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 待检项目列表
        opPendingCheck: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/OPPendingCheck',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                if (data.result == 1) {
                    WaitResponse(deferred, data.data, 0);
                }
                else {
                    deferred.resolve(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取急诊病人信息
        getEmrPatientInfo: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetEmrPatientInfo',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取急诊预存充值明细
        getEmrChargeList: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetEmrChargeList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 首信接口验证
        verifyMIPatientCode: function (visitPatientId, MIPatientCode) {
            var deferred = $q.defer();

            // 异步等待 获取检查报告图片
            function WaitResponseVerifyMIPatientCode(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespVerifyMIPatientCode',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseVerifyMIPatientCode(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/VerifyMIPatientCode',
                data: { visitPatientId: visitPatientId, MIPatientCode: MIPatientCode },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponseVerifyMIPatientCode(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取患者信息（新自助机接口）
        getHisPatientInfo: function (vpId) {
            return BaseService.post("/Request/GetHisPatientInfo", { vpId: vpId });
        },
        // 保存问卷状态
        saveAgreeStatus: function (vpId) {
            return BaseService.post("/Request/SaveAgreeStatus", { vpId: vpId });
        },
        // 获取核磁证明
        reportMRIList: function (visitPatientId) {
            var deferred = $q.defer();
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/ReportMRIList',
                data: { visitPatientId: visitPatientId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1 || data.result == 0) {    // 若返回缓存结果 || 报错
                    deferred.resolve(data);
                } else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                } else {
                    WaitResponse(deferred, data.data, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取核磁证明结果
        reportMRIResult: function (visitPatientId, ida) {
            var deferred = $q.defer();
            // 异步等待 获取核磁证明结果
            function WaitResponseImageNew(deferred, requestId, count) {
                console.log(requestId, count);
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/GetResponseMultiplelImage',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 20) {
                                WaitResponseImageNew(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/ReportMRIResult',
                data: { visitPatientId: visitPatientId, ida: ida },
                withCredentials: true
            }).success(function (data, status) {
                console.log(data);
                // 轮询获取图片 新请求
                if (data.result == 1) {
                    WaitResponseImageNew(deferred, data.data, 0);
                }
                // 轮询获取图片 缓存
                else if (data.result == -1 && data.is_null == 0 && data.data != null && data.data.length > 0) {
                    WaitResponseImageNew(deferred, data.data[0].REQUEST_ID, 0);
                }
                // 查询密码错误
                else if (data.result == -2) {
                    deferred.resolve({ result: -2 });
                }
                else {
                    deferred.reject(data);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        }
    }

    // cfw 2023年2月28日09:35:16 ，增加检查预约列表新response方法
    function WaitCheckListResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckListResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitCheckListResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // cfw 2023年2月28日11:00:58 获取病历图片及是否签字
    function WaitCheckListSignResponse(deferred, requestId, check_no, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetCheckListSignResponse',
                data: { requestId: requestId, check_no: check_no },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitCheckListSignResponse(deferred, requestId, check_no, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // cfw 2023年4月12日10:39:29 获取特需知情同意书病历图片及是否签字
    function WaitConsentSpecialSignResponse(deferred, requestId, his_ip_notice_id, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetConsentSpecialSignResponse',
                data: { requestId: requestId, his_ip_notice_id: his_ip_notice_id },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitConsentSpecialSignResponse(deferred, requestId, his_ip_notice_id, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // 异步等待通用方法
    function WaitResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // cfw 2023年4月11日10:02:20 增加病历列表响应结果
    function WaitIpRecordListResponse(deferred, requestId, count) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetIpRecordListResponse',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitIpRecordListResponse(deferred, requestId, count + 1);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }

    // 异步等待通用方法
    function WaitResponseTbName(deferred, requestId, count, tbName) {
        var timer = $timeout(function () {
            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Request/GetResponse1',
                data: { requestId: requestId, tbName: tbName },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    if (count <= 20) {
                        WaitResponseTbName(deferred, requestId, count + 1, tbName);
                    }
                    else {
                        deferred.resolve({ result: 99 });
                    }
                }
            })
        }, 1100);
    }
})