﻿angular.module('fwapp.services')

// 
.service('VisitPatientService', function ($q, $http, $timeout, BaseService) {
    return {
        // 获取就诊人列表
        visitPatientList: function () {
            return BaseService.post("/Personal/VisitPatientList");
        },
        // 就诊人信息
        visitPatientInfo: function (visitPatientId) {
            return BaseService.post("/Personal/VisitPatientInfo", { visitPatientId: visitPatientId });
        },
        // 通过身份证号获取就诊人信息
        visitPatientInfoByIDCard: function (idCardCode) {
            return BaseService.post("/Personal/VisitPatientInfoByIDCard", { idCardCode: jsencrypt.encrypt(idCardCode) });
        },
        // 添加就诊人 返回就诊人信息
        addVisitPatient: function (realName, idCardCode, idCardType, sex, birthday) {
            return BaseService.post("/Personal/AddVisitPatient", { realName: jsencrypt.encrypt(realName), idCardCode: jsencrypt.encrypt(idCardCode), idCardType: idCardType, sex: sex, birthday: birthday, needRealName: devMode ? "1" : "0" });
        },
        // 绑定就诊人
        bindVisitPatient: function (visitPatientId, patientId, cardNum, phoneNum, veriCode, isSelf, isBindECard) {
            return BaseService.post("/Personal/BindVisitPatient", { visitPatientId: visitPatientId, patientId: patientId, cardNum: cardNum, phoneNum: phoneNum, veriCode: jsencrypt.encrypt(veriCode), isSelf: isSelf, isBindECard: isBindECard });
        },
        // 半绑卡 多卡选择绑卡(IS_BIND_CARD=2)
        bindPatientCardSelect: function (visitPatientId, patientId) {
            return BaseService.post("/Personal/BindPatientCardSelect", { visitPatientId: visitPatientId, patientId: patientId });
        },
        // 多卡选择绑卡 不绑卡
        bindPatientCardSelectV2: function (visitPatientId, patientId) {
            return BaseService.post("/Personal/BindPatientCardSelectV2", { visitPatientId: visitPatientId, patientId: patientId });
        },
        // 多卡选择绑卡后续 半绑
        halfBindCard: function (visitPatientId) {
            return BaseService.post("/Personal/HalfBindCard", { visitPatientId: visitPatientId });
        },
        // 移除就诊人
        removeVisitPatient: function (visitPatientId) {
            return BaseService.post("/Personal/RemoveVisitPatient", { visitPatientId: visitPatientId });
        },
        // 院外病历授权同步
        outRecordAuth: function (visitPatientId, auth) {
            return BaseService.post("/Personal/OutRecordAuth", { visitPatientId: visitPatientId, auth: auth });
        },
        // 获取院外病历医院授权状态
        // 2023-1-29 10:36:24 CGZ 入参增加multiType，传入"1"时显示阜外医院分院及北京市基层社区医院
        getOutRecordHospAuth: function (visitPatientId, multiType) {
            return BaseService.post("/Personal/GetOutRecordHospAuth", { visitPatientId: visitPatientId, multiType: multiType });
        },
        // 保存院外病历医院授权状态
        saveOutRecordHospAuth: function (visitPatientId, authHospCodes, outHospitalAuthResult, selfHospitalAuthResult) {
            return BaseService.post("/Personal/SaveOutRecordHospAuth", { visitPatientId: visitPatientId, authHospCodes: authHospCodes, outHospitalAuthResult: outHospitalAuthResult, selfHospitalAuthResult: selfHospitalAuthResult });
        },
        // 就诊人电子就诊卡：条形码
        onlineCardInfo: function (visitPatientId, hisCardNum) {
            return BaseService.post("/Personal/GetCardCodeBarcode", { visitPatientId: visitPatientId, hisCardNum: hisCardNum });
        },
        // 就诊人电子就诊卡：二维码
        onlineQRCardInfo: function (visitPatientId, hisCardNum) {
            return BaseService.post("/Personal/GetCardCodeQRCode", { visitPatientId: visitPatientId, hisCardNum: hisCardNum });
        },
        // 开通电子就诊卡
        applyECard: function (visitPatientId, phoneNum, veriCode) {
            return BaseService.post("/Personal/ApplyECard", { visitPatientId: visitPatientId, phoneNum: phoneNum, veriCode: jsencrypt.encrypt(veriCode) });
        },
        // 3/4绑卡 验证就诊卡(IS_BIND_CARD=3)
        bindPatientCardOlAchieve: function (visitPatientId, phoneNum, veriCode) {
            return BaseService.post("/Personal/BindPatientCardOlAchieve", { visitPatientId: visitPatientId, phoneNum: phoneNum, veriCode: jsencrypt.encrypt(veriCode) });
        },
        // 检查电子就诊卡是否被开通
        checkECardBind: function (hisCardNum) {
            return BaseService.post("/Personal/CheckECardBind", { hisCardNum: hisCardNum });
        },
        // 获取ECard_ECardFlag 和 ECard_ApplyCardFlag
        getECardFlag: function () {
            return BaseService.post("/Personal/GetECardFlag");
        },
        // 不带逻辑\只拿手机号的RespPatientCheck
        getPhoneAndCardNum: function (requestId, vpId, hisCardNum) {
            var deferred = $q.defer();
            WaitResponse(deferred, requestId, 0);
            function WaitResponse(deferred, requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Request/RespPatientCheck4PhoneNum',
                        data: { requestId: requestId, visitPatientId: vpId, hisCardNum: hisCardNum },
                        withCredentials: true
                    }).success(function (data, status) {
                        console.log(data);
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count < 20) {
                                console.log(requestId, count);
                                WaitResponse(deferred, requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }
            return deferred.promise;
        },
        // 获取电子卡信息
        getHealthCardInfo: function (vpid) {
            return BaseService.post("/Personal/GetHealthCardInfo", { vpid: vpid });
        },
        // 注册健康卡
        registerHealthCard: function (vpid) {
            return BaseService.post("/Personal/RegisterHealthCard", { vpid: vpid });
        },
        // 来院人员体温信息
        temperatureSubmit: function (temp) {
            return BaseService.post("/Personal/TemperatureSubmit", { temp: temp });
        },
        // 来院人员上次体温信息
        lastTemperature: function (vpid) {
            return BaseService.post("/Personal/LastTemperature", { vpid: vpid });
        },
        // 来院人员列表
        temperatureList: function (vpId) {
            return BaseService.post("/Personal/EpidemiolSrvyList", { vpId: vpId });
        },
        // 流调提交
        epidemiolSrvySubmit: function (epidSrvy) {
            return BaseService.post("/Personal/EpidemiolSrvySubmit", { epidSrvy: epidSrvy });
        },
        // 获取流调详情
        getEpidemiolSrvy: function (srvyId) {
            return BaseService.post("/Personal/GetEpidemiolSrvy", { srvyId: srvyId });
        },
        // 删除流调
        deleteEpidemiolSrvy: function (srvyId) {
            return BaseService.post("/Personal/EpidemiolSrvyDelete", { srvyId: srvyId });
        },
        // 新流调进黑名单
        EpidemiolSrvyToTemperature: function (vpId, isBlackList) {
            return BaseService.post("/Personal/EpidemiolSrvyToTemperature", { vpId: vpId, isBlackList: isBlackList });
        },
        // 2020-12-04 获取是否支持添加外国人就诊人
        ForeignModuleIsOpen: function () {
            return BaseService.post("/Personal/ForeignModuleIsOpen");
        },
        // 验证流调信息
        checkEpidSrvy: function (vpId) {
            return BaseService.post("/Personal/CheckEpidSrvy", { vpId: vpId });
        },
        // 检查核酸流调题
        epidemiolSrvyCheckNcp: function (vpId, schedId) {
            return BaseService.post("/Personal/EpidemiolSrvyCheckNcp", { vpId: vpId, schedId: schedId });
        },
        // 提交核酸流调题
        submitEpidSrvyNcp: function (vpId, epidSrvyId, ncpSrvy) {
            return BaseService.post("/Personal/SubmitEpidSrvyNcp", { vpId: vpId, epidSrvyId: epidSrvyId, ncpSrvy: ncpSrvy });
        }
    }
})