; (function (angular) {
    'use strict';
    var indexOf = [].indexOf || function (item) {
        for (var i = 0, l = this.length; i < l; i++) {
            if (i in this && this[i] === item) return i;
        }
        return -1;
    };

    angular.module('pickadate', [])

        .provider('pickadateI18n', function () {
            var defaults = {
                'prev': 'prev',
                'next': 'next'
            };

            this.translations = {};

            this.$get = function () {
                var translations = this.translations;

                return {
                    t: function (key) {
                        return translations[key] || defaults[key];
                    }
                };
            };
        })

        .factory('pickadateUtils', ['dateFilter', function (dateFilter) {
            return {
                isDate: function (obj) {
                    return Object.prototype.toString.call(obj) === '[object Date]';
                },

                stringToDate: function (dateString) {
                    if (this.isDate(dateString)) return new Date(dateString);
                    var dateParts = dateString.split('-'),
                        year = dateParts[0],
                        month = dateParts[1],
                        day = dateParts[2];

                    // set hour to 3am to easily avoid DST change
                    return new Date(year, month - 1, day, 3);
                },

                dateRange: function (first, last, initial, format) {
                    var date, i, _i, dates = [];

                    if (!format) format = 'yyyy-MM-dd';

                    for (i = _i = first; first <= last ? _i < last : _i > last; i = first <= last ? ++_i : --_i) {
                        date = this.stringToDate(initial);
                        date.setDate(date.getDate() + i);
                        dates.push(dateFilter(date, format));
                    }
                    return dates;
                }
            };
        }])

        .directive('pickadate', ['$locale', 'pickadateUtils', 'pickadateI18n', 'dateFilter', function ($locale, dateUtils, i18n, dateFilter) {
            return {
                require: 'ngModel',
                scope: {
                    date: '=ngModel',
                    defaultDate: '=',
                    // 日期模式
                    // (null)=默认 用minDate和maxDate确定范围
                    // black=黑名单 用minDate和maxDate确定范围 再排除掉dateList中的日期
                    // white=白名单 仅显示dateList中的日期
                    dateMode: '=',
                    minDate: '=',
                    maxDate: '=',
                    dateList: '=',
                    disabledDates: '=',
                    datePicking: '=',
                    datePickerModal: '=',
                    onDateSelect: '='
                },
                template:
                    '<div ng-repeat="month in months" class="pickadate">' +
                        '<div class="pickadate-header">' +
                            '<h3 class="pickadate-centered-heading">' +
                                '{{month.currentDate | date:"yyyy年MM月"}}' +
                            '</h3>' +
                        '</div>' +
                        '<div class="pickadate-body">' +
                            '<div class="pickadate-main">' +
                                '<ul class="pickadate-cell">' +
                                    '<li class="pickadate-head" ng-repeat="dayName in dayNames">' +
                                        '{{dayName}}' +
                                    '</li>' +
                                '</ul>' +
                                '<ul class="pickadate-cell">' +
                                    '<li ng-repeat="d in month.dates" ng-click="setDate(d);" class="{{d.className}}" ng-class="{\'pickadate-active\': date == d.date}">' +
                                        '{{d.date | date:"d"}}' +
                                    '</li>' +
                                '</ul>' +
                            '</div>' +
                        '</div>' +
                    '</div>',

                link: function (scope, element, attrs, ngModel) {
                    var minDate = scope.minDate && dateUtils.stringToDate(scope.minDate),
                        maxDate = scope.maxDate && dateUtils.stringToDate(scope.maxDate),
                        dateList = scope.dateList || [],
                        disabledDates = scope.disabledDates || [],
                        currentDate = (scope.defaultDate && dateUtils.stringToDate(scope.defaultDate)) || new Date(),
                        datePicking = scope.datePicking;

                    scope.dayNames = $locale.DATETIME_FORMATS.SHORTDAY;
                    scope.currentDate = currentDate;
                    scope.t = i18n.t;

                    scope.render = function (initialDate) {
                        // 同步开始和结束日期
                        setTimeout(function () {
                            dateList = scope.dateList || [];
                            // 白名单
                            if (scope.dateMode == "white" && dateList != null && dateList.length > 0) {
                                scope.minDate = dateList[0];
                                scope.maxDate = dateList[dateList.length - 1];
                            }
                            minDate = scope.minDate && dateUtils.stringToDate(scope.minDate);
                            maxDate = scope.maxDate && dateUtils.stringToDate(scope.maxDate);
                            var numberMonths = (maxDate.getYear() - minDate.getYear()) * 12 + maxDate.getMonth() - minDate.getMonth() + 1;
                            var months = [];
                            var today = dateFilter(new Date(), 'yyyy-MM-dd');
                            // 初始日期改为最小日期
                            //initialDate = new Date(initialDate.getFullYear(), initialDate.getMonth(), 1);
                            initialDate = new Date(minDate.getFullYear(), minDate.getMonth(), 1);

                            for (var i = 0; i < numberMonths; i++) {
                                var currentMonth = initialDate.getMonth();
                                var currentDate = initialDate;
                                var dayCount = new Date(initialDate.getFullYear(), initialDate.getMonth(), 0, 3).getDate();
                                var currentMonthDates = dateUtils.dateRange(0, dayCount, initialDate);
                                var prevDates = dateUtils.dateRange(-initialDate.getDay(), 0, initialDate);
                                var lastDate = dateUtils.stringToDate(currentMonthDates[currentMonthDates.length - 1]);
                                var nextMonthDates = dateUtils.dateRange(1, 7 - lastDate.getDay(), lastDate);
                                var allDates = prevDates.concat(currentMonthDates, nextMonthDates);
                                var dates = [];
    
                                // Add an extra row if needed to make the calendar to have 6 rows
                                if (allDates.length / 7 < 6) {
                                    allDates = allDates.concat(dateUtils.dateRange(1, 8, allDates[allDates.length - 1]));
                                }
    
                                for (var j = 0; j < allDates.length; j++) {
                                    var className = "", date = allDates[j];
    
                                    if (date < scope.minDate || date > scope.maxDate || dateFilter(date, 'M') !== dateFilter(currentDate, 'M')) {
                                        className = 'pickadate-disabled';
                                    } 
                                    else if (indexOf.call(disabledDates, date) >= 0) {
                                        className = 'pickadate-disabled pickadate-unavailable';
                                    }
                                    else {
                                        // 黑名单
                                        if (scope.dateMode == "black" && dateList != null && dateList.length > 0) {
                                            if (indexOf.call(dateList, dateFilter(date, 'yyyy-MM-dd')) >= 0) {
                                                className = 'pickadate-disabled';
                                            }
                                            else {
                                                className = 'pickadate-enabled';
                                            }
                                        }
                                        // 白名单
                                        else if (scope.dateMode == "white" && dateList != null && dateList.length > 0) {
                                            if (indexOf.call(dateList, dateFilter(date, 'yyyy-MM-dd')) >= 0) {
                                                className = 'pickadate-enabled';
                                            }
                                            else {
                                                className = 'pickadate-disabled';
                                            }
                                        }
                                        // 默认
                                        else {
                                            className = 'pickadate-enabled';
                                        }
                                    }
    
                                    if (date === today) {
                                        className += ' pickadate-today';
                                    }
    
                                    dates.push({ date: date, className: className });
                                }
    
                                var month = {
                                    'currentMonth': currentMonth,
                                    'currentDate': currentDate,
                                    'dayCount': dayCount,
                                    'currentMonthDates': currentMonthDates,
                                    'prevDate': prevDates,
                                    'lastDate': lastDate,
                                    'nextMonthDates': nextMonthDates,
                                    'allDates': allDates,
                                    'dates': dates
                                };
    
                                months.push(month);
    
                                initialDate = new Date(initialDate.getFullYear(), initialDate.getMonth() + 1, 1);
                            }
    
                            scope.months = months;
    
                        }, 0);
                    };

                    scope.setDate = function (dateObj) {
                        if (isDateDisabled(dateObj)) return;
                        ngModel.$setViewValue(dateObj.date);

                        scope.date = ngModel.$modelValue;

                        scope.onDateSelect();
                    };

                    ngModel.$render = function () {
                        var date;
                        if ((date = ngModel.$modelValue) && (indexOf.call(disabledDates, date) === -1)) {
                            scope.currentDate = currentDate = dateUtils.stringToDate(date);
                        } else if (date) {
                            // if the initial date set by the user is in the disabled dates list, unset it
                            scope.setDate({});
                        }
                        scope.render(currentDate);
                    };

                    function isDateDisabled(dateObj) {
                        return (/pickadate-disabled/.test(dateObj.className));
                    }
                }
            };
        }]);
})(window.angular);